@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2005-2006 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  * 
  * Contributors: 
  *   IBM - Initial API and implementation
@@ -58,9 +58,6 @@ import org.eclipse.emf.edit.ui.util.EditUIMarkerHelper;
 import org.eclipse.emf.edit.ui.util.EditUIUtil;
 import org.eclipse.emf.edit.ui.view.ExtendedPropertySheetPage;
 
-import org.eclipse.emf.ecore.EObject;
-import org.eclipse.emf.ecore.EValidator;
-
 import org.eclipse.emf.ecore.resource.Resource;
 import org.eclipse.emf.ecore.resource.ResourceSet;
 
@@ -104,6 +101,7 @@ import org.eclipse.jface.action.Separator;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.dialogs.ProgressMonitorDialog;
 
+import org.eclipse.jface.util.LocalSelectionTransfer;
 import org.eclipse.jface.viewers.ColumnWeightData;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.ISelectionChangedListener;
@@ -123,12 +121,14 @@ import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.CTabFolder;
 
 import org.eclipse.swt.dnd.DND;
+import org.eclipse.swt.dnd.FileTransfer;
 import org.eclipse.swt.dnd.Transfer;
 
 import org.eclipse.swt.events.ControlAdapter;
 import org.eclipse.swt.events.ControlEvent;
 
 import org.eclipse.swt.graphics.Point;
+import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.layout.FillLayout;
 
 import org.eclipse.swt.widgets.Composite;
@@ -232,7 +232,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
    * <!-- end-user-doc -->
    * @generated
    */
-  protected PropertySheetPage propertySheetPage;
+  protected List<PropertySheetPage> propertySheetPages = new ArrayList<PropertySheetPage>();
 
   /**
    * This is the viewer that shadows the selection in the content outline.
@@ -343,6 +343,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
   protected IPartListener partListener =
     new IPartListener()
     {
+      @Override
       public void partActivated(IWorkbenchPart p)
       {
         if (p instanceof ContentOutline)
@@ -356,7 +357,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
         }
         else if (p instanceof PropertySheet)
         {
-          if (((PropertySheet)p).getCurrentPage() == propertySheetPage)
+          if (propertySheetPages.contains(((PropertySheet)p).getCurrentPage()))
           {
             getActionBarContributor().setActiveEditor(EXTLibraryEditor.this);
             handleActivate();
@@ -367,18 +368,22 @@ public class EXTLibraryEditor extends MultiPageEditorPart
           handleActivate();
         }
       }
+      @Override
       public void partBroughtToTop(IWorkbenchPart p)
       {
         // Ignore.
       }
+      @Override
       public void partClosed(IWorkbenchPart p)
       {
         // Ignore.
       }
+      @Override
       public void partDeactivated(IWorkbenchPart p)
       {
         // Ignore.
       }
+      @Override
       public void partOpened(IWorkbenchPart p)
       {
         // Ignore.
@@ -428,6 +433,8 @@ public class EXTLibraryEditor extends MultiPageEditorPart
   protected EContentAdapter problemIndicationAdapter = 
     new EContentAdapter()
     {
+      protected boolean dispatching;
+
       @Override
       public void notifyChanged(Notification notification)
       {
@@ -449,18 +456,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
               {
                 resourceToDiagnosticMap.remove(resource);
               }
-
-              if (updateProblemIndication)
-              {
-                getSite().getShell().getDisplay().asyncExec
-                  (new Runnable()
-                   {
-                     public void run()
-                     {
-                       updateProblemIndication();
-                     }
-                   });
-              }
+              dispatchUpdateProblemIndication();
               break;
             }
           }
@@ -471,6 +467,24 @@ public class EXTLibraryEditor extends MultiPageEditorPart
         }
       }
 
+      protected void dispatchUpdateProblemIndication()
+      {
+        if (updateProblemIndication && !dispatching)
+        {
+          dispatching = true;
+          getSite().getShell().getDisplay().asyncExec
+            (new Runnable()
+             {
+               @Override
+               public void run()
+               {
+                 dispatching = false;
+                 updateProblemIndication();
+               }
+             });
+        }
+      }
+
       @Override
       protected void setTarget(Resource target)
       {
@@ -481,6 +495,8 @@ public class EXTLibraryEditor extends MultiPageEditorPart
       protected void unsetTarget(Resource target)
       {
         basicUnsetTarget(target);
+        resourceToDiagnosticMap.remove(target);
+        dispatchUpdateProblemIndication();
       }
     };
 
@@ -493,6 +509,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
   protected IResourceChangeListener resourceChangeListener =
     new IResourceChangeListener()
     {
+      @Override
       public void resourceChanged(IResourceChangeEvent event)
       {
         IResourceDelta delta = event.getDelta();
@@ -504,6 +521,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
             protected Collection<Resource> changedResources = new ArrayList<Resource>();
             protected Collection<Resource> removedResources = new ArrayList<Resource>();
 
+            @Override
             public boolean visit(IResourceDelta delta)
             {
               if (delta.getResource().getType() == IResource.FILE)
@@ -524,6 +542,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
                     }
                   }
                 }
+                return false;
               }
 
               return true;
@@ -548,6 +567,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
             getSite().getShell().getDisplay().asyncExec
               (new Runnable()
                {
+                 @Override
                  public void run()
                  {
                    removedResources.addAll(visitor.getRemovedResources());
@@ -564,6 +584,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
             getSite().getShell().getDisplay().asyncExec
               (new Runnable()
                {
+                 @Override
                  public void run()
                  {
                    changedResources.addAll(visitor.getChangedResources());
@@ -629,9 +650,10 @@ public class EXTLibraryEditor extends MultiPageEditorPart
   {
     if (!changedResources.isEmpty() && (!isDirty() || handleDirtyConflict()))
     {
+      ResourceSet resourceSet = editingDomain.getResourceSet();
       if (isDirty())
       {
-        changedResources.addAll(editingDomain.getResourceSet().getResources());
+        changedResources.addAll(resourceSet.getResources());
       }
       editingDomain.getCommandStack().flush();
 
@@ -643,7 +665,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
           resource.unload();
           try
           {
-            resource.load(Collections.EMPTY_MAP);
+            resource.load(resourceSet.getLoadOptions());
           }
           catch (IOException exception)
           {
@@ -719,17 +741,13 @@ public class EXTLibraryEditor extends MultiPageEditorPart
 
       if (markerHelper.hasMarkers(editingDomain.getResourceSet()))
       {
-        markerHelper.deleteMarkers(editingDomain.getResourceSet());
-        if (diagnostic.getSeverity() != Diagnostic.OK)
+        try
         {
-          try
-          {
-            markerHelper.createMarkers(diagnostic);
-          }
-          catch (CoreException exception)
-          {
-            EXTLibraryEditorPlugin.INSTANCE.log(exception);
-          }
+          markerHelper.updateMarkers(diagnostic);
+        }
+        catch (CoreException exception)
+        {
+          EXTLibraryEditorPlugin.INSTANCE.log(exception);
         }
       }
     }
@@ -785,11 +803,13 @@ public class EXTLibraryEditor extends MultiPageEditorPart
     commandStack.addCommandStackListener
       (new CommandStackListener()
        {
+         @Override
          public void commandStackChanged(final EventObject event)
          {
            getContainer().getDisplay().asyncExec
              (new Runnable()
               {
+                @Override
                 public void run()
                 {
                   firePropertyChange(IEditorPart.PROP_DIRTY);
@@ -801,9 +821,17 @@ public class EXTLibraryEditor extends MultiPageEditorPart
                   {
                     setSelectionToViewer(mostRecentCommand.getAffectedObjects());
                   }
-                  if (propertySheetPage != null && !propertySheetPage.getControl().isDisposed())
+                  for (Iterator<PropertySheetPage> i = propertySheetPages.iterator(); i.hasNext(); )
                   {
-                    propertySheetPage.refresh();
+                    PropertySheetPage propertySheetPage = i.next();
+                    if (propertySheetPage.getControl() == null || propertySheetPage.getControl().isDisposed())
+                    {
+                      i.remove();
+                    }
+                    else
+                    {
+                      propertySheetPage.refresh();
+                    }
                   }
                 }
               });
@@ -843,6 +871,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
       Runnable runnable =
         new Runnable()
         {
+          @Override
           public void run()
           {
             // Try to select the items in the current content viewer of the editor.
@@ -865,6 +894,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public EditingDomain getEditingDomain()
   {
     return editingDomain;
@@ -975,6 +1005,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
           {
             // This just notifies those things that are affected by the section.
             //
+            @Override
             public void selectionChanged(SelectionChangedEvent selectionChangedEvent)
             {
               setSelection(selectionChangedEvent.getSelection());
@@ -1012,6 +1043,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public Viewer getViewer()
   {
     return currentViewer;
@@ -1034,7 +1066,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
     getSite().registerContextMenu(contextMenu, new UnwrappingSelectionProvider(viewer));
 
     int dndOperations = DND.DROP_COPY | DND.DROP_MOVE | DND.DROP_LINK;
-    Transfer[] transfers = new Transfer[] { LocalTransfer.getInstance() };
+    Transfer[] transfers = new Transfer[] { LocalTransfer.getInstance(), LocalSelectionTransfer.getTransfer(), FileTransfer.getInstance() };
     viewer.addDragSupport(dndOperations, transfers, new ViewerDragAdapter(viewer));
     viewer.addDropSupport(dndOperations, transfers, new EditingDomainViewerDropAdapter(editingDomain, viewer));
   }
@@ -1047,7 +1079,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
    */
   public void createModel()
   {
-    URI resourceURI = EditUIUtil.getURI(getEditorInput());
+    URI resourceURI = EditUIUtil.getURI(getEditorInput(), editingDomain.getResourceSet().getURIConverter());
     Exception exception = null;
     Resource resource = null;
     try
@@ -1079,11 +1111,12 @@ public class EXTLibraryEditor extends MultiPageEditorPart
    */
   public Diagnostic analyzeResourceProblems(Resource resource, Exception exception) 
   {
-    if (!resource.getErrors().isEmpty() || !resource.getWarnings().isEmpty())
+    boolean hasErrors = !resource.getErrors().isEmpty();
+    if (hasErrors || !resource.getWarnings().isEmpty())
     {
       BasicDiagnostic basicDiagnostic =
         new BasicDiagnostic
-          (Diagnostic.ERROR,
+          (hasErrors ? Diagnostic.ERROR : Diagnostic.WARNING,
            "org.eclipse.emf.examples.library.editor", //$NON-NLS-1$
            0,
            getString("_UI_CreateModelError_message", resource.getURI()), //$NON-NLS-1$
@@ -1148,6 +1181,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
 
         selectionViewer = (TreeViewer)viewerPane.getViewer();
         selectionViewer.setContentProvider(new AdapterFactoryContentProvider(adapterFactory));
+        selectionViewer.setUseHashlookup(true);
 
         selectionViewer.setLabelProvider(new AdapterFactoryLabelProvider(adapterFactory));
         selectionViewer.setInput(editingDomain.getResourceSet());
@@ -1346,9 +1380,13 @@ public class EXTLibraryEditor extends MultiPageEditorPart
       getSite().getShell().getDisplay().asyncExec
         (new Runnable()
          {
+           @Override
            public void run()
            {
-             setActivePage(0);
+             if (!getContainer().isDisposed())
+             {
+               setActivePage(0);
+             }
            }
          });
     }
@@ -1375,6 +1413,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
     getSite().getShell().getDisplay().asyncExec
       (new Runnable()
        {
+         @Override
          public void run()
          {
            updateProblemIndication();
@@ -1396,9 +1435,9 @@ public class EXTLibraryEditor extends MultiPageEditorPart
       setPageText(0, ""); //$NON-NLS-1$
       if (getContainer() instanceof CTabFolder)
       {
-        ((CTabFolder)getContainer()).setTabHeight(1);
         Point point = getContainer().getSize();
-        getContainer().setSize(point.x, point.y + 6);
+        Rectangle clientArea = getContainer().getClientArea();
+        getContainer().setSize(point.x,  2 * point.y - clientArea.height - clientArea.y);
       }
     }
   }
@@ -1417,9 +1456,9 @@ public class EXTLibraryEditor extends MultiPageEditorPart
       setPageText(0, getString("_UI_SelectionPage_label")); //$NON-NLS-1$
       if (getContainer() instanceof CTabFolder)
       {
-        ((CTabFolder)getContainer()).setTabHeight(SWT.DEFAULT);
         Point point = getContainer().getSize();
-        getContainer().setSize(point.x, point.y - 6);
+        Rectangle clientArea = getContainer().getClientArea();
+        getContainer().setSize(point.x, clientArea.height + clientArea.y);
       }
     }
   }
@@ -1447,21 +1486,20 @@ public class EXTLibraryEditor extends MultiPageEditorPart
    * <!-- end-user-doc -->
    * @generated
    */
-  @SuppressWarnings("rawtypes")
   @Override
-  public Object getAdapter(Class key)
+  public <T> T getAdapter(Class<T> key)
   {
     if (key.equals(IContentOutlinePage.class))
     {
-      return showOutlineView() ? getContentOutlinePage() : null;
+      return showOutlineView() ? key.cast(getContentOutlinePage()) : null;
     }
     else if (key.equals(IPropertySheetPage.class))
     {
-      return getPropertySheetPage();
+      return key.cast(getPropertySheetPage());
     }
     else if (key.equals(IGotoMarker.class))
     {
-      return this;
+      return key.cast(this);
     }
     else
     {
@@ -1492,6 +1530,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
 
           // Set up the tree viewer.
           //
+          contentOutlineViewer.setUseHashlookup(true);
           contentOutlineViewer.setContentProvider(new AdapterFactoryContentProvider(adapterFactory));
           contentOutlineViewer.setLabelProvider(new AdapterFactoryLabelProvider(adapterFactory));
           contentOutlineViewer.setInput(editingDomain.getResourceSet());
@@ -1532,6 +1571,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
          {
            // This ensures that we handle selections correctly.
            //
+           @Override
            public void selectionChanged(SelectionChangedEvent event)
            {
              handleContentOutlineSelection(event.getSelection());
@@ -1550,27 +1590,25 @@ public class EXTLibraryEditor extends MultiPageEditorPart
    */
   public IPropertySheetPage getPropertySheetPage()
   {
-    if (propertySheetPage == null)
-    {
-      propertySheetPage =
-        new ExtendedPropertySheetPage(editingDomain)
+    PropertySheetPage propertySheetPage =
+      new ExtendedPropertySheetPage(editingDomain, ExtendedPropertySheetPage.Decoration.NONE, null, 0, false)
+      {
+        @Override
+        public void setSelectionToViewer(List<?> selection)
         {
-          @Override
-          public void setSelectionToViewer(List<?> selection)
-          {
-            EXTLibraryEditor.this.setSelectionToViewer(selection);
-            EXTLibraryEditor.this.setFocus();
-          }
+          EXTLibraryEditor.this.setSelectionToViewer(selection);
+          EXTLibraryEditor.this.setFocus();
+        }
 
-          @Override
-          public void setActionBars(IActionBars actionBars)
-          {
-            super.setActionBars(actionBars);
-            getActionBarContributor().shareGlobalActions(this, actionBars);
-          }
-        };
-      propertySheetPage.setPropertySourceProvider(new AdapterFactoryContentProvider(adapterFactory));
-    }
+        @Override
+        public void setActionBars(IActionBars actionBars)
+        {
+          super.setActionBars(actionBars);
+          getActionBarContributor().shareGlobalActions(this, actionBars);
+        }
+      };
+    propertySheetPage.setPropertySourceProvider(new AdapterFactoryContentProvider(adapterFactory));
+    propertySheetPages.add(propertySheetPage);
 
     return propertySheetPage;
   }
@@ -1646,6 +1684,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
     //
     final Map<Object, Object> saveOptions = new HashMap<Object, Object>();
     saveOptions.put(Resource.OPTION_SAVE_ONLY_IF_CHANGED, Resource.OPTION_SAVE_ONLY_IF_CHANGED_MEMORY_BUFFER);
+    saveOptions.put(Resource.OPTION_LINE_DELIMITER, Resource.OPTION_LINE_DELIMITER_UNSPECIFIED);
 
     // Do the work within an operation because this is a long running activity that modifies the workbench.
     //
@@ -1660,8 +1699,10 @@ public class EXTLibraryEditor extends MultiPageEditorPart
           // Save the resources to the file system.
           //
           boolean first = true;
-          for (Resource resource : editingDomain.getResourceSet().getResources())
+          List<Resource> resources = editingDomain.getResourceSet().getResources();
+          for (int i = 0; i < resources.size(); ++i)
           {
+            Resource resource = resources.get(i);
             if ((first || !resource.getContents().isEmpty() || isPersisted(resource)) && !editingDomain.isReadOnly(resource))
             {
               try
@@ -1707,7 +1748,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
 
   /**
    * This returns whether something has been persisted to the URI of the specified resource.
-   * The implementation uses the URI converter from the editor's resource set to try to open an input stream. 
+   * The implementation uses the URI converter from the editor's resource set to try to open an input stream.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
@@ -1787,27 +1828,13 @@ public class EXTLibraryEditor extends MultiPageEditorPart
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public void gotoMarker(IMarker marker)
   {
-    try
+    List<?> targetObjects = markerHelper.getTargetObjects(editingDomain, marker);
+    if (!targetObjects.isEmpty())
     {
-      if (marker.getType().equals(EValidator.MARKER))
-      {
-        String uriAttribute = marker.getAttribute(EValidator.URI_ATTRIBUTE, null);
-        if (uriAttribute != null)
-        {
-          URI uri = URI.createURI(uriAttribute);
-          EObject eObject = editingDomain.getResourceSet().getEObject(uri, true);
-          if (eObject != null)
-          {
-            setSelectionToViewer(Collections.singleton(editingDomain.getWrapper(eObject)));
-          }
-        }
-      }
-    }
-    catch (CoreException exception)
-    {
-      EXTLibraryEditorPlugin.INSTANCE.log(exception);
+      setSelectionToViewer(targetObjects);
     }
   }
 
@@ -1852,6 +1879,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public void addSelectionChangedListener(ISelectionChangedListener listener)
   {
     selectionChangedListeners.add(listener);
@@ -1863,6 +1891,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public void removeSelectionChangedListener(ISelectionChangedListener listener)
   {
     selectionChangedListeners.remove(listener);
@@ -1874,6 +1903,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public ISelection getSelection()
   {
     return editorSelection;
@@ -1886,6 +1916,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public void setSelection(ISelection selection)
   {
     editorSelection = selection;
@@ -1967,6 +1998,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public void menuAboutToShow(IMenuManager menuManager)
   {
     ((IMenuListener)getEditorSite().getActionBarContributor()).menuAboutToShow(menuManager);
@@ -2023,7 +2055,7 @@ public class EXTLibraryEditor extends MultiPageEditorPart
       getActionBarContributor().setActiveEditor(null);
     }
 
-    if (propertySheetPage != null)
+    for (PropertySheetPage propertySheetPage : propertySheetPages)
     {
       propertySheetPage.dispose();
     }
