@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2002-2008 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  *
  * Contributors:
  *   IBM - Initial API and implementation
@@ -43,6 +43,7 @@ import org.eclipse.jface.action.MenuManager;
 import org.eclipse.jface.action.Separator;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.dialogs.ProgressMonitorDialog;
+import org.eclipse.jface.util.LocalSelectionTransfer;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.ISelectionProvider;
@@ -55,12 +56,14 @@ import org.eclipse.jface.viewers.Viewer;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.CTabFolder;
 import org.eclipse.swt.dnd.DND;
+import org.eclipse.swt.dnd.FileTransfer;
 import org.eclipse.swt.dnd.Transfer;
 import org.eclipse.swt.events.ControlAdapter;
 import org.eclipse.swt.events.ControlEvent;
 import org.eclipse.swt.events.MouseAdapter;
 import org.eclipse.swt.events.MouseEvent;
 import org.eclipse.swt.graphics.Point;
+import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Menu;
 import org.eclipse.swt.widgets.Tree;
@@ -88,6 +91,8 @@ import org.eclipse.emf.codegen.ecore.genmodel.GenModel;
 import org.eclipse.emf.codegen.ecore.genmodel.provider.GenModelEditPlugin;
 // import org.eclipse.emf.ecore.provider.EcoreItemProviderAdapterFactory;
 import org.eclipse.emf.codegen.ecore.genmodel.util.GenModelUtil;
+import org.eclipse.emf.common.command.AbstractCommand;
+import org.eclipse.emf.common.ui.viewer.ColumnViewerInformationControlToolTipSupport;
 import org.eclipse.emf.common.command.BasicCommandStack;
 import org.eclipse.emf.common.command.Command;
 import org.eclipse.emf.common.command.CommandStack;
@@ -100,14 +105,15 @@ import org.eclipse.emf.common.ui.viewer.IViewerProvider;
 import org.eclipse.emf.common.util.BasicDiagnostic;
 import org.eclipse.emf.common.util.Diagnostic;
 import org.eclipse.emf.common.util.DiagnosticChain;
+import org.eclipse.emf.common.util.EList;
 import org.eclipse.emf.common.util.URI;
 import org.eclipse.emf.ecore.EObject;
-import org.eclipse.emf.ecore.EValidator;
 import org.eclipse.emf.ecore.plugin.EcorePlugin;
 import org.eclipse.emf.ecore.resource.Resource;
 import org.eclipse.emf.ecore.resource.ResourceSet;
 import org.eclipse.emf.ecore.util.EContentAdapter;
 import org.eclipse.emf.ecore.util.EcoreUtil;
+import org.eclipse.emf.edit.command.ChangeCommand;
 import org.eclipse.emf.edit.domain.AdapterFactoryEditingDomain;
 import org.eclipse.emf.edit.domain.EditingDomain;
 import org.eclipse.emf.edit.domain.IEditingDomainProvider;
@@ -117,6 +123,11 @@ import org.eclipse.emf.edit.provider.ComposedAdapterFactory;
 // import org.eclipse.emf.edit.provider.resource.ResourceItemProviderAdapterFactory;
 import org.eclipse.emf.edit.ui.action.EditingDomainActionBarContributor;
 import org.eclipse.emf.edit.ui.action.ValidateAction;
+import org.eclipse.emf.edit.ui.provider.DecoratingColumLabelProvider;
+import org.eclipse.emf.edit.ui.provider.DiagnosticDecorator;
+import org.eclipse.emf.edit.ui.util.FindAndReplaceTarget;
+import org.eclipse.emf.edit.ui.util.IRevertablePart;
+import org.eclipse.jface.text.IFindReplaceTarget;
 import org.eclipse.emf.edit.ui.celleditor.AdapterFactoryTreeEditor;
 import org.eclipse.emf.edit.ui.dnd.EditingDomainViewerDropAdapter;
 import org.eclipse.emf.edit.ui.dnd.LocalTransfer;
@@ -138,7 +149,7 @@ import org.eclipse.emf.edit.ui.view.ExtendedPropertySheetPage;
  */
 public class GenModelEditor
   extends MultiPageEditorPart
-  implements IEditingDomainProvider, ISelectionProvider, IMenuListener, IViewerProvider, IGotoMarker
+  implements IEditingDomainProvider, ISelectionProvider, IMenuListener, IViewerProvider, IGotoMarker, IRevertablePart
 {
   /**
    * This keeps track of the editing domain that is used to track all changes to the model.
@@ -186,7 +197,7 @@ public class GenModelEditor
    * <!-- end-user-doc -->
    * @generated
    */
-  protected PropertySheetPage propertySheetPage;
+  protected List<PropertySheetPage> propertySheetPages = new ArrayList<PropertySheetPage>();
 
   /**
    * This is the viewer that shadows the selection in the content outline.
@@ -247,6 +258,7 @@ public class GenModelEditor
   protected IPartListener partListener =
     new IPartListener()
     {
+      @Override
       public void partActivated(IWorkbenchPart p)
       {
         if (p instanceof ContentOutline)
@@ -260,7 +272,7 @@ public class GenModelEditor
         }
         else if (p instanceof PropertySheet)
         {
-          if (((PropertySheet)p).getCurrentPage() == propertySheetPage)
+          if (propertySheetPages.contains(((PropertySheet)p).getCurrentPage()))
           {
             getActionBarContributor().setActiveEditor(GenModelEditor.this);
             handleActivate();
@@ -271,18 +283,22 @@ public class GenModelEditor
           handleActivate();
         }
       }
+      @Override
       public void partBroughtToTop(IWorkbenchPart p)
       {
         // Ignore.
       }
+      @Override
       public void partClosed(IWorkbenchPart p)
       {
         // Ignore.
       }
+      @Override
       public void partDeactivated(IWorkbenchPart p)
       {
         // Ignore.
       }
+      @Override
       public void partOpened(IWorkbenchPart p)
       {
         // Ignore.
@@ -338,6 +354,8 @@ public class GenModelEditor
   protected EContentAdapter problemIndicationAdapter = 
     new EContentAdapter()
     {
+      protected boolean dispatching;
+
       @Override
       public void notifyChanged(Notification notification)
       {
@@ -359,18 +377,7 @@ public class GenModelEditor
               {
                 resourceToDiagnosticMap.remove(resource);
               }
-
-              if (updateProblemIndication)
-              {
-                getSite().getShell().getDisplay().asyncExec
-                  (new Runnable()
-                   {
-                     public void run()
-                     {
-                       updateProblemIndication();
-                     }
-                   });
-              }
+              dispatchUpdateProblemIndication();
               break;
             }
           }
@@ -381,6 +388,24 @@ public class GenModelEditor
         }
       }
 
+      protected void dispatchUpdateProblemIndication()
+      {
+        if (updateProblemIndication && !dispatching)
+        {
+          dispatching = true;
+          getSite().getShell().getDisplay().asyncExec
+            (new Runnable()
+             {
+               @Override
+               public void run()
+               {
+                 dispatching = false;
+                 updateProblemIndication();
+               }
+             });
+        }
+      }
+
       @Override
       protected void setTarget(Resource target)
       {
@@ -391,6 +416,8 @@ public class GenModelEditor
       protected void unsetTarget(Resource target)
       {
         basicUnsetTarget(target);
+        resourceToDiagnosticMap.remove(target);
+        dispatchUpdateProblemIndication();
       }
     };
 
@@ -403,6 +430,7 @@ public class GenModelEditor
   protected IResourceChangeListener resourceChangeListener =
     new IResourceChangeListener()
     {
+      @Override
       public void resourceChanged(IResourceChangeEvent event)
       {
         IResourceDelta delta = event.getDelta();
@@ -414,26 +442,38 @@ public class GenModelEditor
             protected Collection<Resource> changedResources = new ArrayList<Resource>();
             protected Collection<Resource> removedResources = new ArrayList<Resource>();
 
-            public boolean visit(IResourceDelta delta)
+            @Override
+            public boolean visit(final IResourceDelta delta)
             {
               if (delta.getResource().getType() == IResource.FILE)
               {
                 if (delta.getKind() == IResourceDelta.REMOVED ||
-                    delta.getKind() == IResourceDelta.CHANGED && delta.getFlags() != IResourceDelta.MARKERS)
+                    delta.getKind() == IResourceDelta.CHANGED)
                 {
-                  Resource resource = resourceSet.getResource(URI.createPlatformResourceURI(delta.getFullPath().toString(), true), false);
+                  final Resource resource = resourceSet.getResource(URI.createPlatformResourceURI(delta.getFullPath().toString(), true), false);
                   if (resource != null)
                   {
                     if (delta.getKind() == IResourceDelta.REMOVED)
                     {
                       removedResources.add(resource);
                     }
-                    else if (!savedResources.remove(resource))
+                    else
                     {
-                      changedResources.add(resource);
+                      if ((delta.getFlags() & IResourceDelta.MARKERS) != 0)
+                      {
+                        DiagnosticDecorator.DiagnosticAdapter.update(resource, markerHelper.getMarkerDiagnostics(resource, (IFile)delta.getResource(), false));
+                      }
+                      if ((delta.getFlags() & IResourceDelta.CONTENT) != 0)
+                      {
+                        if (!savedResources.remove(resource))
+                        {
+                          changedResources.add(resource);
+                        }
+                      }
                     }
                   }
                 }
+                return false;
               }
 
               return true;
@@ -458,6 +498,7 @@ public class GenModelEditor
             getSite().getShell().getDisplay().asyncExec
               (new Runnable()
                {
+                 @Override
                  public void run()
                  {
                    removedResources.addAll(visitor.getRemovedResources());
@@ -474,6 +515,7 @@ public class GenModelEditor
             getSite().getShell().getDisplay().asyncExec
               (new Runnable()
                {
+                 @Override
                  public void run()
                  {
                    changedResources.addAll(visitor.getChangedResources());
@@ -580,15 +622,50 @@ public class GenModelEditor
       updateProblemIndication();
     }
   }
-  
+
   protected void initialize(GenModel genModel)
   {
     updateProblemIndication = false;
-    
-    genModel.reconcile();
+
+    // Reconcile the GenModel using a ChangeCommand.
+    class ReconcileCommand extends ChangeCommand
+    {
+      public ReconcileCommand(GenModel genModel)
+      {
+        super(genModel);
+        setLabel(GenModelEditPlugin.INSTANCE.getString("_UI_ReconcileCommand_name"));
+        setDescription(GenModelEditPlugin.INSTANCE.getString("_UI_ReconcileCommand_description"));
+      }
+
+      @Override
+      protected void doExecute()
+      {
+        ((GenModel)notifier).reconcile();
+      }
+      
+      public boolean hasChanges()
+      {
+        return changeDescription != null && !changeDescription.getObjectChanges().isEmpty();
+      }
+    }
+
+    ReconcileCommand reconcileCommand = new ReconcileCommand(genModel);
+    CommandStack commandStack = editingDomain.getCommandStack();
+    commandStack.execute(reconcileCommand);
+    // If the reconcile operation produced no changes, the command is a no-op so we can remove it from the command stack.
+    // This way the resource is only dirty if it's actually been reconciled in a way that changes the structure.
+    if (!reconcileCommand.hasChanges())
+    {
+      commandStack.undo();
+    }
+
     genModel.setCanGenerate(true);
     validate();
 
+    if (generator != null)
+    {
+      generator.dispose();
+    }
     generator = GenModelUtil.createGenerator(genModel);
     
     updateProblemIndication = true;
@@ -648,17 +725,13 @@ public class GenModelEditor
 
       if (markerHelper.hasMarkers(editingDomain.getResourceSet()))
       {
-        markerHelper.deleteMarkers(editingDomain.getResourceSet());
-        if (diagnostic.getSeverity() != Diagnostic.OK)
+        try
         {
-          try
-          {
-            markerHelper.createMarkers(diagnostic);
-          }
-          catch (CoreException exception)
-          {
-            GenModelEditPlugin.INSTANCE.log(exception);
-          }
+          markerHelper.updateMarkers(diagnostic);
+        }
+        catch (CoreException exception)
+        {
+          GenModelEditPlugin.INSTANCE.log(exception);
         }
       }
     }
@@ -699,11 +772,24 @@ public class GenModelEditor
    */
   protected void initializeEditingDomain()
   {
+    // Create an adapter factory that yields item providers.
+    //
     adapterFactory = new ComposedAdapterFactory(ComposedAdapterFactory.Descriptor.Registry.INSTANCE);
 
     // Create the command stack that will notify this editor as commands are executed.
     //
-    BasicCommandStack commandStack = new BasicCommandStack();
+    BasicCommandStack commandStack = new BasicCommandStack()
+    {
+      @Override
+      public void execute(Command command)
+      {
+        if (!(command instanceof AbstractCommand.NonDirtying))
+        {
+          DiagnosticDecorator.cancel(editingDomain);
+        }
+        super.execute(command);
+      }
+    };
 
     // Add a listener to set the most recent command's affected objects to be the selection of the viewer with focus.
     //
@@ -726,10 +812,17 @@ public class GenModelEditor
                   {
                     setSelectionToViewer(mostRecentCommand.getAffectedObjects());
                   }
-
-                  if (propertySheetPage != null && !propertySheetPage.getControl().isDisposed())
+                  for (Iterator<PropertySheetPage> i = propertySheetPages.iterator(); i.hasNext(); )
                   {
-                    propertySheetPage.refresh();
+                    PropertySheetPage propertySheetPage = i.next();
+                    if (propertySheetPage.getControl() == null || propertySheetPage.getControl().isDisposed())
+                    {
+                      i.remove();
+                    }
+                    else
+                    {
+                      propertySheetPage.refresh();
+                    }
                   }
                 }
               });
@@ -748,7 +841,7 @@ public class GenModelEditor
         }
       };
 
-    editingDomain.getResourceSet().getURIConverter().getURIMap().putAll(EcorePlugin.computePlatformURIMap());
+    editingDomain.getResourceSet().getURIConverter().getURIMap().putAll(EcorePlugin.computePlatformURIMap(true));
   }
 
   /**
@@ -757,10 +850,32 @@ public class GenModelEditor
    * <!-- end-user-doc -->
    * @generated
    */
+  protected void firePropertyChangeGen(int action)
+  {
+    super.firePropertyChange(action);
+  }
+
   @Override
   protected void firePropertyChange(int action)
   {
-    super.firePropertyChange(action);
+    firePropertyChangeGen(action);
+    if (action == IEditorPart.PROP_DIRTY)
+    {
+      EList<Resource> resources = editingDomain.getResourceSet().getResources();
+      if (!resources.isEmpty())
+      {
+        Resource mainResource = resources.get(0);
+        EList<EObject> contents = mainResource.getContents();
+        if (!contents.isEmpty())
+        {
+          EObject genModel = contents.get(0);
+          if (genModel instanceof GenModel)
+          {
+            ((GenModel)genModel).clearCache();
+          }
+        }
+      }
+    }
   }
 
   /**
@@ -779,6 +894,7 @@ public class GenModelEditor
       Runnable runnable =
         new Runnable()
         {
+          @Override
           public void run()
           {
             // Try to select the items in the current content viewer of the editor.
@@ -801,6 +917,7 @@ public class GenModelEditor
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public EditingDomain getEditingDomain()
   {
     return editingDomain;
@@ -893,6 +1010,7 @@ public class GenModelEditor
           {
             // This just notifies those things that are affected by the section.
             //
+            @Override
             public void selectionChanged(SelectionChangedEvent selectionChangedEvent)
             {
               setSelection(selectionChangedEvent.getSelection());
@@ -930,6 +1048,7 @@ public class GenModelEditor
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public Viewer getViewer()
   {
     return currentViewer;
@@ -952,7 +1071,7 @@ public class GenModelEditor
     getSite().registerContextMenu(contextMenu, new UnwrappingSelectionProvider(viewer));
 
     int dndOperations = DND.DROP_COPY | DND.DROP_MOVE | DND.DROP_LINK;
-    Transfer[] transfers = new Transfer[] { LocalTransfer.getInstance() };
+    Transfer[] transfers = new Transfer[] { LocalTransfer.getInstance(), LocalSelectionTransfer.getTransfer(), FileTransfer.getInstance() };
     viewer.addDragSupport(dndOperations, transfers, new ViewerDragAdapter(viewer));
     viewer.addDropSupport(dndOperations, transfers, new EditingDomainViewerDropAdapter(editingDomain, viewer));
   }
@@ -990,7 +1109,7 @@ public class GenModelEditor
    */
   public void createModel()
   {
-    URI resourceURI = EditUIUtil.getURI(getEditorInput());
+    URI resourceURI = EditUIUtil.getURI(getEditorInput(), editingDomain.getResourceSet().getURIConverter());
     Exception exception = null;
     Resource resource = null;
     try
@@ -1022,11 +1141,12 @@ public class GenModelEditor
    */
   public Diagnostic analyzeResourceProblems(Resource resource, Exception exception) 
   {
-    if (!resource.getErrors().isEmpty() || !resource.getWarnings().isEmpty())
+    boolean hasErrors = !resource.getErrors().isEmpty();
+    if (hasErrors || !resource.getWarnings().isEmpty())
     {
       BasicDiagnostic basicDiagnostic =
         new BasicDiagnostic
-          (Diagnostic.ERROR,
+          (hasErrors ? Diagnostic.ERROR : Diagnostic.WARNING,
            "org.eclipse.emf.codegen.ecore.ui",
            0,
            getString("_UI_CreateModelError_message", resource.getURI()),
@@ -1080,11 +1200,12 @@ public class GenModelEditor
         setCurrentViewer(selectionViewer);
   
         selectionViewer.setContentProvider(new AdapterFactoryContentProvider(adapterFactory));
-        selectionViewer.setLabelProvider(new AdapterFactoryLabelProvider(adapterFactory));
+        selectionViewer.setLabelProvider(new DecoratingColumLabelProvider(new AdapterFactoryLabelProvider(adapterFactory), new DiagnosticDecorator(editingDomain, selectionViewer, GenModelEditPlugin.getPlugin().getDialogSettings())));
         selectionViewer.setInput(resource);
         selectionViewer.setSelection(new StructuredSelection(genModel), true);
 
         new AdapterFactoryTreeEditor(selectionViewer.getTree(), adapterFactory);
+        new ColumnViewerInformationControlToolTipSupport(selectionViewer, new DiagnosticDecorator.EditingDomainLocationListener(editingDomain, selectionViewer));
   
         createContextMenuFor(selectionViewer);
         int pageIndex = addPage(tree);
@@ -1130,9 +1251,9 @@ public class GenModelEditor
       setPageText(0, "");
       if (getContainer() instanceof CTabFolder)
       {
-        ((CTabFolder)getContainer()).setTabHeight(1);
         Point point = getContainer().getSize();
-        getContainer().setSize(point.x, point.y + 6);
+        Rectangle clientArea = getContainer().getClientArea();
+        getContainer().setSize(point.x,  2 * point.y - clientArea.height - clientArea.y);
       }
     }
   }
@@ -1151,9 +1272,9 @@ public class GenModelEditor
       setPageText(0, getString("_UI_SelectionPage_label"));
       if (getContainer() instanceof CTabFolder)
       {
-        ((CTabFolder)getContainer()).setTabHeight(SWT.DEFAULT);
         Point point = getContainer().getSize();
-        getContainer().setSize(point.x, point.y - 6);
+        Rectangle clientArea = getContainer().getClientArea();
+        getContainer().setSize(point.x, clientArea.height + clientArea.y);
       }
     }
   }
@@ -1181,21 +1302,24 @@ public class GenModelEditor
    * <!-- end-user-doc -->
    * @generated
    */
-  @SuppressWarnings("rawtypes")
   @Override
-  public Object getAdapter(Class key)
+  public <T> T getAdapter(Class<T> key)
   {
     if (key.equals(IContentOutlinePage.class))
     {
-      return showOutlineView() ? getContentOutlinePage() : null;
+      return showOutlineView() ? key.cast(getContentOutlinePage()) : null;
     }
     else if (key.equals(IPropertySheetPage.class))
     {
-      return getPropertySheetPage();
+      return key.cast(getPropertySheetPage());
     }
     else if (key.equals(IGotoMarker.class))
     {
-      return this;
+      return key.cast(this);
+    }
+    else if (key.equals(IFindReplaceTarget.class)) 
+    {
+      return FindAndReplaceTarget.getAdapter(key, this, GenModelEditPlugin.getPlugin());
     }
     else
     {
@@ -1226,10 +1350,13 @@ public class GenModelEditor
 
           // Set up the tree viewer.
           //
+          contentOutlineViewer.setUseHashlookup(true);
           contentOutlineViewer.setContentProvider(new AdapterFactoryContentProvider(adapterFactory));
-          contentOutlineViewer.setLabelProvider(new AdapterFactoryLabelProvider(adapterFactory));
+          contentOutlineViewer.setLabelProvider(new DecoratingColumLabelProvider(new AdapterFactoryLabelProvider(adapterFactory), new DiagnosticDecorator(editingDomain, contentOutlineViewer, GenModelEditPlugin.getPlugin().getDialogSettings())));
           contentOutlineViewer.setInput(editingDomain.getResourceSet());
 
+          new ColumnViewerInformationControlToolTipSupport(contentOutlineViewer, new DiagnosticDecorator.EditingDomainLocationListener(editingDomain, contentOutlineViewer));
+
           // Make sure our popups work.
           //
           createContextMenuFor(contentOutlineViewer);
@@ -1266,6 +1393,7 @@ public class GenModelEditor
          {
            // This ensures that we handle selections correctly.
            //
+           @Override
            public void selectionChanged(SelectionChangedEvent event)
            {
              handleContentOutlineSelection(event.getSelection());
@@ -1284,27 +1412,25 @@ public class GenModelEditor
    */
   public IPropertySheetPage getPropertySheetPage()
   {
-    if (propertySheetPage == null)
-    {
-      propertySheetPage =
-        new ExtendedPropertySheetPage(editingDomain)
+    PropertySheetPage propertySheetPage =
+      new ExtendedPropertySheetPage(editingDomain, ExtendedPropertySheetPage.Decoration.LIVE, GenModelEditPlugin.getPlugin().getDialogSettings(), 0, true)
+      {
+        @Override
+        public void setSelectionToViewer(List<?> selection)
         {
-          @Override
-          public void setSelectionToViewer(List<?> selection)
-          {
-            GenModelEditor.this.setSelectionToViewer(selection);
-            GenModelEditor.this.setFocus();
-          }
+          GenModelEditor.this.setSelectionToViewer(selection);
+          GenModelEditor.this.setFocus();
+        }
 
-          @Override
-          public void setActionBars(IActionBars actionBars)
-          {
-            super.setActionBars(actionBars);
-            getActionBarContributor().shareGlobalActions(this, actionBars);
-          }
-        };
-      propertySheetPage.setPropertySourceProvider(new AdapterFactoryContentProvider(adapterFactory));
-    }
+        @Override
+        public void setActionBars(IActionBars actionBars)
+        {
+          super.setActionBars(actionBars);
+          getActionBarContributor().shareGlobalActions(this, actionBars);
+        }
+      };
+    propertySheetPage.setPropertySourceProvider(new AdapterFactoryContentProvider(adapterFactory));
+    propertySheetPages.add(propertySheetPage);
 
     return propertySheetPage;
   }
@@ -1352,6 +1478,76 @@ public class GenModelEditor
     return ((BasicCommandStack)editingDomain.getCommandStack()).isSaveNeeded();
   }
 
+  /**
+   * This is for implementing {@link IRevertablePart}.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public void doRevertGen()
+  {
+    DiagnosticDecorator.cancel(editingDomain);
+    
+    ResourceSet resourceSet = editingDomain.getResourceSet();
+    List<Resource> resources = resourceSet.getResources();
+    List<Resource> unloadedResources = new ArrayList<Resource>();
+    updateProblemIndication = false;
+    for (int i = 0; i < resources.size(); ++i)
+    {
+      Resource resource = resources.get(i);
+      if (resource.isLoaded())
+      {
+        resource.unload();
+        unloadedResources.add(resource);
+      }
+    }
+
+    resourceToDiagnosticMap.clear();
+    for (Resource resource : unloadedResources)
+    {
+      try
+      {
+        resource.load(resourceSet.getLoadOptions());
+      }
+      catch (IOException exception)
+      {
+        if (!resourceToDiagnosticMap.containsKey(resource))
+        {
+          resourceToDiagnosticMap.put(resource, analyzeResourceProblems(resource, exception));
+        }
+      }
+    }
+
+    editingDomain.getCommandStack().flush();
+
+    if (AdapterFactoryEditingDomain.isStale(editorSelection))
+    {
+      setSelection(StructuredSelection.EMPTY);
+    }
+
+    updateProblemIndication = true;
+    updateProblemIndication();
+  }
+
+  public void doRevert()
+  {
+    doRevertGen();
+    EList<Resource> resources = editingDomain.getResourceSet().getResources();
+    if (!resources.isEmpty())
+    {
+      Resource mainResource = resources.get(0);
+      EList<EObject> contents = mainResource.getContents();
+      if (!contents.isEmpty())
+      {
+        EObject genModel = contents.get(0);
+        if (genModel instanceof GenModel)
+        {
+          initialize((GenModel)genModel);
+        }
+      }
+    }
+  }
+
   /**
    * This is for implementing {@link IEditorPart} and simply saves the model file.
    * <!-- begin-user-doc -->
@@ -1365,6 +1561,7 @@ public class GenModelEditor
     //
     final Map<Object, Object> saveOptions = new HashMap<Object, Object>();
     saveOptions.put(Resource.OPTION_SAVE_ONLY_IF_CHANGED, Resource.OPTION_SAVE_ONLY_IF_CHANGED_MEMORY_BUFFER);
+    saveOptions.put(Resource.OPTION_LINE_DELIMITER, Resource.OPTION_LINE_DELIMITER_UNSPECIFIED);
 
     // Do the work within an operation because this is a long running activity that modifies the workbench.
     //
@@ -1379,8 +1576,10 @@ public class GenModelEditor
           // Save the resources to the file system.
           //
           boolean first = true;
-          for (Resource resource : editingDomain.getResourceSet().getResources())
+          List<Resource> resources = editingDomain.getResourceSet().getResources();
+          for (int i = 0; i < resources.size(); ++i)
           {
+            Resource resource = resources.get(i);
             if ((first || !resource.getContents().isEmpty() || isPersisted(resource)) && !editingDomain.isReadOnly(resource))
             {
               try
@@ -1426,7 +1625,7 @@ public class GenModelEditor
 
   /**
    * This returns whether something has been persisted to the URI of the specified resource.
-   * The implementation uses the URI converter from the editor's resource set to try to open an input stream. 
+   * The implementation uses the URI converter from the editor's resource set to try to open an input stream.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
@@ -1506,27 +1705,13 @@ public class GenModelEditor
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public void gotoMarker(IMarker marker)
   {
-    try
+    List<?> targetObjects = markerHelper.getTargetObjects(editingDomain, marker);
+    if (!targetObjects.isEmpty())
     {
-      if (marker.getType().equals(EValidator.MARKER))
-      {
-        String uriAttribute = marker.getAttribute(EValidator.URI_ATTRIBUTE, null);
-        if (uriAttribute != null)
-        {
-          URI uri = URI.createURI(uriAttribute);
-          EObject eObject = editingDomain.getResourceSet().getEObject(uri, true);
-          if (eObject != null)
-          {
-            setSelectionToViewer(Collections.singleton(editingDomain.getWrapper(eObject)));
-          }
-        }
-      }
-    }
-    catch (CoreException exception)
-    {
-      GenModelEditPlugin.INSTANCE.log(exception);
+      setSelectionToViewer(targetObjects);
     }
   }
 
@@ -1564,6 +1749,7 @@ public class GenModelEditor
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public void addSelectionChangedListener(ISelectionChangedListener listener)
   {
     selectionChangedListeners.add(listener);
@@ -1575,6 +1761,7 @@ public class GenModelEditor
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public void removeSelectionChangedListener(ISelectionChangedListener listener)
   {
     selectionChangedListeners.remove(listener);
@@ -1586,6 +1773,7 @@ public class GenModelEditor
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public ISelection getSelection()
   {
     return editorSelection;
@@ -1598,6 +1786,7 @@ public class GenModelEditor
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public void setSelection(ISelection selection)
   {
     editorSelection = selection;
@@ -1679,6 +1868,7 @@ public class GenModelEditor
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public void menuAboutToShow(IMenuManager menuManager)
   {
     ((IMenuListener)getEditorSite().getActionBarContributor()).menuAboutToShow(menuManager);
@@ -1735,7 +1925,7 @@ public class GenModelEditor
       getActionBarContributor().setActiveEditor(null);
     }
 
-    if (propertySheetPage != null)
+    for (PropertySheetPage propertySheetPage : propertySheetPages)
     {
       propertySheetPage.dispose();
     }
