@@ -8,11 +8,12 @@
 package org.eclipse.emf.codegen.ecore.xtext.ui;
 
 
-import org.apache.log4j.Logger;
 import org.eclipse.emf.codegen.ecore.xtext.GenModelRuntimeModule;
 import org.eclipse.ui.plugin.AbstractUIPlugin;
 import org.eclipse.xtext.ui.shared.SharedStateModule;
 import org.osgi.framework.BundleContext;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.google.inject.Guice;
 import com.google.inject.Injector;
@@ -25,7 +26,7 @@ import com.google.inject.util.Modules;
 public class Activator extends AbstractUIPlugin
 {
 
-  private static final Logger logger = Logger.getLogger(Activator.class);
+  private static final Logger logger = LoggerFactory.getLogger(Activator.class);
 
   // The plug-in ID
   public static final String PLUGIN_ID = "org.eclipse.emf.codegen.ecore.xtext.ui"; //$NON-NLS-1$
