@@ -418,6 +418,31 @@ public class Generator
               facadeHelper.setCompilerCompliance("20"); 
               break;
             }
+            case JDK210_LITERAL:
+            {
+              facadeHelper.setCompilerCompliance("21"); 
+              break;
+            }
+            case JDK220_LITERAL:
+            {
+              facadeHelper.setCompilerCompliance("22"); 
+              break;
+            }
+            case JDK230_LITERAL:
+            {
+              facadeHelper.setCompilerCompliance("23"); 
+              break;
+            }
+            case JDK240_LITERAL:
+            {
+              facadeHelper.setCompilerCompliance("24"); 
+              break;
+            }
+            case JDK250_LITERAL:
+            {
+              facadeHelper.setCompilerCompliance("25"); 
+              break;
+            }
           }
 
           if (genModel.isCodeFormatting())
