@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2002-2010 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  * 
  * Contributors: 
  *   IBM - Initial API and implementation
@@ -26,6 +26,7 @@ import org.eclipse.emf.ecore.EPackage;
  *
  * <p>
  * The following features are supported:
+ * </p>
  * <ul>
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getPrefix <em>Prefix</em>}</li>
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getBasePackage <em>Base Package</em>}</li>
@@ -56,8 +57,11 @@ import org.eclipse.emf.ecore.EPackage;
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getGenClasses <em>Gen Classes</em>}</li>
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getNestedGenPackages <em>Nested Gen Packages</em>}</li>
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getGenClassifiers <em>Gen Classifiers</em>}</li>
+ *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getPublicationLocation <em>Publication Location</em>}</li>
+ *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getDocumentation <em>Documentation</em>}</li>
+ *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getLoadInitializationFileExtension <em>Load Initialization File Extension</em>}</li>
+ *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#isFamilyTreeInitialization <em>Family Tree Initialization</em>}</li>
  * </ul>
- * </p>
  *
  * @see org.eclipse.emf.codegen.ecore.genmodel.GenModelPackage#getGenPackage()
  * @model
@@ -693,6 +697,111 @@ public interface GenPackage extends GenBase
    */
   EList<GenClassifier> getGenClassifiers();
 
+  /**
+   * Returns the value of the '<em><b>Publication Location</b></em>' attribute.
+   * <!-- begin-user-doc -->
+   * <p>
+   * @since 2.10
+   * </p>
+   * <!-- end-user-doc -->
+   * @return the value of the '<em>Publication Location</em>' attribute.
+   * @see #setPublicationLocation(String)
+   * @see org.eclipse.emf.codegen.ecore.genmodel.GenModelPackage#getGenPackage_PublicationLocation()
+   * @model
+   * @generated
+   */
+  String getPublicationLocation();
+
+  /**
+   * Sets the value of the '{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getPublicationLocation <em>Publication Location</em>}' attribute.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @param value the new value of the '<em>Publication Location</em>' attribute.
+   * @see #getPublicationLocation()
+   * @generated
+   */
+  void setPublicationLocation(String value);
+
+  /**
+   * Returns the value of the '<em><b>Documentation</b></em>' attribute.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * <!-- begin-model-doc -->
+   * @since 2.14
+   * <!-- end-model-doc -->
+   * @return the value of the '<em>Documentation</em>' attribute.
+   * @see #setDocumentation(String)
+   * @see org.eclipse.emf.codegen.ecore.genmodel.GenModelPackage#getGenPackage_Documentation()
+   * @model unsettable="true" suppressedIsSetVisibility="true" suppressedUnsetVisibility="true"
+   * @generated
+   */
+  String getDocumentation();
+
+  /**
+   * Sets the value of the '{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getDocumentation <em>Documentation</em>}' attribute.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @param value the new value of the '<em>Documentation</em>' attribute.
+   * @see #getDocumentation()
+   * @since 2.14
+   * @generated
+   */
+  void setDocumentation(String value);
+
+  /**
+   * Returns the value of the '<em><b>Load Initialization File Extension</b></em>' attribute.
+   * The default value is <code>"ecore"</code>.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * <!-- begin-model-doc -->
+   * @since 2.15
+   * <!-- end-model-doc -->
+   * @return the value of the '<em>Load Initialization File Extension</em>' attribute.
+   * @see #setLoadInitializationFileExtension(String)
+   * @see org.eclipse.emf.codegen.ecore.genmodel.GenModelPackage#getGenPackage_LoadInitializationFileExtension()
+   * @model default="ecore"
+   * @generated
+   */
+  String getLoadInitializationFileExtension();
+
+  /**
+   * Sets the value of the '{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getLoadInitializationFileExtension <em>Load Initialization File Extension</em>}' attribute.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @param value the new value of the '<em>Load Initialization File Extension</em>' attribute.
+   * @see #getLoadInitializationFileExtension()
+   * @since 2.15
+   * @generated
+   */
+  void setLoadInitializationFileExtension(String value);
+
+  /**
+   * Returns the value of the '<em><b>Family Tree Initialization</b></em>' attribute.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * <!-- begin-model-doc -->
+   * Whether this package's implementation class should directly initialize its entirely family containment tree.
+   * @since 2.31
+   * <!-- end-model-doc -->
+   * @return the value of the '<em>Family Tree Initialization</em>' attribute.
+   * @see #setFamilyTreeInitialization(boolean)
+   * @see org.eclipse.emf.codegen.ecore.genmodel.GenModelPackage#getGenPackage_FamilyTreeInitialization()
+   * @model
+   * @generated
+   */
+  boolean isFamilyTreeInitialization();
+
+  /**
+   * Sets the value of the '{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#isFamilyTreeInitialization <em>Family Tree Initialization</em>}' attribute.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @param value the new value of the '<em>Family Tree Initialization</em>' attribute.
+   * @see #isFamilyTreeInitialization()
+   * @since 2.31
+   * @generated
+   */
+  void setFamilyTreeInitialization(boolean value);
+
   String getInterfacePackageName();
   String getReflectionPackageName();
   String getReflectionClassPackageName();
@@ -807,6 +916,11 @@ public interface GenPackage extends GenBase
   List<GenPackage> getPackageInitializationDependencies();
   String getPackageInstanceVariable(GenPackage genPackage);
 
+  /**
+   * @since 2.31
+   */
+  List<GenPackage> getPackageFamilyTreeDependencies();
+
   /**
    * Returns a list of those nestedGenPackages for which hasClassifiers() is
    * true.
@@ -965,6 +1079,11 @@ public interface GenPackage extends GenBase
   
   boolean hasTests();
 
+  /**
+   * @since 2.10
+   */
+  String getSchemaLocation();
+
   /**
    * Returns a nested map structure describing the child creation extensions that this package provides to other packages.
    * The result maps other packages to their classes that have child creation extension provided by this package.
@@ -1022,5 +1141,11 @@ public interface GenPackage extends GenBase
    * @see #getFileExtensions
    * @since 2.4
    */
-  String getFileExtension(); // getFirstFileExtension?
+  String getFileExtension();
+
+  /**
+   * Returns a list of the comma-separated contents of {@link #getFileExtensions()}.
+   * @since 2.10
+   */
+  List<String> getFileExtensionList();
 }
