@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2006 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  * 
  * Contributors: 
  *   IBM - Initial API and implementation
@@ -19,7 +19,7 @@ import org.eclipse.emf.codegen.merge.java.facade.JCompilationUnit;
 /**
  * @since 2.2.0
  */
-@SuppressWarnings({"deprecation", "unchecked"})
+@SuppressWarnings("deprecation")
 public class JDOMJCompilationUnit extends JDOMJNode implements JCompilationUnit
 {
   protected String originalContent;
