@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2005-2009 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  * 
  * Contributors: 
  *   IBM - Initial API and implementation
@@ -18,13 +18,13 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.SortedSet;
 import java.util.TreeSet;
+import java.util.concurrent.atomic.AtomicReference;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
 import org.eclipse.core.runtime.NullProgressMonitor;
 
 import org.eclipse.emf.common.EMFPlugin;
-import org.eclipse.jdt.core.dom.AST;
 import org.eclipse.jdt.core.dom.ASTParser;
 import org.eclipse.jdt.core.dom.CompilationUnit;
 import org.eclipse.jdt.core.dom.ImportDeclaration;
@@ -210,7 +210,7 @@ public class ImportManager
 
     for (int i = 0; i < srcLength; i++)
     {
-      if (Character.isWhitespace(src[i]))
+      if (src[i] <= ' ')
       {
         if (result == null)
         {
@@ -324,6 +324,8 @@ public class ImportManager
         case '<':
         case '>':
         case '&':
+        case '[':
+        case ']':
         {
           if (start != i)
           {
@@ -355,6 +357,7 @@ public class ImportManager
             result.append(c);
           }
           start = i + 1;
+          break;
         }
         default:
         {
@@ -376,7 +379,6 @@ public class ImportManager
    * In fact, a parameterized type expression is also allowed, in which case the expression will be parsed to obtain the
    * individual imported names within it. Then the full expression, with the appropriate substitutions, is returned.
    * @param qualifiedName the qualified name or parameterized type expression.
-   * @param autoImport whether to try to automatically import types as needed.
    * @return the equivalent type or type expression, using short names wherever possible.
    */
   public String getImportedName(String qualifiedName)
@@ -392,6 +394,14 @@ public class ImportManager
     int i = qualifiedName.lastIndexOf('.');
     if (i == -1)
     {
+      if ("this".equals(qualifiedName) || "super".equals(qualifiedName))
+      {
+        String qualifiedThisOrSuper = shortNameToImportMap.get(qualifiedName);
+        if (qualifiedThisOrSuper!= null)
+        {
+          return qualifiedThisOrSuper;
+        }
+      }
       return qualifiedName;
     }
 
@@ -532,7 +542,11 @@ public class ImportManager
     }
     else
     {
-      shortNameToImportMap.put(shortName, importName);
+      String oldImportName = shortNameToImportMap.put(shortName, importName);
+      if (oldImportName != null)
+      {
+        imports.remove(oldImportName);
+      }
     }
   }
 
@@ -549,6 +563,8 @@ public class ImportManager
     packageName = normalize(packageName);
     shortName = normalize(shortName);
     shortNameToImportMap.put(shortName, new StringBuilder(packageName).append('.').append(shortName).toString());
+    shortNameToImportMap.put("this", shortName + ".this");
+    shortNameToImportMap.put("super", shortName + ".super");
   }
 
   /**
@@ -616,7 +632,7 @@ public class ImportManager
   {
     String NL = getLineDelimiter();
     String previousPackageName = null;
-    StringBuffer result = new StringBuffer();
+    StringBuilder  result = new StringBuilder();
 
     for (String importName : getImports())
     {
@@ -672,10 +688,16 @@ public class ImportManager
    */
   private static class EclipseHelper
   {
+    private static final AtomicReference<ASTParser> cachedASTParser = new AtomicReference<ASTParser>(null);
+
     public static List<String> getCompilationUnitImports(String compilationUnitContents)
     {
       List<String> result = new ArrayList<String>();
-      ASTParser parser = ASTParser.newParser(AST.JLS3);
+      ASTParser parser = cachedASTParser.getAndSet(null);
+      if (parser == null)
+      {
+        parser = CodeGenUtil.EclipseUtil.newASTParser(true);
+      }
       parser.setSource(compilationUnitContents.toCharArray());
       CompilationUnit compilationUnit = (CompilationUnit)parser.createAST(new NullProgressMonitor());
       for (Iterator<?> i = compilationUnit.imports().iterator(); i.hasNext();)
@@ -683,10 +705,12 @@ public class ImportManager
         ImportDeclaration importDeclaration = (ImportDeclaration)i.next();
         result.add(importDeclaration.getName().getFullyQualifiedName());
       }
+      cachedASTParser.set(parser);
       return result;
     }
   }
 
+
   /**
    * Records the given <code>StringBuilder</code> and its current length, so that computed imports can later be
    * {@link #emitSortedImports() emitted}, and {@link #addCompilationUnitImports(String) adds} any import declarations
