@@ -1,9 +1,9 @@
 /**
- * Copyright (c) 2002-2007 IBM Corporation and others.
+ * Copyright (c) 2002-2012 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  *
  * Contributors:
  *   IBM - Initial API and implementation
@@ -15,6 +15,8 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.LinkedHashSet;
 import java.util.List;
@@ -50,8 +52,10 @@ import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
+import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.ui.IEditorPart;
+import org.eclipse.ui.IWorkbenchPart;
 import org.eclipse.ui.PartInitException;
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.dialogs.ElementListSelectionDialog;
@@ -64,6 +68,7 @@ import org.eclipse.emf.common.util.Diagnostic;
 import org.eclipse.emf.common.util.EList;
 import org.eclipse.emf.common.util.TreeIterator;
 import org.eclipse.emf.common.util.URI;
+import org.eclipse.emf.ecore.EAnnotation;
 import org.eclipse.emf.ecore.EGenericType;
 import org.eclipse.emf.ecore.EObject;
 import org.eclipse.emf.ecore.EPackage;
@@ -72,6 +77,7 @@ import org.eclipse.emf.ecore.EcorePackage;
 import org.eclipse.emf.ecore.EPackage.Registry;
 import org.eclipse.emf.ecore.plugin.EcorePlugin;
 import org.eclipse.emf.ecore.provider.EcoreEditPlugin;
+import org.eclipse.emf.ecore.provider.EcoreItemProviderAdapterFactory;
 import org.eclipse.emf.ecore.resource.Resource;
 import org.eclipse.emf.ecore.resource.ResourceSet;
 import org.eclipse.emf.ecore.resource.impl.ResourceSetImpl;
@@ -79,12 +85,17 @@ import org.eclipse.emf.ecore.util.EcoreUtil;
 import org.eclipse.emf.edit.command.CommandParameter;
 import org.eclipse.emf.edit.domain.EditingDomain;
 import org.eclipse.emf.edit.domain.IEditingDomainProvider;
+import org.eclipse.emf.edit.ui.action.CollapseAllAction;
 import org.eclipse.emf.edit.ui.action.ControlAction;
 import org.eclipse.emf.edit.ui.action.CreateChildAction;
 import org.eclipse.emf.edit.ui.action.CreateSiblingAction;
 import org.eclipse.emf.edit.ui.action.EditingDomainActionBarContributor;
+import org.eclipse.emf.edit.ui.action.ExpandAllAction;
+import org.eclipse.emf.edit.ui.action.FindAction;
 import org.eclipse.emf.edit.ui.action.LoadResourceAction;
+import org.eclipse.emf.edit.ui.action.RevertAction;
 import org.eclipse.emf.edit.ui.action.ValidateAction;
+import org.eclipse.emf.edit.ui.provider.DiagnosticDecorator;
 import org.eclipse.emf.edit.ui.provider.ExtendedImageRegistry;
 
 
@@ -111,7 +122,7 @@ public class EcoreActionBarContributor
       return new MenuManager(EcoreEditorPlugin.getPlugin().getString("_UI_ReflectiveEditor_menu"), "org.eclipse.emf.ecoreMenuID");
     }
   }
-  
+
   public static class ExtendedLoadResourceAction extends LoadResourceAction
   {
     @Override
@@ -121,19 +132,19 @@ public class EcoreActionBarContributor
       ExtendedLoadResourceDialog loadResourceDialog =
         new ExtendedLoadResourceDialog
           (shell, domain);
-    
+
       if (loadResourceDialog.open() == Window.OK && !loadResourceDialog.getRegisteredPackages().isEmpty())
       {
         String source = EcoreEditorPlugin.INSTANCE.getSymbolicName();
-        BasicDiagnostic diagnosic = 
+        BasicDiagnostic diagnosic =
           new BasicDiagnostic(Diagnostic.INFO, source, 0, EcoreEditorPlugin.INSTANCE.getString("_UI_RuntimePackageDetail_message"), null);
         for (EPackage ePackage : loadResourceDialog.getRegisteredPackages())
         {
           diagnosic.add(new BasicDiagnostic(Diagnostic.INFO, source, 0, ePackage.getNsURI(), null));
         }
         new DiagnosticDialog
-         (shell, 
-          EcoreEditorPlugin.INSTANCE.getString("_UI_Information_title"), 
+         (shell,
+          EcoreEditorPlugin.INSTANCE.getString("_UI_Information_title"),
           EcoreEditorPlugin.INSTANCE.getString("_UI_RuntimePackageHeader_message"),
           diagnosic,
           Diagnostic.INFO).open();
@@ -148,7 +159,7 @@ public class EcoreActionBarContributor
       {
         super(parent, domain);
       }
-      
+
       @Override
       protected boolean processResource(Resource resource)
       {
@@ -175,17 +186,17 @@ public class EcoreActionBarContributor
       protected Collection<EPackage> getAllPackages(Resource resource)
       {
         List<EPackage> result = new ArrayList<EPackage>();
-        for (TreeIterator<?> j = 
+        for (TreeIterator<?> j =
                new EcoreUtil.ContentTreeIterator<Object>(resource.getContents())
                {
                  private static final long serialVersionUID = 1L;
-  
+
                  @Override
                  protected Iterator<? extends EObject> getEObjectChildren(EObject eObject)
                  {
-                   return 
-                     eObject instanceof EPackage ? 
-                       ((EPackage)eObject).getESubpackages().iterator() : 
+                   return
+                     eObject instanceof EPackage ?
+                       ((EPackage)eObject).getESubpackages().iterator() :
                          Collections.<EObject>emptyList().iterator();
                  }
                };
@@ -205,19 +216,84 @@ public class EcoreActionBarContributor
       {
         Composite composite = (Composite)super.createDialogArea(parent);
         Composite buttonComposite = (Composite)composite.getChildren()[0];
+
         Button browseRegisteredPackagesButton = new Button(buttonComposite, SWT.PUSH);
         browseRegisteredPackagesButton.setText(EcoreEditorPlugin.INSTANCE.getString("_UI_BrowseRegisteredPackages_label"));
         prepareBrowseRegisteredPackagesButton(browseRegisteredPackagesButton);
         {
           FormData data = new FormData();
           Control [] children = buttonComposite.getChildren();
-          data.left = new FormAttachment(0, 0);
           data.right = new FormAttachment(children[0], -CONTROL_OFFSET);
           browseRegisteredPackagesButton.setLayoutData(data);
         }
+
+        Button browseTargetPlatformPackagesButton = new Button(buttonComposite, SWT.PUSH);
+        browseTargetPlatformPackagesButton.setText(EcoreEditorPlugin.INSTANCE.getString("_UI_BrowseTargetPlatformPackages_label"));
+        prepareBrowseTargetPlatformPackagesButton(browseTargetPlatformPackagesButton);
+        {
+          FormData data = new FormData();
+          data.right = new FormAttachment(browseRegisteredPackagesButton, -CONTROL_OFFSET);
+          browseTargetPlatformPackagesButton.setLayoutData(data);
+        }
+
         return composite;
       }
 
+      /**
+       * @since 2.9
+       */
+      protected void prepareBrowseTargetPlatformPackagesButton(Button browseTargetPlatformPackagesButton)
+      {
+        browseTargetPlatformPackagesButton.addSelectionListener
+          (new SelectionAdapter()
+           {
+             @Override
+             public void widgetSelected(SelectionEvent event)
+             {
+               TargetPlatformPackageDialog classpathPackageDialog = new TargetPlatformPackageDialog(getShell());
+               classpathPackageDialog.open();
+               Object [] result = classpathPackageDialog.getResult();
+               if (result != null)
+               {
+                 List<?> nsURIs = Arrays.asList(result);
+                 ResourceSet resourceSet = new ResourceSetImpl();
+                 resourceSet.getURIConverter().getURIMap().putAll(EcorePlugin.computePlatformURIMap(true));
+
+                 // To support Xcore resources, we need a resource with a URI that helps determine the containing project
+                 //
+                 Resource dummyResource = domain == null ? null : resourceSet.createResource(domain.getResourceSet().getResources().get(0).getURI());
+
+                 StringBuffer uris = new StringBuffer();
+                 Map<String, URI> ePackageNsURItoModelLocationMap = new HashMap<String, URI>(EcorePlugin.getEPackageNsURIToGenModelLocationMap(true));
+                 ePackageNsURItoModelLocationMap.putAll(EcorePlugin.getEPackageNsURIToDynamicModelLocationMap(true));
+                 for (int i = 0, length = result.length; i < length; i++)
+                 {
+                   URI location = ePackageNsURItoModelLocationMap.get(result[i]);
+                   Resource resource = resourceSet.getResource(location, true);
+                   EcoreUtil.resolveAll(resource);
+                 }
+
+                 EList<Resource> resources = resourceSet.getResources();
+                 resources.remove(dummyResource);
+
+                 for (Resource resource : resources)
+                 {
+                   for (EPackage ePackage : getAllPackages(resource))
+                   {
+                     if (nsURIs.contains(ePackage.getNsURI()))
+                     {
+                       uris.append(resource.getURI());
+                       uris.append("  ");
+                       break;
+                     }
+                   }
+                 }
+                 uriField.setText((uriField.getText() + "  " + uris.toString()).trim());
+               }
+             }
+           });
+      }
+
       protected void prepareBrowseRegisteredPackagesButton(Button browseRegisteredPackagesButton)
       {
         browseRegisteredPackagesButton.addSelectionListener
@@ -235,17 +311,18 @@ public class EcoreActionBarContributor
                  if (registeredPackageDialog.isDevelopmentTimeVersion())
                  {
                    ResourceSet resourceSet = new ResourceSetImpl();
-                   resourceSet.getURIConverter().getURIMap().putAll(EcorePlugin.computePlatformURIMap());
+                   resourceSet.getURIConverter().getURIMap().putAll(EcorePlugin.computePlatformURIMap(false));
 
                    // To support Xcore resources, we need a resource with a URI that helps determine the containing project
                    //
-                   Resource dummyResource = resourceSet.createResource(domain.getResourceSet().getResources().get(0).getURI());
+                   Resource dummyResource = domain == null ? null : resourceSet.createResource(domain.getResourceSet().getResources().get(0).getURI());
 
                    StringBuffer uris = new StringBuffer();
-                   Map<String, URI> ePackageNsURItoGenModelLocationMap = EcorePlugin.getEPackageNsURIToGenModelLocationMap();
+                   Map<String, URI> ePackageNsURItoModelLocationMap = new HashMap<String, URI>(EcorePlugin.getEPackageNsURIToGenModelLocationMap(false));
+                   ePackageNsURItoModelLocationMap.putAll(EcorePlugin.getEPackageNsURIToDynamicModelLocationMap(false));
                    for (int i = 0, length = result.length; i < length; i++)
                    {
-                     URI location = ePackageNsURItoGenModelLocationMap.get(result[i]);
+                     URI location = ePackageNsURItoModelLocationMap.get(result[i]);
                      Resource resource = resourceSet.getResource(location, true);
                      EcoreUtil.resolveAll(resource);
                    }
@@ -279,18 +356,19 @@ public class EcoreActionBarContributor
                  }
                }
              }
-           });      
+           });
       }
     }
-    
-    public static class RegisteredPackageDialog extends ElementListSelectionDialog
-    {
-      protected boolean isDevelopmentTimeVersion = true;
 
-      public RegisteredPackageDialog(Shell parent)
+    /**
+     * @since 2.9
+     */
+    public static class TargetPlatformPackageDialog extends ElementListSelectionDialog
+    {
+      public TargetPlatformPackageDialog(Shell parent)
       {
         super
-          (parent, 
+          (parent,
            new LabelProvider()
            {
              @Override
@@ -299,24 +377,66 @@ public class EcoreActionBarContributor
                return ExtendedImageRegistry.getInstance().getImage(EcoreEditPlugin.INSTANCE.getImage("full/obj16/EPackage"));
              }
            });
-        
+
         setMultipleSelection(true);
         setMessage(EcoreEditorPlugin.INSTANCE.getString("_UI_SelectRegisteredPackageURI"));
         setFilter("*");
         setTitle(EcoreEditorPlugin.INSTANCE.getString("_UI_PackageSelection_label"));
       }
-      
+
+      protected void updateElements()
+      {
+        Map<String, URI> ePackageNsURItoModelLocationMap = new HashMap<String, URI>(EcorePlugin.getEPackageNsURIToGenModelLocationMap(true));
+        ePackageNsURItoModelLocationMap.putAll(EcorePlugin.getEPackageNsURIToDynamicModelLocationMap(true));
+        Object [] result = ePackageNsURItoModelLocationMap.keySet().toArray(new Object[ePackageNsURItoModelLocationMap.size()]);
+        Arrays.sort(result);
+        setListElements(result);
+      }
+
+      @Override
+      protected Control createDialogArea(Composite parent)
+      {
+        Composite result = (Composite)super.createDialogArea(parent);
+        updateElements();
+        return result;
+      }
+    }
+
+    public static class RegisteredPackageDialog extends ElementListSelectionDialog
+    {
+      protected boolean isDevelopmentTimeVersion = true;
+
+      public RegisteredPackageDialog(Shell parent)
+      {
+        super
+          (parent,
+           new LabelProvider()
+           {
+             @Override
+            public Image getImage(Object element)
+             {
+               return ExtendedImageRegistry.getInstance().getImage(EcoreEditPlugin.INSTANCE.getImage("full/obj16/EPackage"));
+             }
+           });
+
+        setMultipleSelection(true);
+        setMessage(EcoreEditorPlugin.INSTANCE.getString("_UI_SelectRegisteredPackageURI"));
+        setFilter("*");
+        setTitle(EcoreEditorPlugin.INSTANCE.getString("_UI_PackageSelection_label"));
+      }
+
       public boolean isDevelopmentTimeVersion()
       {
         return isDevelopmentTimeVersion;
       }
-      
+
       protected void updateElements()
       {
         if (isDevelopmentTimeVersion)
         {
-          Map<String, URI> ePackageNsURItoGenModelLocationMap = EcorePlugin.getEPackageNsURIToGenModelLocationMap();
-          Object [] result = ePackageNsURItoGenModelLocationMap.keySet().toArray(new Object[ePackageNsURItoGenModelLocationMap.size()]);
+          Map<String, URI> ePackageNsURItoModelLocationMap = new HashMap<String, URI>(EcorePlugin.getEPackageNsURIToGenModelLocationMap(false));
+          ePackageNsURItoModelLocationMap.putAll(EcorePlugin.getEPackageNsURIToDynamicModelLocationMap(false));
+          Object [] result = ePackageNsURItoModelLocationMap.keySet().toArray(new Object[ePackageNsURItoModelLocationMap.size()]);
           Arrays.sort(result);
           setListElements(result);
         }
@@ -338,7 +458,7 @@ public class EcoreActionBarContributor
         buttonGroup.setLayout(layout);
         final Button developmentTimeVersionButton = new Button(buttonGroup, SWT.RADIO);
         developmentTimeVersionButton.addSelectionListener
-          (new SelectionAdapter() 
+          (new SelectionAdapter()
            {
              @Override
              public void widgetSelected(SelectionEvent event)
@@ -463,29 +583,51 @@ public class EcoreActionBarContributor
   protected IMenuManager createSiblingMenuManager;
 
   protected SelectionChangedEvent lastSelectionChangedEvent;
-  
-  protected ViewerFilterAction showGenericsAction = 
+
+  protected ViewerFilterAction showGenericsAction =
     new ViewerFilterAction(EcoreEditorPlugin.INSTANCE.getString("_UI_ShowGenerics_menu_item"), IAction.AS_CHECK_BOX)
     {
       @Override
-      protected void refreshViewers()
+      public void addViewer(Viewer viewer)
       {
-        super.refreshViewers();
-        if (lastSelectionChangedEvent != null && activeEditorPart instanceof EcoreEditor)
+        EcoreItemProviderAdapterFactory ecoreItemProviderAdapterFactory = ((EcoreEditor)activeEditorPart).ecoreItemProviderAdapterFactory;
+        if (viewers == null || !viewers.contains(viewer))
         {
-          selectionChanged(lastSelectionChangedEvent); 
+          ecoreItemProviderAdapterFactory.setShowGenerics(isChecked());
+          super.addViewer(viewer);
+        }
+        else if (ecoreItemProviderAdapterFactory.isShowGenerics() != isChecked())
+        {
+          ecoreItemProviderAdapterFactory.setShowGenerics(isChecked());
+          viewer.refresh();
+        }
+
+        if (lastSelectionChangedEvent != null)
+        {
+          selectionChanged(lastSelectionChangedEvent);
         }
       }
-      
+
+      @Override
+      public void setChecked(boolean checked)
+      {
+        if (activeEditorPart instanceof EcoreEditor)
+        {
+          EcoreItemProviderAdapterFactory ecoreItemProviderAdapterFactory = ((EcoreEditor)activeEditorPart).ecoreItemProviderAdapterFactory;
+          ecoreItemProviderAdapterFactory.setShowGenerics(checked);
+        }
+        super.setChecked(checked);
+      }
+
       @Override
       public boolean select(Viewer viewer, Object parentElement, Object element)
       {
         return isChecked() ||
-         !(element instanceof ETypeParameter || 
+         !(element instanceof ETypeParameter ||
            element instanceof EGenericType);
-      }    
+      }
     };
-  
+
   /**
    * This creates an instance of the contributor.
    * <!-- begin-user-doc -->
@@ -496,13 +638,18 @@ public class EcoreActionBarContributor
   {
     super(ADDITIONS_LAST_STYLE);
     loadResourceAction = new ExtendedLoadResourceAction();
+    liveValidationAction = new DiagnosticDecorator.LiveValidator.LiveValidationAction(EcoreEditorPlugin.getPlugin().getDialogSettings());
     validateAction = new ValidateAction();
     controlAction = new ControlAction();
-    
+    findAction = FindAction.create();
+    revertAction = new RevertAction();
+    expandAllAction = new ExpandAllAction();
+    collapseAllAction = new CollapseAllAction();
+
     showGenericsAction.setChecked
-      (Boolean.parseBoolean(EcoreEditorPlugin.getPlugin().getDialogSettings().get("showGenericsAction")));    
+      (Boolean.parseBoolean(EcoreEditorPlugin.getPlugin().getDialogSettings().get("showGenericsAction")));
   }
-  
+
   public void showGenerics(boolean isChecked)
   {
     if (showGenericsAction != null)
@@ -516,7 +663,7 @@ public class EcoreActionBarContributor
   {
     EcoreEditorPlugin.getPlugin().getDialogSettings().put(
       "showGenericsAction", Boolean.toString(showGenericsAction.isChecked()));
-    
+
     super.dispose();
   }
 
@@ -529,6 +676,7 @@ public class EcoreActionBarContributor
   @Override
   public void contributeToToolBar(IToolBarManager toolBarManager)
   {
+    super.contributeToToolBar(toolBarManager);
     toolBarManager.add(new Separator("ecore-settings"));
     toolBarManager.add(new Separator("ecore-additions"));
   }
@@ -562,7 +710,7 @@ public class EcoreActionBarContributor
     //
     createSiblingMenuManager = new MenuManager(EcoreEditorPlugin.getPlugin().getString("_UI_CreateSibling_menu_item"));
     submenuManager.insertBefore("additions", createSiblingMenuManager);
-    
+
     // Force an update because Eclipse hides empty menus now.
     //
     submenuManager.addMenuListener
@@ -617,12 +765,12 @@ public class EcoreActionBarContributor
       }
     }
   }
-  
+
   @Override
   public void setActiveEditor(IEditorPart part)
   {
     setActiveEditorGen(part);
-    
+
     if (part instanceof EcoreEditor)
     {
       showGenericsAction.addViewer(((EcoreEditor)part).getViewer());
@@ -631,7 +779,7 @@ public class EcoreActionBarContributor
     else
     {
       showGenericsAction.setEnabled(false);
-    }    
+    }
   }
 
   /**
@@ -687,7 +835,7 @@ public class EcoreActionBarContributor
       createSiblingMenuManager.update(true);
     }
   }
-  
+
   public void selectionChanged(SelectionChangedEvent event)
   {
     lastSelectionChangedEvent = event;
@@ -716,7 +864,7 @@ public class EcoreActionBarContributor
             continue;
           }
         }
-        actions.add(new CreateChildAction(activeEditorPart, selection, descriptor));
+        actions.add(new EcoreCreateChildAction(activeEditorPart, selection, descriptor));
       }
     }
     return actions;
@@ -744,7 +892,7 @@ public class EcoreActionBarContributor
             continue;
           }
         }
-        actions.add(new CreateSiblingAction(activeEditorPart, selection, descriptor));
+        actions.add(new EcoreCreateSiblingAction(activeEditorPart, selection, descriptor));
       }
     }
     return actions;
@@ -754,7 +902,7 @@ public class EcoreActionBarContributor
   {
     return feature == EcorePackage.Literals.ECLASS__EGENERIC_SUPER_TYPES ||
       feature == EcorePackage.Literals.ECLASSIFIER__ETYPE_PARAMETERS ||
-      feature == EcorePackage.Literals.EOPERATION__EGENERIC_EXCEPTIONS || 
+      feature == EcorePackage.Literals.EOPERATION__EGENERIC_EXCEPTIONS ||
       feature == EcorePackage.Literals.EOPERATION__ETYPE_PARAMETERS ||
       feature == EcorePackage.Literals.ETYPED_ELEMENT__EGENERIC_TYPE;
   }
@@ -766,26 +914,87 @@ public class EcoreActionBarContributor
    * If <code>contributionID</code> is <code>null</code>, they are simply added.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
-   * @generated
+   * @generated NOT
    */
   protected void populateManager(IContributionManager manager, Collection<? extends IAction> actions, String contributionID)
   {
     if (actions != null)
     {
+      // Look for actions that create EAnnotations.
+      //
+      Set<IAction> ignoredActions = new HashSet<IAction>();
+      Set<IAction> annotationActions = new LinkedHashSet<IAction>();
       for (IAction action : actions)
       {
+        if (action instanceof EObjectProvider)
+        {
+          EObjectProvider eObjectProvider = (EObjectProvider)action;
+          EObject eObject = eObjectProvider.getEObject();
+          if (eObject instanceof EAnnotation)
+          {
+            annotationActions.add(action);
+            ignoredActions.add(action);
+          }
+        }
+      }
+
+      // If there is more than one action that creates an annotation...
+      //
+      if (annotationActions.size() > 1)
+      {
+        // Create a menu manager to group them.
+        // This assumes the first action is one for the null source.
+        //
+        IAction action = annotationActions.iterator().next();
+        String actionText = action.getText();
+        MenuManager annotationMenuManager = new MenuManager(actionText, action.getImageDescriptor(), "annotations");
+
+        // Add that menu manager instead of the individual actions.
         if (contributionID != null)
         {
-          manager.insertBefore(contributionID, action);
+          manager.insertBefore(contributionID, annotationMenuManager);
         }
         else
         {
-          manager.add(action);
+          manager.add(annotationMenuManager);
+        }
+
+        // Add an item for each annotation action.
+        //
+        for (IAction annotationAction : annotationActions)
+        {
+          annotationMenuManager.add(annotationAction);
+          String source = ((EAnnotation)((EObjectProvider)annotationAction).getEObject()).getSource();
+          if (source != null)
+          {
+            // Set the label to include the source.
+            //
+            annotationAction.setText(actionText + " - " + source);
+          }
+        }
+      }
+      else
+      {
+        ignoredActions.clear();
+      }
+
+      for (IAction action : actions)
+      {
+        if (!ignoredActions.contains(action))
+        {
+          if (contributionID != null)
+          {
+            manager.insertBefore(contributionID, action);
+          }
+          else
+          {
+            manager.add(action);
+          }
         }
       }
     }
   }
-    
+
   /**
    * This removes from the specified <code>manager</code> all {@link org.eclipse.jface.action.ActionContributionItem}s
    * based on the {@link org.eclipse.jface.action.IAction}s contained in the <code>actions</code> collection.
@@ -793,7 +1002,7 @@ public class EcoreActionBarContributor
    * <!-- end-user-doc -->
    * @generated
    */
-  protected void depopulateManager(IContributionManager manager, Collection<? extends IAction> actions)
+  protected void depopulateManagerGen(IContributionManager manager, Collection<? extends IAction> actions)
   {
     if (actions != null)
     {
@@ -822,6 +1031,20 @@ public class EcoreActionBarContributor
     }
   }
 
+  protected void depopulateManager(IContributionManager manager, Collection<? extends IAction> actions)
+  {
+    depopulateManagerGen(manager, actions);
+    IContributionItem[] items = manager.getItems();
+    for (int i = 0; i < items.length; i++)
+    {
+      IContributionItem contributionItem = items[i];
+      if ("annotations".equals(contributionItem.getId()))
+      {
+        manager.remove(contributionItem);
+      }
+    }
+  }
+
   /**
    * This populates the pop-up menu before it appears.
    * <!-- begin-user-doc -->
@@ -873,4 +1096,111 @@ public class EcoreActionBarContributor
     return true;
   }
 
+  /**
+   * An interface implemented by {@link EcoreCreateChildAction} and {@link EcoreCreateSiblingAction} to provide access to the data in the descriptor.
+   * @since 2.14
+   */
+  public interface EObjectProvider
+  {
+    public EObject getEObject();
+  }
+
+  /**
+   * A create child action subclass that provides access to the {@link #descriptor} and specializes {@link #run()} to show the properties view.
+   * @since 2.14
+   */
+  public class EcoreCreateChildAction extends CreateChildAction implements EObjectProvider
+  {
+    public EcoreCreateChildAction(IWorkbenchPart workbenchPart, ISelection selection, Object descriptor)
+    {
+      super(workbenchPart, selection, descriptor);
+    }
+
+    public EObject getEObject()
+    {
+      if (descriptor instanceof CommandParameter)
+      {
+        CommandParameter commandParameter = (CommandParameter)descriptor;
+        return commandParameter.getEValue();
+      }
+      else
+      {
+        return null;
+      }
+    }
+
+    @Override
+    public void run()
+    {
+      super.run();
+
+      // This is dispatched twice because the command stack listener dispatches once and then the viewer selection is also dispatches once,
+      // and we need to delay until the selection is established.
+      //
+      final Display display = EcoreActionBarContributor.this.getPage().getWorkbenchWindow().getShell().getDisplay();
+      display.asyncExec(new Runnable()
+        {
+          public void run()
+          {
+            display.asyncExec(new Runnable()
+              {
+                public void run()
+                {
+                  showPropertiesViewAction.run();
+                }
+              });
+          }
+        });
+    }
+  }
+
+  /**
+   * A create sibling action subclass that provides access to the {@link #descriptor} and specializes {@link #run()} to show the properties view.
+   *
+   * @since 2.14
+   */
+  public class EcoreCreateSiblingAction extends CreateSiblingAction implements EObjectProvider
+  {
+    public EcoreCreateSiblingAction(IWorkbenchPart workbenchPart, ISelection selection, Object descriptor)
+    {
+      super(workbenchPart, selection, descriptor);
+    }
+
+    public EObject getEObject()
+    {
+      if (descriptor instanceof CommandParameter)
+      {
+        CommandParameter commandParameter = (CommandParameter)descriptor;
+        return commandParameter.getEValue();
+      }
+      else
+      {
+        return null;
+      }
+    }
+
+    @Override
+    public void run()
+    {
+      super.run();
+
+      // This is dispatched twice because the command stack listener dispatches once and then the viewer selection is also dispatches once,
+      // and we need to delay until the selection is established.
+      //
+      final Display display = EcoreActionBarContributor.this.getPage().getWorkbenchWindow().getShell().getDisplay();
+      display.asyncExec(new Runnable()
+        {
+          public void run()
+          {
+            display.asyncExec(new Runnable()
+              {
+                public void run()
+                {
+                  showPropertiesViewAction.run();
+                }
+              });
+          }
+        });
+    }
+  }
 }
