@@ -1,15 +1,18 @@
 /**
  * Copyright (c) 2006-2012 IBM Corporation and others
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  *
  * Contributors:
  *   IBM - Initial API and implementation
  */
 package org.eclipse.emf.ecore.xcore.exporter;
 
+import java.io.BufferedInputStream;
+import java.io.IOException;
+import java.io.OutputStream;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -21,8 +24,17 @@ import java.util.Set;
 import org.eclipse.core.resources.IFile;
 import org.eclipse.core.resources.IProject;
 import org.eclipse.core.resources.IProjectDescription;
+import org.eclipse.core.resources.IWorkspace;
+import org.eclipse.core.resources.IWorkspaceRunnable;
 import org.eclipse.core.resources.ResourcesPlugin;
+import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.NullProgressMonitor;
 import org.eclipse.core.runtime.Path;
+import org.eclipse.core.runtime.Status;
+import org.eclipse.core.runtime.jobs.Job;
+import org.eclipse.emf.codegen.ecore.genmodel.GenAnnotation;
 import org.eclipse.emf.codegen.ecore.genmodel.GenBase;
 import org.eclipse.emf.codegen.ecore.genmodel.GenClassifier;
 import org.eclipse.emf.codegen.ecore.genmodel.GenFeature;
@@ -31,6 +43,7 @@ import org.eclipse.emf.codegen.ecore.genmodel.GenModelFactory;
 import org.eclipse.emf.codegen.ecore.genmodel.GenModelPackage;
 import org.eclipse.emf.codegen.ecore.genmodel.GenPackage;
 import org.eclipse.emf.codegen.util.ImportManager;
+import org.eclipse.emf.common.util.BasicDiagnostic;
 import org.eclipse.emf.common.util.Diagnostic;
 import org.eclipse.emf.common.util.EList;
 import org.eclipse.emf.common.util.Monitor;
@@ -43,11 +56,11 @@ import org.eclipse.emf.ecore.EGenericType;
 import org.eclipse.emf.ecore.EModelElement;
 import org.eclipse.emf.ecore.EObject;
 import org.eclipse.emf.ecore.EPackage;
+import org.eclipse.emf.ecore.EPackage.Registry;
 import org.eclipse.emf.ecore.EReference;
 import org.eclipse.emf.ecore.plugin.EcorePlugin;
 import org.eclipse.emf.ecore.resource.Resource;
 import org.eclipse.emf.ecore.resource.ResourceSet;
-import org.eclipse.emf.ecore.resource.impl.ResourceSetImpl;
 import org.eclipse.emf.ecore.util.EcoreUtil;
 import org.eclipse.emf.ecore.xcore.XGenericType;
 import org.eclipse.emf.ecore.xcore.XImportDirective;
@@ -57,18 +70,31 @@ import org.eclipse.emf.ecore.xcore.XcoreFactory;
 import org.eclipse.emf.ecore.xcore.XcorePackage;
 import org.eclipse.emf.ecore.xcore.mappings.XcoreMapper;
 import org.eclipse.emf.ecore.xcore.scoping.XcoreImportedNamespaceAwareScopeProvider;
+import org.eclipse.emf.ecore.xcore.ui.quickfix.XcoreClasspathUpdater;
 import org.eclipse.emf.ecore.xcore.util.EcoreXcoreBuilder;
 import org.eclipse.emf.ecore.xcore.util.XcoreGenModelBuilder;
 import org.eclipse.emf.ecore.xcore.util.XcoreGenModelInitializer;
 import org.eclipse.emf.exporter.ModelExporter;
+import org.eclipse.jdt.core.IJavaProject;
+import org.eclipse.jdt.core.JavaCore;
+import org.eclipse.xtext.formatting2.FormatterPreferenceValuesProvider;
+import org.eclipse.xtext.formatting2.FormatterRequest;
+import org.eclipse.xtext.formatting2.IFormatter2;
+import org.eclipse.xtext.formatting2.regionaccess.ITextReplacement;
+import org.eclipse.xtext.formatting2.regionaccess.internal.NodeModelBasedRegionAccessBuilder;
 import org.eclipse.xtext.naming.IQualifiedNameConverter;
 import org.eclipse.xtext.naming.IQualifiedNameProvider;
 import org.eclipse.xtext.naming.QualifiedName;
+import org.eclipse.xtext.parser.IParseResult;
+import org.eclipse.xtext.preferences.IPreferenceValues;
+import org.eclipse.xtext.preferences.TypedPreferenceValues;
 import org.eclipse.xtext.resource.IEObjectDescription;
 import org.eclipse.xtext.resource.SaveOptions;
+import org.eclipse.xtext.resource.XtextResource;
 import org.eclipse.xtext.scoping.IScope;
 import org.eclipse.xtext.scoping.IScopeProvider;
 import org.eclipse.xtext.ui.XtextProjectHelper;
+import org.eclipse.xtext.util.RuntimeIOException;
 
 import com.google.common.collect.Sets;
 import com.google.inject.Inject;
@@ -76,6 +102,10 @@ import com.google.inject.Provider;
 
 public class XcoreExporter extends ModelExporter
 {
+  private static String SAVE_FAMILY = "Save";
+  
+  public static Diagnostic RETRY = new BasicDiagnostic();
+
   @Inject
   Provider<EcoreXcoreBuilder> ecoreXcoreBuilderProvider;
 
@@ -97,6 +127,14 @@ public class XcoreExporter extends ModelExporter
   @Inject
   private IQualifiedNameConverter qualifiedNameConverter;
 
+  @Inject
+  protected IFormatter2 formatter;
+
+  @Inject
+  private FormatterPreferenceValuesProvider preferencesProvider;
+
+  @Inject
+  private Provider<ResourceSet> resourceSetProvider;
 
   private static final Set<String> IMPLICIT_ALIASES = Sets.newHashSet();
   static
@@ -138,11 +176,13 @@ public class XcoreExporter extends ModelExporter
   @Override
   protected Diagnostic doExport(Monitor monitor, ModelExporter.ExportData exportData) throws Exception
   {
-    for (Map.Entry<GenPackage, URI> entry : exportData.genPackageToArtifactURI.entrySet())
+    // Add natures and libraries if necessary.
+    // Because the builder needs to run to update the index, if we do add a library, we need to return early to allow the workspace modify operation to complete.
+    // After that's done, we want to retry, at which point there should be no libraries added the second time.
+    //
+    boolean retry = false;
+    for (URI xcoreLocationURI : exportData.genPackageToArtifactURI.values())
     {
-      GenPackage genPackage = entry.getKey();
-      URI xcoreLocationURI = entry.getValue();
-
       // Add the Xtext nature if it's absent.
       //
       IFile xcoreFile = ResourcesPlugin.getWorkspace().getRoot().getFile(new Path(xcoreLocationURI.toPlatformString(true)));
@@ -159,12 +199,29 @@ public class XcoreExporter extends ModelExporter
           description.setNatureIds(newNatures);
           xcoreProject.setDescription(description, null);
         }
+        XcoreClasspathUpdater xcoreClasspathUpdater = new XcoreClasspathUpdater();
+        IJavaProject xcoreJavaProject = JavaCore.create(xcoreProject);
+        retry = xcoreClasspathUpdater.addBundle(xcoreJavaProject, "org.eclipse.emf.ecore.xcore.lib", null) || retry;
+        retry = xcoreClasspathUpdater.addBundle(xcoreJavaProject, "org.eclipse.xtext.xbase.lib", null) || retry;
       }
+    }
+    if (retry)
+    {
+      return RETRY;
+    }
+
+    final List<Runnable> runnables = new ArrayList<Runnable>();
+    for (Map.Entry<GenPackage, URI> entry : exportData.genPackageToArtifactURI.entrySet())
+    {
+      GenPackage genPackage = entry.getKey();
+      URI xcoreLocationURI = entry.getValue();
 
       // Create an appropriate resource set for Xcore models.
       //
-      ResourceSet resourceSet = new ResourceSetImpl();
-      resourceSet.getURIConverter().getURIMap().putAll(EcorePlugin.computePlatformURIMap());
+      final ResourceSet resourceSet = resourceSetProvider.get();
+      final Map<URI, URI> uriMap = resourceSet.getURIConverter().getURIMap();
+      Registry packageRegistry = resourceSet.getPackageRegistry();
+      uriMap.putAll(EcorePlugin.computePlatformURIMap(true));
 
       // Load a clone of the GenModel in the new resource set.
       //
@@ -172,9 +229,9 @@ public class XcoreExporter extends ModelExporter
       inputGenModel.reconcile();
 
       Resource inputResource = inputGenModel.eResource();
-      Resource outputResource = resourceSet.createResource(xcoreLocationURI);
+      final XtextResource outputResource = (XtextResource)resourceSet.createResource(xcoreLocationURI);
 
-      // Create a fresh newly GenModel for the packages we just loaded.
+      // Create a fresh new GenModel for the packages we just loaded.
       //
       GenModel genModel = GenModelFactory.eINSTANCE.createGenModel();
       List<EPackage> ePackageClones = new ArrayList<EPackage>();
@@ -203,7 +260,7 @@ public class XcoreExporter extends ModelExporter
             //
             for (EAttribute eAttribute : genBase1.eClass().getEAllAttributes())
             {
-              if (!eAttribute.isMany() && genBase1.eIsSet(eAttribute))
+              if (!eAttribute.isMany())
               {
                 Object value1 = genBase1.eGet(eAttribute);
                 Object value2 = genBase2.eGet(eAttribute);
@@ -218,19 +275,30 @@ public class XcoreExporter extends ModelExporter
                   }
                   EcoreUtil.setAnnotation(eModelElement, GenModelPackage.eNS_URI, eAttribute.getName(), EcoreUtil.convertToString(eAttribute.getEAttributeType(), value1));
                 }
-                for (Iterator<EObject> i = genBase1.eContents().iterator(), j = genBase2.eContents().iterator(); i.hasNext() && j.hasNext();)
-                {
-                  EObject content1 = i.next();
-                  EObject content2 = j.next();
-                  if (content1 instanceof GenBase && content2 instanceof GenBase)
-                  {
-                    visit((GenBase)content1, (GenBase)content2);
-                  }
-                }
               }
             }
+
+            for (Iterator<GenBase> i = getContents(genBase1).iterator(), j = getContents(genBase2).iterator(); i.hasNext() && j.hasNext();)
+            {
+              GenBase content1 = i.next();
+              GenBase content2 = j.next();
+              visit((GenBase)content1, (GenBase)content2);
+            }
           }
         }
+
+        List<GenBase> getContents(EObject eObject)
+        {
+          List<GenBase> result = new ArrayList<GenBase>();
+          for (EObject eContent : eObject.eContents())
+          {
+            if (eContent instanceof GenBase && !(eContent instanceof GenAnnotation))
+            {
+              result.add((GenBase)eContent);
+            }
+          }
+          return result;
+        }
       }.visit(inputGenModel, genModel);
 
       // Use the builder to create an appropriate Xcore instance for populating the output resource.
@@ -242,24 +310,32 @@ public class XcoreExporter extends ModelExporter
       outputResource.getContents().add(inputGenModel);
       outputResource.getContents().add(inputGenPackage.getEcorePackage());
 
-      // Put all the specialize internal GenPackages in appropriately named resources so the serialize can resolve them.
+      // Put all the specialize internal GenPackages in appropriately named resources so the serializer can resolve them.
+      // Xtext complains about duplicate resources in the resource set if we put them in the original resource set.
       //
+      ResourceSet additionalResources = resourceSetProvider.get();
       GenPackage ecoreGenPackage = inputGenModel.getEcoreGenPackage();
       if (ecoreGenPackage != null)
       {
-        Resource ecoreResource = resourceSet.createResource(URI.createURI("platform:/plugin/org.eclipse.emf.ecore/model/Ecore.genmodel"));
+        URI ecoreResourceURI = URI.createPlatformResourceURI("/org.eclipse.emf.ecore/model/Ecore.genmodel", false);
+        packageRegistry.put(ecoreResourceURI.toString(), ecoreGenPackage.getEcorePackage());
+        Resource ecoreResource = additionalResources.createResource(ecoreResourceURI);
         ecoreResource.getContents().add(ecoreGenPackage.getGenModel());
       }
       GenPackage xmlTypeGenPackage = inputGenModel.getXMLTypeGenPackage();
       if (xmlTypeGenPackage != null)
       {
-        Resource xmlTypeResource = resourceSet.createResource(URI.createURI("platform:/plugin/org.eclipse.emf.ecore/model/XMLType.genmodel"));
+        URI xmlTypeResourceURI = URI.createPlatformResourceURI("/org.eclipse.emf.ecore/model/XMLType.genmodel", false);
+        packageRegistry.put(xmlTypeResourceURI.toString(), xmlTypeGenPackage.getEcorePackage());
+        Resource xmlTypeResource = additionalResources.createResource(xmlTypeResourceURI);
         xmlTypeResource.getContents().add(xmlTypeGenPackage.getGenModel());
       }
       GenPackage xmlNamespaceGenPackage = inputGenModel.getXMLNamespaceGenPackage();
       if (xmlNamespaceGenPackage != null)
       {
-        Resource xmlNamespaceResource = resourceSet.createResource(URI.createURI("platform:/plugin/org.eclipse.emf.ecore/model/XMLNamespace.genmodel"));
+        URI xmlNamespaceResourceURI = URI.createPlatformResourceURI("/org.eclipse.emf.ecore/model/XMLNamespace.genmodel", false);
+        packageRegistry.put(xmlNamespaceResourceURI.toString(), xmlNamespaceGenPackage.getEcorePackage());
+        Resource xmlNamespaceResource = additionalResources.createResource(xmlNamespaceResourceURI);
         xmlNamespaceResource.getContents().add(xmlNamespaceGenPackage.getGenModel());
       }
 
@@ -297,17 +373,20 @@ public class XcoreExporter extends ModelExporter
               importManager.addImport(qualifiedNameValue);
             }
 
-            // We need to ensure that if we resolve to a different instance, we switch to use that so that serialization will find the right instance.
-            //
-            XGenericType xGenericType = genericTypeMap.get(eGenericType);
-            IScope scope = scopeProvider.getScope(xGenericType, XcorePackage.Literals.XGENERIC_TYPE__TYPE);
-            IEObjectDescription genClassifierDescription = scope.getSingleElement(qualifiedName);
-            if (genClassifierDescription != null)
+            if (genClassifier.eResource() != outputResource)
             {
-              EObject resolvedGenClassifier = resourceSet.getEObject(genClassifierDescription.getEObjectURI(), true);
-              if (resolvedGenClassifier != null && resolvedGenClassifier != genClassifier)
+              // We need to ensure that if we resolve to a different instance, we switch to use that so that serialization will find the right instance.
+              //
+              XGenericType xGenericType = genericTypeMap.get(eGenericType);
+              IScope scope = scopeProvider.getScope(xGenericType, XcorePackage.Literals.XGENERIC_TYPE__TYPE);
+              IEObjectDescription genClassifierDescription = scope.getSingleElement(qualifiedName);
+              if (genClassifierDescription != null)
               {
-                xGenericType.setType((GenClassifier)resolvedGenClassifier);
+                EObject resolvedGenClassifier = resourceSet.getEObject(genClassifierDescription.getEObjectURI(), true);
+                if (resolvedGenClassifier != null && resolvedGenClassifier != genClassifier)
+                {
+                  xGenericType.setType((GenClassifier)resolvedGenClassifier);
+                }
               }
             }
           }
@@ -318,7 +397,7 @@ public class XcoreExporter extends ModelExporter
           XReference xReference = (XReference)mapper.getToXcoreMapping(eReference).getXcoreElement();
           EList<GenFeature> keys = xReference.getKeys();
           GenFeature opposite = xReference.getOpposite();
-          if (opposite != null)
+          if (opposite != null && opposite.eResource() != outputResource)
           {
             IScope scope = scopeProvider.getScope(xReference, XcorePackage.Literals.XREFERENCE__OPPOSITE);
             IEObjectDescription genFeatureDescription = scope.getSingleElement(QualifiedName.create(opposite.getName()));
@@ -337,13 +416,16 @@ public class XcoreExporter extends ModelExporter
             for (ListIterator<GenFeature> k = keys.listIterator(); k.hasNext(); )
             {
               GenFeature key = k.next();
-              IEObjectDescription genFeatureDescription = scope.getSingleElement(QualifiedName.create(key.getName()));
-              if (genFeatureDescription != null)
+              if (key.eResource() != outputResource)
               {
-                EObject resolvedGenFeature = resourceSet.getEObject(genFeatureDescription.getEObjectURI(), true);
-                if (resolvedGenFeature != null)
+                IEObjectDescription genFeatureDescription = scope.getSingleElement(QualifiedName.create(key.getName()));
+                if (genFeatureDescription != null)
                 {
-                  k.set((GenFeature)resolvedGenFeature);
+                  EObject resolvedGenFeature = resourceSet.getEObject(genFeatureDescription.getEObjectURI(), true);
+                  if (resolvedGenFeature != null)
+                  {
+                    k.set((GenFeature)resolvedGenFeature);
+                  }
                 }
               }
             }
@@ -366,12 +448,124 @@ public class XcoreExporter extends ModelExporter
 
       // Save the final result.
       //
-      Map<Object, Object> options = new HashMap<Object, Object>();
-      SaveOptions.newBuilder().format().noValidation().getOptions().addTo(options);
-      outputResource.save(options);
+      final Map<Object, Object> options = new HashMap<Object, Object>();
+      SaveOptions.newBuilder().format().getOptions().addTo(options);
+
+      Runnable runnable =
+        new Runnable()
+        {
+          @Override
+          public void run()
+          {
+            try
+            {
+              // Temporarily clear the mappings so that the serializer properly finds the non-normalized URIs in the index.
+              //
+              Map<URI, URI> copyiedURIMap = new HashMap<URI, URI>(uriMap);
+              uriMap.clear();
+              outputResource.save(options);
+              uriMap.putAll(copyiedURIMap);
+
+              outputResource.unload();
+              outputResource.load(null);
+              IParseResult parseResult = outputResource.getParseResult();
+              if (parseResult != null)
+              {
+                IPreferenceValues configuration = preferencesProvider.getPreferenceValues(outputResource);
+                try
+                {
+                  FormatterRequest request = new FormatterRequest();
+                  request.setTextRegionAccess(new NodeModelBasedRegionAccessBuilder().withResource(outputResource).create());
+                  request.setPreferences(TypedPreferenceValues.castOrWrap(configuration));
+                  request.addRegion(parseResult.getRootNode().getTotalTextRegion());
+                  List<ITextReplacement> edits = formatter.format(request);
+
+                  BufferedInputStream bufferedInputStream = new BufferedInputStream(resourceSet.getURIConverter().createInputStream(outputResource.getURI()));
+                  byte[] input = new byte[bufferedInputStream.available()];
+                  bufferedInputStream.read(input);
+                  bufferedInputStream.close();
+                  String text = new String(input, outputResource.getEncoding());
+                  StringBuilder builder = new StringBuilder(text);
+                  for (int i = edits.size(); --i >= 0; )
+                  {
+                    ITextReplacement replacement = edits.get(i);
+                    int offset = replacement.getOffset();
+                    builder.replace(offset, offset + replacement.getLength(), replacement.getReplacementText());
+                  }
+
+                  OutputStream outputStream = resourceSet.getURIConverter().createOutputStream(outputResource.getURI());
+                  outputStream.write(builder.toString().getBytes(outputResource.getEncoding()));
+                  outputStream.close();
+                }
+                catch (Throwable throwable)
+                {
+                  XcoreExporterPlugin.INSTANCE.log(throwable);
+                }
+              }
+            }
+            catch (IOException exception)
+            {
+              throw new RuntimeIOException(exception);
+            }
+          }
+        };
+      runnables.add(runnable);
     }
+
+    // Do this in a job so that Xtext nature we added has a chance to build the index needed by the serializer.
+    //
+    Job job =
+      new Job("Save")
+      {
+        @Override
+        public boolean belongsTo(Object family)
+        {
+          return family == SAVE_FAMILY;
+        }
+        
+        @Override
+        protected IStatus run(IProgressMonitor monitor)
+        {
+          try
+          {
+            IWorkspace workspace = ResourcesPlugin.getWorkspace();
+            IWorkspaceRunnable runnable =
+               new IWorkspaceRunnable()
+              {
+                @Override
+                public void run(IProgressMonitor monitor) throws CoreException
+                {
+                  for (Runnable runnable : runnables)
+                  {
+                    runnable.run();
+                  }
+                }
+              };
+            workspace.run(runnable, null, IWorkspace.AVOID_UPDATE, null);
+            return Status.OK_STATUS;
+          }
+          catch (Exception exception)
+          {
+            return Status.CANCEL_STATUS;
+          }
+        }
+      };
+    job.schedule();
+
     return Diagnostic.OK_INSTANCE;
   }
+  
+  public void waitForSaveJob()
+  {
+    try
+    {
+      Job.getJobManager().join(SAVE_FAMILY, new NullProgressMonitor());
+    }
+    catch (Throwable e)
+    {
+      // Ignore
+    }
+  }
 
   protected URI getReferencedGenPackageArtifactURI(ModelExporter.ExportData exportData, GenPackage genPackage)
   {
