@@ -1,16 +1,15 @@
 /**
  * Copyright (c) 2011-2012 Eclipse contributors and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  */
 package org.eclipse.emf.ecore.xcore.mappings;
 
 
 import org.eclipse.emf.codegen.ecore.genmodel.GenClass;
 import org.eclipse.emf.ecore.EClass;
-import org.eclipse.emf.ecore.xcore.util.XcoreJvmInferrer;
 import org.eclipse.xtext.common.types.JvmGenericType;
 
 
@@ -20,6 +19,10 @@ public class XClassMapping extends AbstractMapping
 
   private GenClass genClass;
 
+  private JvmGenericType interfaceType;
+
+  private JvmGenericType classType;
+
   public EClass getEClass()
   {
     return eClass;
@@ -42,11 +45,21 @@ public class XClassMapping extends AbstractMapping
 
   public JvmGenericType getInterfaceType()
   {
-    return XcoreJvmInferrer.getInferredElement(genClass, genClass.getQualifiedInterfaceName());
+    return interfaceType;
+  }
+
+  public void setInterfaceType(JvmGenericType interfaceType)
+  {
+    this.interfaceType = interfaceType;
   }
 
   public JvmGenericType getClassType()
   {
-    return XcoreJvmInferrer.getInferredElement(genClass, genClass.getQualifiedClassName());
+    return classType;
+  }
+
+  public void setClassType(JvmGenericType classType) 
+  {
+    this.classType = classType;
   }
 }
