@@ -1,16 +1,15 @@
 /**
  * Copyright (c) 2011-2012 Eclipse contributors and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  */
 package org.eclipse.emf.ecore.xcore.mappings;
 
 
 import org.eclipse.emf.codegen.ecore.genmodel.GenDataType;
 import org.eclipse.emf.ecore.EDataType;
-import org.eclipse.emf.ecore.xcore.util.XcoreJvmInferrer;
 import org.eclipse.xtext.common.types.JvmOperation;
 
 
@@ -20,6 +19,10 @@ public class XDataTypeMapping extends AbstractMapping
 
   private GenDataType genDataType;
 
+  private JvmOperation creator;
+
+  private JvmOperation converter;
+
   public EDataType getEDataType()
   {
     return eDataType;
@@ -42,11 +45,21 @@ public class XDataTypeMapping extends AbstractMapping
 
   public JvmOperation getCreator()
   {
-    return XcoreJvmInferrer.getInferredElement(genDataType, genDataType.getGenPackage().getQualifiedFactoryClassName() + ".create" + genDataType.getName());
+    return creator;
+  }
+
+  public void setCreator(JvmOperation creator)
+  {
+    this.creator = creator;
   }
 
   public JvmOperation getConverter()
   {
-    return XcoreJvmInferrer.getInferredElement(genDataType, genDataType.getGenPackage().getQualifiedFactoryClassName() + ".convert" + genDataType.getName());
+    return converter;
+  }
+
+  public void setConverter(JvmOperation converter)
+  {
+    this.converter = converter;
   }
 }
