@@ -1,14 +1,15 @@
 /**
  * Copyright (c) 2011-2012 Eclipse contributors and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  */
 package org.eclipse.emf.ecore.xcore.util;
 
 
 import java.util.ArrayList;
+import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.regex.Pattern;
@@ -38,9 +39,14 @@ import org.eclipse.emf.ecore.ETypeParameter;
 import org.eclipse.emf.ecore.ETypedElement;
 import org.eclipse.emf.ecore.EcoreFactory;
 import org.eclipse.emf.ecore.EcorePackage;
-import org.eclipse.emf.ecore.impl.EClassifierImpl;
+import org.eclipse.emf.ecore.impl.EAnnotationImpl;
+import org.eclipse.emf.ecore.impl.EClassImpl;
+import org.eclipse.emf.ecore.impl.EDataTypeImpl;
+import org.eclipse.emf.ecore.impl.EGenericTypeImpl;
+import org.eclipse.emf.ecore.impl.EReferenceImpl;
 import org.eclipse.emf.ecore.util.EcoreUtil;
 import org.eclipse.emf.ecore.util.EcoreValidator;
+import org.eclipse.emf.ecore.util.ExtendedMetaData;
 import org.eclipse.emf.ecore.xcore.XAnnotation;
 import org.eclipse.emf.ecore.xcore.XAnnotationDirective;
 import org.eclipse.emf.ecore.xcore.XAttribute;
@@ -70,6 +76,7 @@ import org.eclipse.emf.ecore.xcore.services.XcoreGrammarAccess;
 import org.eclipse.xtext.common.types.JvmTypeReference;
 import org.eclipse.xtext.nodemodel.ICompositeNode;
 import org.eclipse.xtext.nodemodel.ILeafNode;
+import org.eclipse.xtext.nodemodel.INode;
 import org.eclipse.xtext.nodemodel.util.NodeModelUtils;
 import org.eclipse.xtext.xbase.XBlockExpression;
 
@@ -79,7 +86,7 @@ import com.google.inject.Provider;
 
 public class XcoreEcoreBuilder
 {
-  private static final Pattern COMMENT_LINE_BREAK_PATTERN = Pattern.compile("([ \t]*((\n\r?)|(\r\n?))(\\s*\\*\\s?)?)|\\s*$", Pattern.MULTILINE);
+  private static final Pattern COMMENT_LINE_BREAK_PATTERN = Pattern.compile("([ \t]*(\\r?\\n)(\\s*\\*\\s?)?)|\\s*$", Pattern.MULTILINE);
 
   @Inject
   private XcoreMapper mapper;
@@ -102,9 +109,7 @@ public class XcoreEcoreBuilder
   @Inject
   private XcoreGrammarAccess xcoreGrammarAccess;
 
-  protected List<Runnable> runnables = new ArrayList<Runnable>();
-
-  protected List<Runnable> instanceTypeRunnables = new ArrayList<Runnable>();
+  protected final List<DeferredInitializer> deferredInitializers = new ArrayList<DeferredInitializer>();
 
   protected XcoreInterpreter interpreter;
 
@@ -112,28 +117,17 @@ public class XcoreEcoreBuilder
 
   public void link()
   {
-    // Hook up local references.
-    //
-    List<Runnable> currentRunnables = new ArrayList<Runnable>(runnables);
-    runnables.clear();
-    for (Runnable runnable : currentRunnables)
+    for (DeferredInitializer deferredInitializer : deferredInitializers)
     {
-      runnable.run();
+      deferredInitializer.setNeedsInitialization(true);
     }
-    for (Runnable runnable : runnables)
-    {
-      runnable.run();
-    }
-  }
 
-  public void linkInstanceTypes()
-  {
-    // Hook up instance types.
-    //
-    for (Runnable runnable : instanceTypeRunnables)
+    for (DeferredInitializer deferredInitializer : deferredInitializers)
     {
-      runnable.run();
+      deferredInitializer.initialize();
     }
+
+    deferredInitializers.clear();
   }
 
   public static void setQualifiedPackageName(EPackage ePackage, String name)
@@ -144,7 +138,6 @@ public class XcoreEcoreBuilder
       int index = name.lastIndexOf(".");
       if (index == -1)
       {
-        basePackage = null;
         ePackage.setName(name);
       }
       else
@@ -186,8 +179,15 @@ public class XcoreEcoreBuilder
       // At least to this for Ecore to avoid inducing a model with circular inheritance.
       // TODO
       //
-      ePackage.setNsURI("org.eclipse.emf.ecore".equals(name) ? EcorePackage.eNS_URI : name);
-      ePackage.setNsPrefix(ePackage.getName());
+      if (ePackage.getNsURI() == null)
+      {
+        ePackage.setNsURI("org.eclipse.emf.ecore".equals(name) ? EcorePackage.eNS_URI : name);
+      }
+      if (ePackage.getNsPrefix() == null)
+      {
+        String packageName = ePackage.getName();
+        ePackage.setNsPrefix(packageName.toLowerCase().startsWith("xml") ? "_" + packageName : packageName);
+      }
     }
 
     EList<EClassifier> eClassifiers = ePackage.getEClassifiers();
@@ -205,8 +205,9 @@ public class XcoreEcoreBuilder
     return ePackage;
   }
 
-  void handleAnnotations(final XModelElement xModelElement, final EModelElement eModelElement)
+  protected void handleAnnotations(final XModelElement xModelElement, final EModelElement eModelElement)
   {
+    Map<String, DeferredEAnnotationImpl> specialAnnotations = new LinkedHashMap<String, XcoreEcoreBuilder.DeferredEAnnotationImpl>();
     ICompositeNode node = NodeModelUtils.getNode(xModelElement);
     if (node != null)
     {
@@ -245,7 +246,11 @@ public class XcoreEcoreBuilder
               }
               if (comment != null)
               {
-                EcoreUtil.setDocumentation(eModelElement, comment.toString());
+                DeferredEAnnotationImpl eAnnotation = new DeferredEAnnotationImpl(null);
+                eAnnotation.setSource(GenModelPackage.eNS_URI);
+                eModelElement.getEAnnotations().add(eAnnotation);
+                eAnnotation.getDetails().put("documentation", comment.toString());
+                specialAnnotations.put(GenModelPackage.eNS_URI, eAnnotation);
               }
             }
             break;
@@ -257,60 +262,89 @@ public class XcoreEcoreBuilder
         }
       }
     }
-    runnables.add
-      (new Runnable()
-       {
-         public void run()
-         {
-           EList<EAnnotation> eAnnotations = eModelElement.getEAnnotations();
-           for (XAnnotation xAnnotation : xModelElement.getAnnotations())
-           {
-             //      map(eAnnotation, xAnnotation);
-             String sourceURI = null;
-             XAnnotationDirective source = xAnnotation.getSource();
-             if (source != null)
-             {
-               sourceURI = source.getSourceURI();
-             }
-             EClass eClass = EcorePackage.eNS_URI.equals(sourceURI) ? eModelElement.eClass() : null;
 
-             EMap<String, String> details = xAnnotation.getDetails();
-             if (details.isEmpty())
-             {
-               EAnnotation eAnnotation = EcoreFactory.eINSTANCE.createEAnnotation();
-               eAnnotation.setSource(sourceURI);
-               eAnnotations.add(eAnnotation);
-             }
-             else
-             {
-               for (Map.Entry<String, String> detail : details)
-               {
-                 String key = detail.getKey();
-                 String value = detail.getValue();
-                 if (eClass != null)
-                 {
-                   EStructuralFeature eStructuralFeature = eClass.getEStructuralFeature(key);
-                   if (eStructuralFeature instanceof EAttribute)
-                   {
-                     // Be more careful about exceptions.
-                     // TODO
-                     //
-                     eModelElement.eSet(eStructuralFeature, value);
-                     continue;
-                   }
-                 }
-                 if (EcoreUtil.getAnnotation(eModelElement, sourceURI, key) == null)
-                 {
-                   EcoreUtil.setAnnotation(eModelElement, sourceURI, key, value);
-                 }
-               }
-             }
-           }
-         }
-       });
-     }
+    EList<EAnnotation> eAnnotations = eModelElement.getEAnnotations();
+    for (XAnnotation xAnnotation : xModelElement.getAnnotations())
+    {
+      //      map(eAnnotation, xAnnotation);
+      String sourceURI = null;
 
-  EClassifier getEClassifier(final XClassifier xClassifier)
+        List<INode> nodes = NodeModelUtils.findNodesForFeature(xAnnotation, XcorePackage.Literals.XANNOTATION__SOURCE);
+        StringBuilder annotationLiteral = new StringBuilder();
+        for (INode sourceNode : nodes)
+        {
+          annotationLiteral.append(NodeModelUtils.getTokenText(sourceNode));
+        }
+        int index = annotationLiteral.lastIndexOf(" ");
+        if (index != -1)
+        {
+          annotationLiteral.delete(0, index + 1);
+        }
+        index = annotationLiteral.lastIndexOf(".");
+        if (index != -1)
+        {
+          annotationLiteral.delete(0, index + 1);
+        }
+        String simpleAnnotationName = annotationLiteral.toString();
+        if ("GenModel".equals(simpleAnnotationName))
+        {
+          sourceURI = GenModelPackage.eNS_URI;
+        }
+        else if ("Ecore".equals(simpleAnnotationName))
+        {
+          sourceURI = EcorePackage.eNS_URI;
+        }
+        else if ("ExtendedMetaData".equals(simpleAnnotationName))
+        {
+          sourceURI = ExtendedMetaData.ANNOTATION_URI;
+        }
+
+        EClass eClass = EcorePackage.eNS_URI.equals(sourceURI) ? eModelElement.eClass() : null;
+
+        DeferredEAnnotationImpl eAnnotation = specialAnnotations.get(sourceURI);
+        if (eAnnotation == null)
+        {
+          eAnnotation = new DeferredEAnnotationImpl(xAnnotation);
+          if (sourceURI != null)
+          {
+            specialAnnotations.put(sourceURI, eAnnotation);
+          }
+        }
+        eAnnotation.setSource(sourceURI);
+
+        EMap<String, String> details = eAnnotation.getDetails();
+        for (Map.Entry<String, String> detail : xAnnotation.getDetails())
+        {
+          String key = detail.getKey();
+          String value = detail.getValue();
+
+          if (eClass != null)
+          {
+            EStructuralFeature eStructuralFeature = eClass.getEStructuralFeature(key);
+            if (eStructuralFeature instanceof EAttribute)
+            {
+              // Be more careful about exceptions.
+              // TODO
+              //
+              EDataType eDataType = (EDataType)eStructuralFeature.getEType();
+              eModelElement.eSet(eStructuralFeature, EcoreUtil.createFromString(eDataType, value));
+              continue;
+            }
+          }
+
+          details.put(key,  value);
+        }
+
+        // Add it if it's not an Ecore annotation or if it is an Ecore annotation but isn't empty.
+        if (eClass == null || !details.isEmpty())
+        {
+          eAnnotations.add(eAnnotation);
+          deferredInitializers.add(eAnnotation);
+        }
+      }
+  }
+
+  protected EClassifier getEClassifier(final XClassifier xClassifier)
   {
     final EClassifier eClassifier = xClassifier instanceof XClass ? getEClass((XClass)xClassifier) : xClassifier instanceof XEnum
       ? getEEnum((XEnum)xClassifier) : getEDataType((XDataType)xClassifier);
@@ -328,39 +362,30 @@ public class XcoreEcoreBuilder
         //
         eClassifier.setInstanceTypeName("java.lang.Cloneable");
       }
-      instanceTypeRunnables.add
-        (new Runnable()
-         {
-           public void run()
-           {
-             JvmTypeReference instanceType = xClassifier.getInstanceType();
-             if (instanceType != null)
-             {
-               String instanceTypeName = instanceType.getIdentifier();
-               String normalizedInstanceTypeName = EcoreUtil.toJavaInstanceTypeName((EGenericType)EcoreValidator.EGenericTypeBuilder.INSTANCE.parseInstanceTypeName(instanceTypeName).getData().get(0));
-               eClassifier.setInstanceTypeName(normalizedInstanceTypeName);
-               if (classLoader != null && eClassifier instanceof EClassifierImpl)
-               {
-                 try
-                 {
-                   Class<?> instanceClass = classLoader.loadClass(eClassifier.getInstanceClassName());
-                   ((EClassifierImpl)eClassifier).setInstanceClassGen(instanceClass);
-                 }
-                 catch (Throwable throwable)
-                 {
-                   // Ignore.
-                 }
-               }
-             }
-           }
-         });
+
+      // Populate the instance type early because GenOperation IDs depend on the data type's unqualified instance type and it might not be set so early.
+      List<INode> nodes = NodeModelUtils.findNodesForFeature(xClassifier, XcorePackage.Literals.XCLASSIFIER__INSTANCE_TYPE);
+      if (!nodes.isEmpty())
+      {
+        StringBuilder instanceTypeLiteral = new StringBuilder();
+        for (INode node : nodes)
+        {
+          instanceTypeLiteral.append(NodeModelUtils.getTokenText(node));
+        }
+        eClassifier.setInstanceTypeName(instanceTypeLiteral.toString());
+      }
+
+      if (eClassifier instanceof DeferredInitializer)
+      {
+        deferredInitializers.add((DeferredInitializer)eClassifier);
+      }
     }
     return eClassifier;
   }
 
-  EClass getEClass(final XClass xClass)
+  protected EClass getEClass(final XClass xClass)
   {
-    final EClass eClass = EcoreFactory.eINSTANCE.createEClass();
+    final EClass eClass = new DeferredEClassImpl(xClass, classLoader);
     mapper.getMapping(xClass).setEClass(eClass);
     mapper.getToXcoreMapping(eClass).setXcoreElement(xClass);
     if (xClass.isInterface())
@@ -406,7 +431,7 @@ public class XcoreEcoreBuilder
     return eClass;
   }
 
-  EOperation getEOperation(XOperation xOperation)
+  protected EOperation getEOperation(XOperation xOperation)
   {
     EOperation eOperation = EcoreFactory.eINSTANCE.createEOperation();
     mapper.getMapping(xOperation).setEOperation(eOperation);
@@ -444,7 +469,7 @@ public class XcoreEcoreBuilder
     return eOperation;
   }
 
-  EParameter getEParameter(XParameter xParameter)
+  protected EParameter getEParameter(XParameter xParameter)
   {
     EParameter eParameter = EcoreFactory.eINSTANCE.createEParameter();
     mapper.getMapping(xParameter).setEParameter(eParameter);
@@ -454,7 +479,7 @@ public class XcoreEcoreBuilder
     return eParameter;
   }
 
-  ETypeParameter getETypeParameter(XTypeParameter xTypeParameter)
+  protected ETypeParameter getETypeParameter(XTypeParameter xTypeParameter)
   {
     ETypeParameter eTypeParameter = EcoreFactory.eINSTANCE.createETypeParameter();
     mapper.getMapping(xTypeParameter).setETypeParameter(eTypeParameter);
@@ -469,7 +494,7 @@ public class XcoreEcoreBuilder
     return eTypeParameter;
   }
 
-  void handleETypedElement(ETypedElement eTypedElement, XTypedElement xTypedElement)
+  protected void handleETypedElement(ETypedElement eTypedElement, XTypedElement xTypedElement)
   {
     eTypedElement.setName(nonNullName(xTypedElement.getName()));
     handleAnnotations(xTypedElement, eTypedElement);
@@ -529,7 +554,7 @@ public class XcoreEcoreBuilder
     }
   }
 
-  EGenericType getEGenericType(final XGenericType xGenericType)
+  protected EGenericType getEGenericType(final XGenericType xGenericType)
   {
     if (xGenericType == null)
     {
@@ -537,8 +562,7 @@ public class XcoreEcoreBuilder
     }
     else
     {
-      final EGenericType eGenericType = EcoreFactory.eINSTANCE.createEGenericType();
-      //      map(eGenericType, xGenericType);
+      DeferredEGenericTypeImpl eGenericType = new DeferredEGenericTypeImpl(xGenericType);
       XGenericType lowerBound = xGenericType.getLowerBound();
       if (lowerBound != null)
       {
@@ -554,29 +578,14 @@ public class XcoreEcoreBuilder
       {
         eTypeArguments.add(getEGenericType(typeArgument));
       }
-
-      runnables.add(new Runnable()
-        {
-          public void run()
-          {
-            GenBase type = xGenericType.getType();
-            if (type instanceof GenTypeParameter)
-            {
-              eGenericType.setETypeParameter(((GenTypeParameter)type).getEcoreTypeParameter());
-            }
-            else if (type instanceof GenClassifier)
-            {
-              eGenericType.setEClassifier(((GenClassifier)type).getEcoreClassifier());
-            }
-          }
-        });
+      deferredInitializers.add(eGenericType);
       return eGenericType;
     }
   }
 
-  EReference getEReference(final XReference xReference)
+  protected EReference getEReference(final XReference xReference)
   {
-    final EReference eReference = EcoreFactory.eINSTANCE.createEReference();
+    final DeferredEReferenceImpl eReference = new DeferredEReferenceImpl(xReference);
     mapper.getMapping(xReference).setEStructuralFeature(eReference);
     mapper.getToXcoreMapping(eReference).setXcoreElement(xReference);
     if (xReference.isContainment())
@@ -591,38 +600,12 @@ public class XcoreEcoreBuilder
     {
       eReference.setResolveProxies(false);
     }
-
     handleEStructuralFeature(eReference, xReference);
-
-    runnables.add(new Runnable()
-      {
-        public void run()
-        {
-          GenFeature opposite = xReference.getOpposite();
-          if (opposite != null)
-          {
-            eReference.setEOpposite((EReference)opposite.getEcoreFeature());
-          }
-          runnables.add(new Runnable()
-            {
-              public void run()
-              {
-                for (GenFeature key : xReference.getKeys())
-                {
-                  EStructuralFeature eAttribute = key.getEcoreFeature();
-                  if (eAttribute instanceof EAttribute)
-                  {
-                    eReference.getEKeys().add((EAttribute)eAttribute);
-                  }
-                }
-              }});
-        }
-      });
-
+    deferredInitializers.add(eReference);
     return eReference;
   }
 
-  EAttribute getEAttribute(final XAttribute xAttribute)
+  protected EAttribute getEAttribute(final XAttribute xAttribute)
   {
     final EAttribute eAttribute = EcoreFactory.eINSTANCE.createEAttribute();
     mapper.getMapping(xAttribute).setEStructuralFeature(eAttribute);
@@ -637,7 +620,7 @@ public class XcoreEcoreBuilder
     return eAttribute;
   }
 
-  void handleEStructuralFeature(EStructuralFeature eStructuralFeature, XStructuralFeature xStructuralFeature)
+  protected void handleEStructuralFeature(EStructuralFeature eStructuralFeature, XStructuralFeature xStructuralFeature)
   {
     eStructuralFeature.setName(nonNullName(xStructuralFeature.getName()));
     handleETypedElement(eStructuralFeature, xStructuralFeature);
@@ -685,9 +668,9 @@ public class XcoreEcoreBuilder
     }
   }
 
-  EDataType getEDataType(XDataType xDataType)
+  protected EDataType getEDataType(XDataType xDataType)
   {
-    EDataType eDataType = EcoreFactory.eINSTANCE.createEDataType();
+    EDataType eDataType = new DeferredEDataTypeImpl(xDataType, classLoader);
     mapper.getMapping(xDataType).setEDataType(eDataType);
     mapper.getToXcoreMapping(eDataType).setXcoreElement(xDataType);
     EList<ETypeParameter> eTypeParameters = eDataType.getETypeParameters();
@@ -706,7 +689,7 @@ public class XcoreEcoreBuilder
     return eDataType;
   }
 
-  EEnum getEEnum(XEnum xEnum)
+  protected EEnum getEEnum(XEnum xEnum)
   {
     EEnum eEnum = EcoreFactory.eINSTANCE.createEEnum();
     mapper.getMapping(xEnum).setEDataType(eEnum);
@@ -719,7 +702,7 @@ public class XcoreEcoreBuilder
     return eEnum;
   }
 
-  EEnumLiteral getEEnumLiteral(XEnumLiteral xEnumLiteral)
+  protected EEnumLiteral getEEnumLiteral(XEnumLiteral xEnumLiteral)
   {
     EEnumLiteral eEnumLiteral = EcoreFactory.eINSTANCE.createEEnumLiteral();
     mapper.getToXcoreMapping(eEnumLiteral).setXcoreElement(xEnumLiteral);
@@ -730,4 +713,409 @@ public class XcoreEcoreBuilder
     eEnumLiteral.setValue(xEnumLiteral.getValue());
     return eEnumLiteral;
   }
-}
+
+  /**
+   * This was introduced to address the problems uncovered by https://bugs.eclipse.org/bugs/show_bug.cgi?id=514561.
+   */
+  public interface DeferredInitializer
+  {
+    void setNeedsInitialization(boolean needsInitialization);
+    void initialize();
+  }
+
+  private static final class DeferredEDataTypeImpl extends EDataTypeImpl implements DeferredInitializer
+  {
+    private final XClassifier xClassifier;
+
+    private final ClassLoader classLoader;
+
+    private boolean needsInitialization;
+
+    public DeferredEDataTypeImpl(XClassifier xClassifier, ClassLoader classLoader)
+    {
+      this.xClassifier = xClassifier;
+      this.classLoader = classLoader;
+    }
+
+    public void setNeedsInitialization(boolean needsInitialization)
+    {
+      this.needsInitialization = needsInitialization;
+    }
+
+    public void initialize()
+    {
+      if (needsInitialization)
+      {
+        needsInitialization = false;
+
+        JvmTypeReference instanceType = xClassifier.getInstanceType();
+        if (instanceType != null)
+        {
+          String instanceTypeName = instanceType.getIdentifier();
+          String normalizedInstanceTypeName = EcoreUtil.toJavaInstanceTypeName((EGenericType)EcoreValidator.EGenericTypeBuilder.INSTANCE.buildEGenericType(instanceTypeName));
+          setInstanceTypeName(normalizedInstanceTypeName);
+          if (classLoader != null)
+          {
+            try
+            {
+              Class<?> instanceClass = classLoader.loadClass(getInstanceClassName());
+              setInstanceClassGen(instanceClass);
+            }
+            catch (Throwable throwable)
+            {
+              // Ignore.
+            }
+          }
+        }
+      }
+    }
+
+    @Override
+    public boolean isSetInstanceClassName()
+    {
+      initialize();
+      return super.isSetInstanceClassName();
+    }
+
+    @Override
+    public String getInstanceClassName()
+    {
+      initialize();
+      return super.getInstanceClassName();
+    }
+
+    @Override
+    public boolean isSetInstanceTypeName()
+    {
+      initialize();
+      return super.isSetInstanceTypeName();
+    }
+
+    @Override
+    public String getInstanceTypeName()
+    {
+      initialize();
+      return super.getInstanceTypeName();
+    }
+
+    @Override
+    public Class<?> getInstanceClass()
+    {
+      initialize();
+      return super.getInstanceClass();
+    }
+  }
+
+  private static final class DeferredEClassImpl extends EClassImpl implements DeferredInitializer
+  {
+    private final XClassifier xClassifier;
+
+    protected boolean needsInitialization;
+
+    private ClassLoader classLoader;
+
+    public DeferredEClassImpl(XClassifier xClassifier, ClassLoader classLoader)
+    {
+      this.xClassifier = xClassifier;
+      this.classLoader = classLoader;
+    }
+
+    public void setNeedsInitialization(boolean needsInitialization)
+    {
+      this.needsInitialization = needsInitialization;
+    }
+
+    public void initialize()
+    {
+      if (needsInitialization)
+      {
+        needsInitialization = false;
+
+        JvmTypeReference instanceType = xClassifier.getInstanceType();
+        if (instanceType != null)
+        {
+          String instanceTypeName = instanceType.getIdentifier();
+          String normalizedInstanceTypeName = EcoreUtil.toJavaInstanceTypeName(EcoreValidator.EGenericTypeBuilder.INSTANCE.buildEGenericType(instanceTypeName));
+          setInstanceTypeName(normalizedInstanceTypeName);
+          if (classLoader != null)
+          {
+            try
+            {
+              Class<?> instanceClass = classLoader.loadClass(getInstanceClassName());
+              setInstanceClassGen(instanceClass);
+            }
+            catch (Throwable throwable)
+            {
+              // Ignore.
+            }
+          }
+        }
+      }
+    }
+
+    @Override
+    public boolean isSetInstanceClassName()
+    {
+      initialize();
+      return super.isSetInstanceClassName();
+    }
+
+    @Override
+    public String getInstanceClassName()
+    {
+      initialize();
+      return super.getInstanceClassName();
+    }
+
+    @Override
+    public boolean isSetInstanceTypeName()
+    {
+      initialize();
+      return super.isSetInstanceTypeName();
+    }
+
+    @Override
+    public String getInstanceTypeName()
+    {
+      initialize();
+      return super.getInstanceTypeName();
+    }
+
+    @Override
+    public Class<?> getInstanceClass()
+    {
+      initialize();
+      return super.getInstanceClass();
+    }
+  }
+
+  private static class DeferredEReferenceImpl extends EReferenceImpl implements DeferredInitializer
+  {
+    private final XReference xReference;
+
+    private boolean needsInitialization;
+
+    public DeferredEReferenceImpl(XReference xReference)
+    {
+      this.xReference = xReference;
+    }
+
+    public void setNeedsInitialization(boolean needsInitialization)
+    {
+      this.needsInitialization = needsInitialization;
+    }
+
+    public void initialize()
+    {
+      if (needsInitialization)
+      {
+        needsInitialization = false;
+        GenFeature opposite = xReference.getOpposite();
+        if (opposite != null)
+        {
+          setEOpposite((EReference)opposite.getEcoreFeature());
+        }
+        for (GenFeature key : xReference.getKeys())
+        {
+          EStructuralFeature eAttribute = key.getEcoreFeature();
+          if (eAttribute instanceof EAttribute)
+          {
+            getEKeys().add((EAttribute)eAttribute);
+         }
+        }
+      }
+    }
+
+    @Override
+    public boolean eIsSet(int featureID)
+    {
+      switch (featureID)
+      {
+        case EcorePackage.EREFERENCE__EREFERENCE_TYPE:
+        case EcorePackage.EREFERENCE__EKEYS:
+          initialize();
+          break;
+      }
+
+      return super.eIsSet(featureID);
+    }
+
+    @Override
+    public EList<EAttribute> getEKeys()
+    {
+      initialize();
+      return super.getEKeys();
+    }
+
+    @Override
+    public EReference getEOpposite()
+    {
+      initialize();
+      return super.getEOpposite();
+    }
+
+    @Override
+    public EReference basicGetEOpposite()
+    {
+      initialize();
+      return super.basicGetEOpposite();
+    }
+  }
+
+  private static final class DeferredEGenericTypeImpl extends EGenericTypeImpl implements DeferredInitializer
+  {
+    private final XGenericType xGenericType;
+
+    private boolean needsInitialization;
+
+    private DeferredEGenericTypeImpl(XGenericType xGenericType)
+    {
+      this.xGenericType = xGenericType;
+    }
+
+    public void setNeedsInitialization(boolean needsInitialization)
+    {
+      this.needsInitialization = needsInitialization;
+    }
+
+    public void initialize()
+    {
+      if (needsInitialization)
+      {
+        GenBase type = xGenericType.getType();
+        // It's possible that we recursively reach this point again while resolving the type proxy.
+        // This does not cause stack overflow because it succeeds the next time, but there's no point in processing the type again if it's already been processed.
+        if (needsInitialization)
+        {
+          needsInitialization = false;
+          if (type != null)
+          {
+            if (type instanceof GenTypeParameter)
+            {
+              setETypeParameter(((GenTypeParameter)type).getEcoreTypeParameter());
+            }
+            else if (type instanceof GenClassifier)
+            {
+              setEClassifier(((GenClassifier)type).getEcoreClassifier());
+            }
+            else
+            {
+              setEClassifier(getERawType());
+            }
+          }
+        }
+      }
+    }
+
+    @Override
+    public EClassifier getERawType()
+    {
+      initialize();
+      return super.getERawType();
+    }
+
+    @Override
+    public EClassifier basicGetERawType()
+    {
+      initialize();
+      return super.basicGetERawType();
+    }
+
+    @Override
+    public EClassifier getEClassifier()
+    {
+      initialize();
+      return super.getEClassifier();
+    }
+
+    @Override
+    public EClassifier basicGetEClassifier()
+    {
+      initialize();
+      return super.basicGetEClassifier();
+    }
+
+    @Override
+    public ETypeParameter getETypeParameter()
+    {
+      initialize();
+      return super.getETypeParameter();
+    }
+
+    @Override
+    public boolean eIsSet(int featureID)
+    {
+      switch (featureID)
+      {
+        case EcorePackage.EGENERIC_TYPE__ERAW_TYPE:
+        case EcorePackage.EGENERIC_TYPE__ETYPE_PARAMETER:
+        case EcorePackage.EGENERIC_TYPE__ECLASSIFIER:
+          initialize();
+          break;
+      }
+
+      return super.eIsSet(featureID);
+    }
+
+    @Override
+    public String toString()
+    {
+      if (needsInitialization)
+      {
+        return "* needs initialization *";
+      }
+
+      return super.toString();
+    }
+  }
+
+  private static final class DeferredEAnnotationImpl extends EAnnotationImpl implements DeferredInitializer
+  {
+    private final XAnnotation xAnnotation;
+
+    private boolean needsInitialization;
+
+    private DeferredEAnnotationImpl(XAnnotation xAnnotation)
+    {
+      this.xAnnotation = xAnnotation;
+    }
+
+    public void setNeedsInitialization(boolean needsInitialization)
+    {
+      this.needsInitialization = needsInitialization;
+    }
+
+    public void initialize()
+    {
+      if (needsInitialization && xAnnotation != null)
+      {
+        needsInitialization = false;
+        XAnnotationDirective source = xAnnotation.getSource();
+        if (source != null)
+        {
+         setSource(source.getSourceURI());
+        }
+      }
+    }
+
+    @Override
+    public boolean eIsSet(int featureID)
+    {
+      switch (featureID)
+      {
+        case EcorePackage.EANNOTATION__SOURCE:
+          initialize();
+          break;
+      }
+
+      return super.eIsSet(featureID);
+    }
+
+    @Override
+    public String getSource()
+    {
+      initialize();
+      return super.getSource();
+    }
+  }
+}
\ No newline at end of file
