@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2012 Eclipse contributors and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  */
 package org.eclipse.emf.ecore.xcore.validation;
 
@@ -18,6 +18,9 @@ public final class XcoreIssueCodes
 
   public static final String CONTAINER_WITHOUT_OPPOSITE = ISSUE_CODE_PREFIX + "container_without_opposite";
 
+  public static final String XBASE_LIB_NOT_ON_CLASSPATH = ISSUE_CODE_PREFIX + "xbase_lib_not_on_classpath";
+  public static final String XCORE_LIB_NOT_ON_CLASSPATH = ISSUE_CODE_PREFIX + "xcore_lib_not_on_classpath";
+
   private XcoreIssueCodes()
   {
   }
