@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2002-2008 IBM Corporation, Embarcadero Technologies, and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  *
  * Contributors:
  *   IBM - Initial API and implementation
@@ -14,6 +14,7 @@ package org.eclipse.emf.ecore.xmi.impl;
 
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.StringReader;
 import java.io.UnsupportedEncodingException;
 import java.lang.reflect.Field;
 import java.lang.reflect.InvocationTargetException;
@@ -75,6 +76,7 @@ import org.xml.sax.InputSource;
 import org.xml.sax.Locator;
 import org.xml.sax.SAXException;
 import org.xml.sax.SAXParseException;
+import org.xml.sax.ext.Locator2;
 import org.xml.sax.helpers.DefaultHandler;
 
 
@@ -96,7 +98,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
   protected final static String NO_NAMESPACE_SCHEMA_LOCATION_ATTRIB = XMLResource.XSI_NS + ":" + XMLResource.NO_NAMESPACE_SCHEMA_LOCATION;
 
   protected final static boolean DEBUG_DEMANDED_PACKAGES = false;
-  
+
   protected static class MyStack<E> extends BasicEList<E>
   {
     private static final long serialVersionUID = 1L;
@@ -114,7 +116,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
 
     public final void push(E o)
     {
-      grow(size + 1);  
+      grow(size + 1);
       data[size++] = o;
     }
 
@@ -334,9 +336,21 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
   protected boolean isNamespaceAware;
   protected boolean suppressDocumentRoot;
   protected boolean laxWildcardProcessing;
+  /**
+   * @since 2.9
+   */
+  protected boolean usePackageNsURIAsLocation;
 
   /**
+   * @since 2.9
    */
+  protected XMLResource.MissingPackageHandler missingPackageHandler;
+
+  /**
+   * @since 2.35
+   */
+  protected boolean resolveEntities;
+
   public XMLHandler(XMLResource xmlResource, XMLHelper helper, Map<?, ?> options)
   {
     this.xmlResource = xmlResource;
@@ -365,7 +379,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
 
     eObjectToExtensionMap = xmlResource.getEObjectToExtensionMap();
     eObjectToExtensionMap.clear();
-    
+
     helper.setOptions(options);
 
     if (Boolean.TRUE.equals(options.get(XMLResource.OPTION_DISABLE_NOTIFY)))
@@ -386,14 +400,14 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
     Object extendedMetaDataOption = options.get(XMLResource.OPTION_EXTENDED_META_DATA);
     setExtendedMetaDataOption(extendedMetaDataOption);
 
-    recordUnknownFeature = Boolean.TRUE.equals(options.get(XMLResource.OPTION_RECORD_UNKNOWN_FEATURE));  
+    recordUnknownFeature = Boolean.TRUE.equals(options.get(XMLResource.OPTION_RECORD_UNKNOWN_FEATURE));
     if (recordUnknownFeature && extendedMetaData == null)
     {
       setExtendedMetaDataOption(Boolean.TRUE);
     }
-    
-    useNewMethods = Boolean.FALSE.equals(options.get(XMLResource.OPTION_USE_DEPRECATED_METHODS));  
-    
+
+    useNewMethods = Boolean.FALSE.equals(options.get(XMLResource.OPTION_USE_DEPRECATED_METHODS));
+
     XMLOptions xmlOptions = (XMLOptions)options.get(XMLResource.OPTION_XML_OPTIONS);
     if (xmlOptions != null)
     {
@@ -429,7 +443,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       mixedTargets.push(anyType.getMixed());
       text = new StringBuffer();
     }
-    
+
     anyType = (EClass)options.get(XMLResource.OPTION_ANY_TYPE);
     anySimpleType = (EClass)options.get(XMLResource.OPTION_ANY_SIMPLE_TYPE);
 
@@ -438,10 +452,10 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       anyType = XMLTypePackage.eINSTANCE.getAnyType();
       anySimpleType = XMLTypePackage.eINSTANCE.getSimpleAnyType();
     }
-    
+
     helper.setAnySimpleType(anySimpleType);
-    
-    @SuppressWarnings("unchecked") Map<EClassFeatureNamePair, EStructuralFeature> newEClassFeatureNamePairToEStructuralFeatureMap = 
+
+    @SuppressWarnings("unchecked") Map<EClassFeatureNamePair, EStructuralFeature> newEClassFeatureNamePairToEStructuralFeatureMap =
       (Map<EClassFeatureNamePair, EStructuralFeature>)options.get(XMLResource.OPTION_USE_XML_NAME_TO_FEATURE_MAP);
     eClassFeatureNamePairToEStructuralFeatureMap =  newEClassFeatureNamePairToEStructuralFeatureMap;
     if (eClassFeatureNamePairToEStructuralFeatureMap == null)
@@ -452,31 +466,31 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
     {
       isOptionUseXMLNameToFeatureSet = true;
     }
-    
+
     recordAnyTypeNSDecls = Boolean.TRUE.equals(options.get(XMLResource.OPTION_RECORD_ANY_TYPE_NAMESPACE_DECLARATIONS));
-    
+
     hrefAttribute = XMLResource.HREF;
-    
+
     if (Boolean.TRUE.equals(options.get(XMLResource.OPTION_USE_ENCODED_ATTRIBUTE_STYLE)))
     {
       hrefAttribute = null;
     }
-    
+
     if (Boolean.TRUE.equals(options.get(XMLResource.OPTION_DEFER_IDREF_RESOLUTION)))
     {
       helper.setCheckForDuplicates(deferIDREFResolution = true);
     }
-    
+
     if (Boolean.TRUE.equals(options.get(XMLResource.OPTION_CONFIGURATION_CACHE)))
     {
       useConfigurationCache = true;
     }
-   
+
     // The entity handler is the best place to resolve and deresolve URIs since it can do it there just once to produce the entity.
     // So most often the entity handler will be a URI handler as well and when used as a URI handler will be an identity handler.
     //
     uriHandler = (XMLResource.URIHandler)options.get(XMLResource.OPTION_URI_HANDLER);
-    resourceEntityHandler = (XMLResource.ResourceEntityHandler)options.get(XMLResource.OPTION_RESOURCE_ENTITY_HANDLER); 
+    resourceEntityHandler = (XMLResource.ResourceEntityHandler)options.get(XMLResource.OPTION_RESOURCE_ENTITY_HANDLER);
     if (resourceEntityHandler != null)
     {
       resourceEntityHandler.reset();
@@ -496,6 +510,10 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
     {
       laxWildcardProcessing = true;
     }
+
+    usePackageNsURIAsLocation = !Boolean.FALSE.equals(options.get(XMLResource.OPTION_USE_PACKAGE_NS_URI_AS_LOCATION));
+    missingPackageHandler = (XMLResource.MissingPackageHandler)options.get(XMLResource.OPTION_MISSING_PACKAGE_HANDLER);
+    resolveEntities = Boolean.TRUE.equals(options.get(XMLResource.OPTION_RESOLVE_ENTITIES));
   }
 
   protected void setExtendedMetaDataOption(Object extendedMetaDataOption)
@@ -504,7 +522,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
     {
       if (extendedMetaDataOption.equals(Boolean.TRUE))
       {
-        extendedMetaData = 
+        extendedMetaData =
           resourceSet == null ?
             ExtendedMetaData.INSTANCE :
             new BasicExtendedMetaData(resourceSet.getPackageRegistry());
@@ -553,11 +571,11 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       mixedTargets.push(anyType.getMixed());
       text = new StringBuffer();
     }
-    
-    // bug #126072 
-    @SuppressWarnings("unchecked") Map<EClassFeatureNamePair, EStructuralFeature> newEClassFeatureNamePairToEStructuralFeatureMap = 
+
+    // bug #126072
+    @SuppressWarnings("unchecked") Map<EClassFeatureNamePair, EStructuralFeature> newEClassFeatureNamePairToEStructuralFeatureMap =
       (Map<EClassFeatureNamePair, EStructuralFeature>)options.get(XMLResource.OPTION_USE_XML_NAME_TO_FEATURE_MAP);
-    eClassFeatureNamePairToEStructuralFeatureMap = 
+    eClassFeatureNamePairToEStructuralFeatureMap =
       newEClassFeatureNamePairToEStructuralFeatureMap;
     if (eClassFeatureNamePairToEStructuralFeatureMap == null)
     {
@@ -577,7 +595,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
     // So most often the entity handler will be a URI handler as well and when used as a URI handler will be an identity handler.
     //
     uriHandler = (XMLResource.URIHandler)options.get(XMLResource.OPTION_URI_HANDLER);
-    resourceEntityHandler = (XMLResource.ResourceEntityHandler)options.get(XMLResource.OPTION_RESOURCE_ENTITY_HANDLER); 
+    resourceEntityHandler = (XMLResource.ResourceEntityHandler)options.get(XMLResource.OPTION_RESOURCE_ENTITY_HANDLER);
     if (resourceEntityHandler != null)
     {
       resourceEntityHandler.reset();
@@ -593,7 +611,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
   {
     this.xmlResource = null;
     this.extendedMetaData = null;
-    // bug #126072 
+    // bug #126072
     eClassFeatureNamePair.eClass = null;
     eClassFeatureNamePairToEStructuralFeatureMap = null;
     if (isOptionUseXMLNameToFeatureSet && helper instanceof XMLHelperImpl)
@@ -604,7 +622,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
     {
       featuresToKinds = null;
     }
-    
+
     if (ecoreBuilder != null)
     {
         this.ecoreBuilder.setExtendedMetaData(null);
@@ -666,11 +684,11 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
 
   protected XMIException toXMIException(SAXParseException e)
   {
-    XMIException xmiException = 
+    XMIException xmiException =
       new XMIException
-        (e.getException() == null ? e : e.getException(), 
-         e.getSystemId() == null ? getLocation() : e.getSystemId(), 
-         e.getLineNumber(), 
+        (e.getException() == null ? e : e.getException(),
+         e.getSystemId() == null ? getLocation() : e.getSystemId(),
+         e.getLineNumber(),
          e.getColumnNumber());
     return xmiException;
   }
@@ -759,7 +777,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       handleCDATA();
     }
   }
-  
+
   //
   // Implement DTDHandler methods
   //
@@ -791,6 +809,11 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
   @Override
   public InputSource resolveEntity(String publicId, String systemId) throws SAXException
   {
+    if (!resolveEntities)
+    {
+      return new InputSource(new StringReader("")); //$NON-NLS-1$
+    }
+
     try
     {
       Map<Object, Object> options = new HashMap<Object, Object>();
@@ -813,12 +836,12 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       throw new SAXException(exception);
     }
   }
-  
+
   /**
    * Returns the xsi type attribute's value.
    */
   protected abstract String getXSIType();
-  
+
   /**
    * Process the XML attributes for the newly created object.
    */
@@ -826,7 +849,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
 
   /**
    * Process the XML namespace declarations.
-   * @deprecated since 2.2 
+   * @deprecated since 2.2
    */
   @Deprecated
   protected void handleNamespaceAttribs()
@@ -907,34 +930,51 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
   {
     if (locator != null)
     {
-      Class<?> locatorClass = locator.getClass();
-      try
+      if (locator instanceof Locator2)
       {
-        Method encodingMethod = locatorClass.getMethod("getEncoding");
-        String encoding = (String)encodingMethod.invoke(locator);
+        Locator2 locator2 = (Locator2)locator;
+        String encoding = locator2.getEncoding();
         if (encoding != null)
         {
           this.xmlResource.setEncoding(encoding);
         }
-    
-        Method versionMethod = locatorClass.getMethod("getXMLVersion");
-        String version = (String)versionMethod.invoke(locator);
+        String version = locator2.getXMLVersion();
         if (version != null)
         {
           this.xmlResource.setXMLVersion(version);
         }
       }
-      catch (NoSuchMethodException e)
+      else
       {
-        // Ignore.
-      }
-      catch (IllegalAccessException e)
-      {
-        // Ignore.
-      }
-      catch (InvocationTargetException e)
-      {
-        // Ignore.
+        Class<?> locatorClass = locator.getClass();
+        try
+        {
+          Method encodingMethod = locatorClass.getMethod("getEncoding");
+          String encoding = (String)encodingMethod.invoke(locator);
+          if (encoding != null)
+          {
+            this.xmlResource.setEncoding(encoding);
+          }
+  
+          Method versionMethod = locatorClass.getMethod("getXMLVersion");
+          String version = (String)versionMethod.invoke(locator);
+          if (version != null)
+          {
+            this.xmlResource.setXMLVersion(version);
+          }
+        }
+        catch (NoSuchMethodException e)
+        {
+          // Ignore.
+        }
+        catch (IllegalAccessException e)
+        {
+          // Ignore.
+        }
+        catch (InvocationTargetException e)
+        {
+          // Ignore.
+        }
       }
     }
   }
@@ -972,13 +1012,13 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
 
     elements.push(name);
     String prefix = "";
-       
+
     if (useNewMethods)
     {
       if (isRoot)
       {
         handleSchemaLocation();
-      } 
+      }
       prefix = helper.getPrefix((uri.length() == 0) ? null : uri);
       prefix = (prefix == null) ? "" : prefix;
     }
@@ -1029,7 +1069,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
    * Check if the values of the forward references have been set (they may
    * have been set due to a bidirectional reference being set).  If not, set them.
    * If this is called during end document processing, errors should be diagnosed.
-   * If it is called in the middle of a document, 
+   * If it is called in the middle of a document,
    * we need to clean up the forward reference lists to avoid processing resolved references again later.
    */
   protected void handleForwardReferences(boolean isEndDocument)
@@ -1054,7 +1094,17 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
         {
           // Try to resolve the proxy locally.
           //
-          EObject resolvedEObject = xmlResource.getEObject(proxy.eProxyURI().fragment());
+          EObject resolvedEObject = null;
+          
+          try
+          {
+            resolvedEObject = xmlResource.getEObject(proxy.eProxyURI().fragment());
+          }
+          catch (RuntimeException exception)
+          {
+            // Ignore exceptions, e.g., when a URI fragment is used but is ill-formed.
+          }
+          
           if (resolvedEObject != null)
           {
             // We won't need to process this again later.
@@ -1131,7 +1181,16 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
     for (Iterator<SingleReference> i = forwardSingleReferences.iterator(); i.hasNext(); )
     {
       SingleReference ref = i.next();
-      EObject obj = xmlResource.getEObject((String) ref.getValue());
+      EObject obj = null;
+      RuntimeException cause = null;
+      try
+      {
+        obj = xmlResource.getEObject((String) ref.getValue());
+      }
+      catch (RuntimeException exception)
+      {
+        cause = exception;
+      }
 
       if (obj != null)
       {
@@ -1145,12 +1204,12 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       }
       else if (isEndDocument)
       {
-        error
-          (new UnresolvedReferenceException
-            ((String) ref.getValue(),
-             getLocation(),
-             ref.getLineNumber(),
-             ref.getColumnNumber()));
+        UnresolvedReferenceException exception = new UnresolvedReferenceException(ref.getObject(), ref.getFeature(), (String) ref.getValue(), getLocation(), ref.getLineNumber(), ref.getColumnNumber());
+        if (cause != null)
+        {
+          exception.initCause(cause);
+        }
+        error(exception);
       }
     }
 
@@ -1163,20 +1222,30 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       for (int j = 0, l = values.length; j < l; j++)
       {
         String id = (String) values[j];
-        EObject obj = xmlResource.getEObject(id);
-        values[j] = obj;
+        EObject obj = null;
+        RuntimeException cause = null;
+        
+        try
+        {
+          obj = xmlResource.getEObject(id);
+          values[j] = obj;
+        }
+        catch (RuntimeException exception)
+        {
+          cause = exception;
+        }
 
         if (obj == null)
         {
           failure = true;
           if (isEndDocument)
           {
-            error
-              (new UnresolvedReferenceException
-                (id,
-                 getLocation(),
-                 ref.getLineNumber(),
-                 ref.getColumnNumber()));
+            UnresolvedReferenceException exception = new UnresolvedReferenceException(ref.getObject(), ref.getFeature(), id, getLocation(), ref.getLineNumber(), ref.getColumnNumber()); 
+            if (cause != null)
+            {
+              exception.initCause(cause);
+            }
+            error(exception);
           }
         }
       }
@@ -1211,7 +1280,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       extent.addAll(deferredExtent);
     }
 
-    // Pretend there is an xmlns="" because we really need to ensure that the null prefix 
+    // Pretend there is an xmlns="" because we really need to ensure that the null prefix
     // isn't used to denote something other than the null namespace.
     //
     if (usedNullNamespacePackage)
@@ -1222,7 +1291,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
     helper.popContext();
     handleForwardReferences(true);
 
-    if (disableNotify) 
+    if (disableNotify)
     {
       for (Iterator<?> i = EcoreUtil.getAllContents(xmlResource.getContents(), false); i.hasNext(); )
       {
@@ -1236,7 +1305,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       if (extent.size() == 1)
       {
         EObject root = extent.get(0);
-        recordNamespacesSchemaLocations(root);     
+        recordNamespacesSchemaLocations(root);
       }
 
       if (DEBUG_DEMANDED_PACKAGES)
@@ -1252,7 +1321,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       }
     }
   }
-  
+
   protected EMap<String, String> recordNamespacesSchemaLocations(EObject root)
   {
     EClass eClass = root.eClass();
@@ -1310,22 +1379,22 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
         eFactory = ePackage.getEFactoryInstance();
       }
     }
-    
+
     documentRoot= createDocumentRoot(prefix, uri, name, eFactory, top);
-    
+
     if (documentRoot != null) return documentRoot;
-    
+
     EObject newObject = null;
     if (useNewMethods)
     {
-      newObject = createObject(eFactory, helper.getType(eFactory, name) , false);     
+      newObject = createObject(eFactory, helper.getType(eFactory, name) , false);
     }
     else
     {
       newObject = createObjectFromFactory(eFactory, name);
     }
     newObject = validateCreateObjectFromFactory(eFactory, name, newObject, top);
-    
+
     if (top)
     {
       processTopObject(newObject);
@@ -1346,7 +1415,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
     }
     return newObject;
   }
-  
+
   protected EObject createDocumentRoot(String prefix, String uri, String name, EFactory eFactory, boolean top)
   {
     if (extendedMetaData != null && eFactory != null)
@@ -1370,10 +1439,10 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       {
         // EATM Kind of hacky.
         String typeName = extendedMetaData.getName(eClass);
-        @SuppressWarnings("deprecation") EObject newObject = 
-          useNewMethods ? 
-            createObject(eFactory, eClass, true) : 
-              helper.createObject(eFactory, typeName);          
+        @SuppressWarnings("deprecation") EObject newObject =
+          useNewMethods ?
+            createObject(eFactory, eClass, true) :
+              helper.createObject(eFactory, typeName);
         validateCreateObjectFromFactory(eFactory, typeName, newObject);
         if (top)
         {
@@ -1478,7 +1547,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       {
         extent.addUnique(object);
       }
-          
+
       if (extendedMetaData != null && !mixedTargets.isEmpty())
       {
         FeatureMap featureMap = mixedTargets.pop();
@@ -1520,14 +1589,14 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
         objects.pop();
         mixedTargets.pop();
       }
-      else 
+      else
       {
         EObject object = objects.popEObject();
-        if (mixedTargets.peek() != null && 
-              (object.eContainer() != null || 
+        if (mixedTargets.peek() != null &&
+              (object.eContainer() != null ||
                  suppressDocumentRoot ||
-                 recordUnknownFeature && 
-                   (eObjectToExtensionMap.containsValue(object) || ((InternalEObject)object).eDirectResource() != null))) 
+                 recordUnknownFeature &&
+                   (eObjectToExtensionMap.containsValue(object) || ((InternalEObject)object).eDirectResource() != null)))
         {
           handleMixedText();
           mixedTargets.pop();
@@ -1541,7 +1610,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
           mixedTargets.pop();
           text = null;
         }
-      } 
+      }
     }
     else if (isIDREF)
     {
@@ -1689,7 +1758,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
     }
     urisToLocations.put(null, uri);
   }
-  
+
   protected void processSchemaLocations(String prefix, String name)
   {
     if (urisToLocations != null)
@@ -1795,7 +1864,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       else if (extendedMetaData != null)
       {
         EReference eReference = (EReference)feature;
-        boolean isContainment = eReference.isContainment();      
+        boolean isContainment = eReference.isContainment();
         if (!isContainment && !eReference.isResolveProxies() && extendedMetaData.getFeatureKind(feature) != ExtendedMetaData.UNSPECIFIED_FEATURE)
         {
           isIDREF = true;
@@ -1830,7 +1899,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
           }
         }
       }
-      else 
+      else
       {
         createObject(peekObject, feature);
       }
@@ -1890,7 +1959,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
             }
           }
         }
-       
+
         handleUnknownFeature(prefix, name, true, peekObject, null);
       }
     }
@@ -1922,12 +1991,12 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
 
   protected String getLocation()
   {
-    return 
+    return
       locator != null && locator.getSystemId() != null ?
         locator.getSystemId() :
         resourceURI == null ? "" : resourceURI.toString();
   }
-  
+
   protected AnyType getExtension(EObject peekObject)
   {
     AnyType anyType = eObjectToExtensionMap.get(peekObject);
@@ -1990,7 +2059,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
          getLineNumber(),
          getColumnNumber()));
   }
-  
+
   public void error(XMIException e)
   {
     xmlResource.getErrors().add(e);
@@ -2089,10 +2158,10 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
     else
     {
       obj = createObjectFromFactory(eFactory, typeName);
-      
+
     }
     obj = validateCreateObjectFromFactory(eFactory, typeName, obj, feature);
-    
+
     if (obj != null)
     {
       if (contextFeature == null)
@@ -2152,9 +2221,9 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
           factory = eClass.getEPackage().getEFactoryInstance();
         }
         obj = createObjectFromFactory(factory, typeName);
-      }   
+      }
     }
-    
+
     obj = validateCreateObjectFromFactory(factory, typeName, obj, feature);
 
     if (obj != null)
@@ -2191,7 +2260,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
 
     return newObject;
   }
-  
+
   protected EObject createObject(EFactory eFactory, EClassifier type, boolean documentRoot)
   {
     EObject newObject = helper.createObject(eFactory, type);
@@ -2260,7 +2329,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
             if (!(peekObject instanceof AnyType))
             {
               AnyType anyType = getExtension(objects.peekEObject());
-              EStructuralFeature entryFeature = 
+              EStructuralFeature entryFeature =
                 extendedMetaData.demandFeature(extendedMetaData.getNamespace(feature), extendedMetaData.getName(feature), true);
               anyType.getAny().add(entryFeature, newObject);
               contextFeature = entryFeature;
@@ -2271,7 +2340,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
           {
             String namespace = extendedMetaData.getNamespace(feature);
             String name = extendedMetaData.getName(feature);
-            EStructuralFeature wildcardFeature = 
+            EStructuralFeature wildcardFeature =
               extendedMetaData.getElementWildcardAffiliation((objects.peekEObject()).eClass(), namespace, name);
             if (wildcardFeature != null)
             {
@@ -2296,7 +2365,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       // processing unknown feature with xsi:type (xmi:type)
       if (recordUnknownFeature || processAnyXML)
       {
-        
+
         EObject result = null;
         String namespace = extendedMetaData.getNamespace(factory.getEPackage());
         if (namespace == null)
@@ -2317,7 +2386,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
         if (!(peekObject instanceof AnyType))
         {
           AnyType anyType = getExtension(peekObject);
-          EStructuralFeature entryFeature = 
+          EStructuralFeature entryFeature =
             extendedMetaData.demandFeature(extendedMetaData.getNamespace(feature), extendedMetaData.getName(feature), true);
           anyType.getAny().add(entryFeature, result);
           contextFeature = entryFeature;
@@ -2328,7 +2397,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       {
         String namespace = extendedMetaData.getNamespace(feature);
         String name = extendedMetaData.getName(feature);
-        EStructuralFeature wildcardFeature = 
+        EStructuralFeature wildcardFeature =
           extendedMetaData.getElementWildcardAffiliation((objects.peekEObject()).eClass(), namespace, name);
         if (wildcardFeature != null)
         {
@@ -2361,7 +2430,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
     }
 
     validateCreateObjectFromFactory(factory, typeName, newObject);
-    
+
     return newObject;
   }
 
@@ -2447,7 +2516,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       return null;
     }
 
-    EPackage ePackage = 
+    EPackage ePackage =
       extendedMetaData == null ?
         packageRegistry.getEPackage(uriString) :
         extendedMetaData.getPackage(uriString);
@@ -2477,6 +2546,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
         }
       }
 
+      URI nsURI = uri;
       if (urisToLocations != null)
       {
         URI locationURI = urisToLocations.get(uriString);
@@ -2522,7 +2592,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
             }
           }
         }
-        else if (!XMLResource.XML_SCHEMA_URI.equals(uriString))
+        else if (!XMLResource.XML_SCHEMA_URI.equals(uriString) && (usePackageNsURIAsLocation || uri != nsURI))
         {
           try
           {
@@ -2554,10 +2624,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
         else
         {
           List<EObject> contents = resource.getContents();
-          if (!contents.isEmpty())
-          {
-            content = contents.get(0);
-          }
+          content = EcoreUtil.getObjectByType(contents, EcorePackage.Literals.EPACKAGE);
         }
 
         if (content instanceof EPackage)
@@ -2613,7 +2680,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       {
         String namespace = extendedMetaData.getNamespace(contextFeature);
         String name = extendedMetaData.getName(contextFeature);
-        EStructuralFeature wildcardFeature = 
+        EStructuralFeature wildcardFeature =
           extendedMetaData.getElementWildcardAffiliation((objects.peekEObject()).eClass(), namespace, name);
         if (wildcardFeature != null)
         {
@@ -2630,7 +2697,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       }
     }
 
-    return null;
+    return missingPackageHandler != null ? missingPackageHandler.getPackage(uriString) : null;
   }
 
   protected URIConverter getURIConverter()
@@ -2805,7 +2872,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
           }
           isFirstID = false;
         }
-  
+
         if (mustAddOrNotOppositeIsMany)
         {
           EObject resolvedEObject = xmlResource.getEObject(id);
@@ -2817,7 +2884,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
             continue;
           }
         }
-      } 
+      }
 
       if (mustAdd)
       {
@@ -2882,9 +2949,9 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       {
         uri = uriHandler.resolve(uri);
       }
-      else if (resolve && 
-            uri.isRelative() && 
-            uri.hasRelativePath() && 
+      else if (resolve &&
+            uri.isRelative() &&
+            uri.hasRelativePath() &&
             (extendedMetaData == null ?
               !packageRegistry.containsKey(uri.trimFragment().toString()) :
               extendedMetaData.getPackage(uri.trimFragment().toString()) == null))
@@ -2932,11 +2999,11 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
     public boolean equals(Object that)
     {
       EClassFeatureNamePair typedThat = (EClassFeatureNamePair)that;
-      return  
-        typedThat.eClass == eClass && 
+      return
+        typedThat.eClass == eClass &&
         typedThat.isElement == isElement &&
         typedThat.featureName.equals(featureName) &&
-        (typedThat.namespaceURI != null ? typedThat.namespaceURI.equals(namespaceURI): namespaceURI == null);         
+        (typedThat.namespaceURI != null ? typedThat.namespaceURI.equals(namespaceURI): namespaceURI == null);
     }
 
     @Override
@@ -2987,8 +3054,8 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
       {
         if (extendedMetaData != null)
         {
-          EStructuralFeature wildcardFeature = 
-            isElement ? 
+          EStructuralFeature wildcardFeature =
+            isElement ?
               extendedMetaData.getElementWildcardAffiliation(eClass, uri, name) :
               extendedMetaData.getAttributeWildcardAffiliation(eClass, uri, name);
           if (wildcardFeature != null)
@@ -3008,7 +3075,7 @@ public abstract class XMLHandler extends DefaultHandler implements XMLDefaultHan
         }
         else
         {
-          // EATM Call the deprecated method which does the same thing 
+          // EATM Call the deprecated method which does the same thing
           // but might have an override in older code.
           result = getFeature(object, prefix, name);
         }
