@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2002-2009 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  *
  * Contributors:
  *   IBM - Initial API and implementation
@@ -17,6 +17,7 @@ import org.eclipse.emf.common.notify.NotificationChain;
 import org.eclipse.emf.common.util.EList;
 import org.eclipse.emf.common.util.URI;
 import org.eclipse.emf.ecore.resource.Resource;
+import org.eclipse.emf.ecore.util.ExtendedMetaData;
 
 
 /**
@@ -52,6 +53,12 @@ public interface InternalEObject extends EObject
    * The index is used only for {@link ETypedElement#isMany() many-valued} features;
    * it represents the position within the list.
    * </p>
+   * <p>
+   * Given given an <code>eObject</code> present in the <code>eFeature</code> of some other {@link InternalEObject} <code>x</code>, the following condition must hold:
+   * <pre>
+   *   x.eObjectForURIFragmentSegment(x.eURIFragmentSegment(eFeature, eObject)) == eObject
+   * </pre>
+   * </p>
    * @param eFeature the feature relating the given object to this object, or <code>null</code>.
    * @param eObject the object to be identified.
    * @return the fragment segment that resolves to the given object in this object's given feature.
@@ -63,7 +70,7 @@ public interface InternalEObject extends EObject
    * <p>
    * The fragment segment encoding will typically be of the form returned by {@link #eURIFragmentSegment eURIFragmentSegment}.
    * @param uriFragmentSegment a fragment segment.
-   * @return the fragment segment that resolves to the given object in this object's given feature.
+   * @return the object resolved by the fragment segment.
    */
   EObject eObjectForURIFragmentSegment(String uriFragmentSegment);
 
@@ -215,7 +222,6 @@ public interface InternalEObject extends EObject
    * Set the store associated with this object.
    * Most objects will <b>not</b> support this.
    * @param store the store to associate with this object.
-   * @throws UnsupportedOperationException
    */
   void eSetStore(EStore store);
 
@@ -413,6 +419,21 @@ public interface InternalEObject extends EObject
    * @param resolve whether to resolve.
    * @param coreType whether to return the core type value or the API type value.
    * @return the value of the given feature of the object.
+   * @exception IllegalArgumentException 
+   * if the feature is not one the {@link #eClass meta class}'s 
+   * {@link EClass#getEAllStructuralFeatures features}
+   * and is also not {@link ExtendedMetaData#getAffiliation(EClass, EStructuralFeature) affiliated} with one of the meta class's features.
+   * <p>
+   * Note that for high-performance generated model implementation classes,
+   * full checking whether the feature is among of the meta class's features
+   * is performed only if assertions are enabled for the JVM.
+   * As such,
+   * the return value for an invalid feature,
+   * in the absence of enabled assertions,
+   * is undefined,
+   * though typically it will be the value of the {@link EClass#getEStructuralFeature(int) meta class's feature}
+   * with the same {@link EStructuralFeature#getFeatureID() ID} as the given feature.
+   * </p>
    * @see EObject#eGet(EStructuralFeature, boolean)
    */
   public Object eGet(EStructuralFeature eFeature, boolean resolve, boolean coreType);
@@ -443,7 +464,7 @@ public interface InternalEObject extends EObject
 
   /**
    * Does the equivalent of <code>eObject.eInvoke(eObject.eClass().getEOperation(featureID), arguments)</code>.
-   * @see #eInvoke(EOperation, EList<?>)
+   * @see #eInvoke(EOperation, EList)
    * @since 2.6
    */
   Object eInvoke(int operationID, EList<?> arguments) throws InvocationTargetException;
