@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2002-2007 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  *
  * Contributors:
  *   IBM - Initial API and implementation
@@ -22,6 +22,7 @@ import java.io.OutputStreamWriter;
 import java.io.Reader;
 import java.io.StringReader;
 import java.io.Writer;
+import java.net.SocketTimeoutException;
 import java.util.Map;
 import java.util.Set;
 import java.util.regex.Matcher;
@@ -84,6 +85,17 @@ public interface URIConverter
    */
   String RESPONSE_URI = "URI";
 
+  /**
+   * An option to pass a timeout value, i.e., a non-negative <code>Integer</code>, to the URI converter's methods.
+   * If the operation cannot be completed within the specified number of milliseconds
+   * and the {@link #getURIHandler(URI) handler} for the URI supports timeouts,
+   * an {@link IOException} is thrown,
+   * e.g., a URI with <code>http</code> scheme will throw {@link SocketTimeoutException}.
+   * The default value is <code>0</code>, i.e., infinite timeout.
+   * @since 2.9
+   */
+  String OPTION_TIMEOUT = "TIMEOUT";
+
   /**
    * Returns the normalized form of the URI.
    * <p>
@@ -361,7 +373,7 @@ public interface URIConverter
     @Override
     public synchronized void reset() throws IOException
     {
-      super.reset();
+      buffer = null;
       reader.reset();
     }
     
@@ -375,7 +387,7 @@ public interface URIConverter
       {
         super(size);
         characters = new char [size];
-        writer = new OutputStreamWriter(this, encoding);
+        writer = encoding == null ? new OutputStreamWriter(this) : new OutputStreamWriter(this, encoding);
       }
       
       public int read() throws IOException
@@ -573,7 +585,6 @@ public interface URIConverter
   {
     /**
      * Encrypts the specified output stream.
-     * @param outputStream
      * @return an encrypted output stream
      */
     OutputStream encrypt(OutputStream outputStream) throws Exception;
@@ -588,7 +599,6 @@ public interface URIConverter
   
     /**
      * Decrypts the specified input stream.
-     * @param inputStream
      * @return a decrypted input stream
      */
     InputStream decrypt(InputStream inputStream) throws Exception;
