@@ -10,10 +10,12 @@
  */
 package org.eclipse.emf.ecore.resource.impl;
 
+
 import java.io.FilterOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.nio.charset.StandardCharsets;
 
 import javax.crypto.Cipher;
 import javax.crypto.CipherInputStream;
@@ -24,6 +26,7 @@ import javax.crypto.spec.DESKeySpec;
 
 import org.eclipse.emf.ecore.resource.URIConverter;
 
+
 /**
  * <p>EMF implementation for the {@link org.eclipse.emf.ecore.resource.URIConverter.Cipher} interface using 
  * the DES encryption algorithm.</p>  
@@ -40,46 +43,47 @@ import org.eclipse.emf.ecore.resource.URIConverter;
 public class DESCipherImpl implements URIConverter.Cipher
 {
   protected static final String ENCRYPTION_SCHEME = "DES";
+
   protected static final String UNICODE_FORMAT = "UTF-8";
 
   protected String stringKey;
+
   protected SecretKey key;
-  
-  
+
   public DESCipherImpl()
   {
     this(null);
   }
-  
+
   public DESCipherImpl(String key)
   {
     this.stringKey = key;
   }
-  
+
   public OutputStream encrypt(OutputStream outputStream) throws Exception
   {
     Cipher cipher = Cipher.getInstance(ENCRYPTION_SCHEME);
     cipher.init(Cipher.ENCRYPT_MODE, getKey());
-    
+
     // The CipherOutputStream shoudln't close the underlying stream
     //
     outputStream = new FilterOutputStream(outputStream)
-    {
-      @Override
-      public void close() throws IOException
       {
-        // Do nothing
-      }
+        @Override
+        public void close() throws IOException
+        {
+          // Do nothing
+        }
 
-      @Override
-      public void write(byte[] b, int off, int len) throws IOException
-      {
-        out.write(b, off, len);
-      }
-    };
+        @Override
+        public void write(byte[] b, int off, int len) throws IOException
+        {
+          out.write(b, off, len);
+        }
+      };
     return new CipherOutputStream(outputStream, cipher);
   }
-  
+
   public void finish(OutputStream outputStream) throws Exception
   {
     outputStream.close();
@@ -91,7 +95,7 @@ public class DESCipherImpl implements URIConverter.Cipher
     cipher.init(Cipher.DECRYPT_MODE, getKey());
     return new CipherInputStream(inputStream, cipher);
   }
-  
+
   public void finish(InputStream inputStream) throws Exception
   {
     // Do nothing.
@@ -102,7 +106,7 @@ public class DESCipherImpl implements URIConverter.Cipher
     if (key == null)
     {
       SecretKeyFactory keyFactory = SecretKeyFactory.getInstance(ENCRYPTION_SCHEME);
-      DESKeySpec keySpec = new DESKeySpec(stringKey.getBytes(UNICODE_FORMAT));
+      DESKeySpec keySpec = new DESKeySpec(stringKey.getBytes(StandardCharsets.UTF_8));
       key = keyFactory.generateSecret(keySpec);
     }
     return key;
