@@ -41,12 +41,12 @@ import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
+import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
-import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
@@ -268,6 +268,8 @@ public class FeatureEditorDialog extends Dialog
     choiceLabelGridData.horizontalAlignment = SWT.FILL;
     choiceLabel.setLayoutData(choiceLabelGridData);
 
+    Rectangle bounds = parent.getMonitor().getBounds();
+    
     // We use multi even for a single line because we want to respond to the enter key.
     //
     int style = multiLine ?
@@ -277,7 +279,7 @@ public class FeatureEditorDialog extends Dialog
     if (choiceText != null)
     {
       GridData choiceTextGridData = new GridData();
-      choiceTextGridData.widthHint = Display.getCurrent().getBounds().width / 5;
+      choiceTextGridData.widthHint = bounds.width / 5;
       choiceTextGridData.verticalAlignment = SWT.BEGINNING;
       choiceTextGridData.horizontalAlignment = SWT.FILL;
       choiceTextGridData.grabExcessHorizontalSpace = true;
@@ -297,8 +299,8 @@ public class FeatureEditorDialog extends Dialog
     if (choiceTable != null)
     {
       GridData choiceTableGridData = new GridData();
-      choiceTableGridData.widthHint = Display.getCurrent().getBounds().width / 5;
-      choiceTableGridData.heightHint = Display.getCurrent().getBounds().height / 3;
+      choiceTableGridData.widthHint = bounds.width / 5;
+      choiceTableGridData.heightHint = bounds.height / 3;
       choiceTableGridData.verticalAlignment = SWT.FILL;
       choiceTableGridData.horizontalAlignment = SWT.FILL;
       choiceTableGridData.grabExcessHorizontalSpace= true;
@@ -365,10 +367,7 @@ public class FeatureEditorDialog extends Dialog
     addButtonGridData.verticalAlignment = SWT.FILL;
     addButtonGridData.horizontalAlignment = SWT.FILL;
     addButton.setLayoutData(addButtonGridData);
-    if (valueHandler != null)
-    {
-      addButton.setEnabled(valueHandler.isValid("") == null);
-    }
+    addButton.setEnabled(valueHandler != null && valueHandler.isValid("") == null);
 
     final Button removeButton = new Button(controlButtons, SWT.PUSH);
     removeButton.setText(EMFEditUIPlugin.INSTANCE.getString("_UI_Remove_label"));
@@ -376,6 +375,7 @@ public class FeatureEditorDialog extends Dialog
     removeButtonGridData.verticalAlignment = SWT.FILL;
     removeButtonGridData.horizontalAlignment = SWT.FILL;
     removeButton.setLayoutData(removeButtonGridData);
+    removeButton.setEnabled(false);
 
     Label spaceLabel = new Label(controlButtons, SWT.NONE);
     GridData spaceLabelGridData = new GridData();
@@ -388,6 +388,7 @@ public class FeatureEditorDialog extends Dialog
     upButtonGridData.verticalAlignment = SWT.FILL;
     upButtonGridData.horizontalAlignment = SWT.FILL;
     upButton.setLayoutData(upButtonGridData);
+    upButton.setEnabled(false);
 
     final Button downButton = new Button(controlButtons, SWT.PUSH);
     downButton.setText(EMFEditUIPlugin.INSTANCE.getString("_UI_Down_label"));
@@ -395,6 +396,7 @@ public class FeatureEditorDialog extends Dialog
     downButtonGridData.verticalAlignment = SWT.FILL;
     downButtonGridData.horizontalAlignment = SWT.FILL;
     downButton.setLayoutData(downButtonGridData);
+    downButton.setEnabled(false);
 
     Composite featureComposite = new Composite(contents, SWT.NONE);
     {
@@ -420,8 +422,8 @@ public class FeatureEditorDialog extends Dialog
 
     final Table featureTable = new Table(featureComposite, SWT.MULTI | SWT.BORDER);
     GridData featureTableGridData = new GridData();
-    featureTableGridData.widthHint = Display.getCurrent().getBounds().width / 5;
-    featureTableGridData.heightHint = Display.getCurrent().getBounds().height / 3;
+    featureTableGridData.widthHint = bounds.width / 5;
+    featureTableGridData.heightHint = bounds.height / 3;
     featureTableGridData.verticalAlignment = SWT.FILL;
     featureTableGridData.horizontalAlignment = SWT.FILL;
     featureTableGridData.grabExcessHorizontalSpace= true;
@@ -462,12 +464,15 @@ public class FeatureEditorDialog extends Dialog
           // Up is enabled only if something will actually be moved up.
           //
           boolean upEnabled = false;
-          int upIndex = Math.max(selectionIndices[0] - 1, 0);
-          for (int i = 0; i < selectionIndices.length; ++i)
+          if (selectionIndices.length > 0)
           {
-            if (upIndex++ != selectionIndices[i])
+            int upIndex = Math.max(selectionIndices[0] - 1, 0);
+            for (int i = 0; i < selectionIndices.length; ++i)
             {
-              upEnabled = true;
+              if (upIndex++ != selectionIndices[i])
+              {
+                upEnabled = true;
+              }
             }
           }
           upButton.setEnabled(upEnabled);
@@ -475,12 +480,15 @@ public class FeatureEditorDialog extends Dialog
           // Down is enabled only if something will actually be moved up.
           //
           boolean downEnabled = false;
-          int downIndex = Math.min(selectionIndices[selectionIndices.length - 1] + 1, featureTable.getItemCount() - 1);
-          for (int i = selectionIndices.length - 1; i >= 0; --i)
+          if (selectionIndices.length > 0)
           {
-            if (downIndex-- !=  selectionIndices[i])
+            int downIndex = Math.min(selectionIndices[selectionIndices.length - 1] + 1, featureTable.getItemCount() - 1);
+            for (int i = selectionIndices.length - 1; i >= 0; --i)
             {
-              downEnabled = true;
+              if (downIndex-- !=  selectionIndices[i])
+              {
+                downEnabled = true;
+              }
             }
           }
           downButton.setEnabled(downEnabled);
@@ -772,8 +780,8 @@ public class FeatureEditorDialog extends Dialog
           if (!children.isEmpty())
           {
             featureTable.setSelection(selectionIndices[0] == 0 ? 0 : selectionIndices[0] - 1);
-            featureTable.notifyListeners(SWT.Selection, null);
           }
+          featureTable.notifyListeners(SWT.Selection, null);
 
           // If there is a choice table...
           //
