@@ -114,11 +114,6 @@ public class DiagnosticDecorator extends CellLabelProvider implements ILabelDeco
             escape = false;
             break;
           }
-          case '\003':
-          {
-            escape = true;
-            break;
-          }
           case ' ':
           {
             result.append("&#160;");
@@ -141,6 +136,10 @@ public class DiagnosticDecorator extends CellLabelProvider implements ILabelDeco
           }
         }
       }
+      else if (character == '\003')
+      {
+        escape = true;
+      }
       else
       {
         result.append(character);
@@ -161,7 +160,7 @@ public class DiagnosticDecorator extends CellLabelProvider implements ILabelDeco
 
   /**
    * Cleans up the escaping and HTML tags inserted by the {@link LiveValidator live validator}.
-   * It can be safely called on text not produces by the live validator because it only transformed {@link #enquote(String) enquoted} content.
+   * It can be safely called on text not produced by the live validator because it only transformed {@link #enquote(String) enquoted} content.
    */
   public static String strip(String content)
   {
@@ -174,7 +173,7 @@ public class DiagnosticDecorator extends CellLabelProvider implements ILabelDeco
       {
         result.append(content.substring(start, matcher.start()));
         String label = matcher.group(1);
-        result.append(label.replace("&lt;", "<").replace("&amp;", "&"));
+        result.append(label.replace("&lt;", "<").replace("&amp;", "&").replace("&#160;", " "));
         start = matcher.end();
       }
       while (matcher.find());
@@ -1112,6 +1111,7 @@ public class DiagnosticDecorator extends CellLabelProvider implements ILabelDeco
 
   private static final Map<EditingDomain, LiveValidator> LIVE_VALIDATORS = new HashMap<EditingDomain, LiveValidator>();
 
+  private int limit = getLimit();
   protected DiagnosticAdapter diagnosticAdapter;
   protected EditingDomain editingDomain;
   protected LiveValidator liveValidator;
@@ -1695,6 +1695,10 @@ public class DiagnosticDecorator extends CellLabelProvider implements ILabelDeco
     {
       child = children.get(index);
       buildMoreToolTipText(moreResults, labelProvider, child);
+      if (moreResults.length() > limit)
+      {
+        break;
+      }
     }
     if (moreResults.length() != 0)
     {
@@ -1802,6 +1806,10 @@ public class DiagnosticDecorator extends CellLabelProvider implements ILabelDeco
     {
       child = children.get(index);
       buildMoreToolTipText(result, labelProvider, child);
+      if (result.length() > limit)
+      {
+        break;
+      }
     }
   }
 
@@ -1826,4 +1834,26 @@ public class DiagnosticDecorator extends CellLabelProvider implements ILabelDeco
 
     super.dispose();
   }
+
+  private static int getLimit()
+  {
+    String property = System.getProperty("org.eclipse.emf.common.util.Diagnostic.limit");
+    if (property != null)
+    {
+      try
+      {
+        // Allow for 100 lines of text per diagnostic.
+        int result = Integer.parseInt(property) + 100;
+        if (result > 0)
+        {
+          return result;
+        }
+      }
+      catch (RuntimeException exception)
+      {
+        //$FALL-THROUGH$
+      }
+    }
+    return 10000;
+  }
 }
