@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2002-2006 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  * 
  * Contributors: 
  *   IBM - Initial API and implementation
@@ -237,7 +237,6 @@ import org.eclipse.emf.edit.domain.EditingDomain;
  *      }
  *    };
  * </pre>
- *
  */
 public class ItemProvider
   implements 
@@ -246,6 +245,7 @@ public class ItemProvider
     IItemLabelProvider, 
     IItemColorProvider,
     IItemFontProvider,
+    IItemStyledLabelProvider,
     IStructuredItemContentProvider, 
     ITreeItemContentProvider, 
     IUpdateableItemParent
@@ -275,6 +275,12 @@ public class ItemProvider
    */
   protected Object background;
 
+  /**
+   * This is the text returned by {@link IItemStyledLabelProvider#getStyledText getStyledText(Object)}.
+   * @since 2.10
+   */
+  protected Object styledText;
+
   /**
    * This is the parent returned by {@link ITreeItemContentProvider#getParent getParent(Object)}.
    */
@@ -360,7 +366,7 @@ public class ItemProvider
 
     public boolean isLabelUpdate()
     {
-      return isContentRefresh;
+      return isLabelUpdate;
     }
   }
 
@@ -1026,4 +1032,48 @@ public class ItemProvider
   {
     return UnexecutableCommand.INSTANCE;
   }
+
+  /**
+   * This implements {@link IItemStyledLabelProvider#getStyledText(Object) IItemStyledLabelProvider.getStyledText} 
+   * by returning {@link #styledText}.
+   * @since 2.10
+   */
+  public Object getStyledText(Object object) 
+  {
+    if (styledText == null) 
+    {
+      return new StyledString(getText(object));
+    }
+    return styledText;
+  }
+
+  /**
+   * This delegates to {@link #getStyledText(Object) getStyledText(this)}.
+   * @since 2.10
+   */
+  public Object getStyledText() 
+  {
+    return getStyledText(this);
+  }
+
+  /**
+   * This allows {@link #styledText} to be set.
+   * If there is a domain notifier, it fires the appropriate domain event.
+   * @since 2.10
+   */
+  public void setStyledText(Object object, Object styledText)
+  {
+    this.styledText = styledText;
+    
+    fireNotifyChanged(new ItemProviderNotification(Notification.SET, null, styledText, Notification.NO_INDEX, false, false, true));
+  }
+
+  /**
+   * This delegates to {@link #setStyledText(Object, Object) setStyledText(this, styledText)}.
+   * @since 2.10
+   */
+  public void setStyledText(Object styledText)
+  {
+	  setStyledText(this, styledText);
+  }
 }
