@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2005-2008 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  * 
  * Contributors: 
  *   IBM - Initial API and implementation
@@ -25,6 +25,7 @@ import org.eclipse.emf.codegen.ecore.genmodel.GenBase;
 import org.eclipse.emf.codegen.ecore.genmodel.GenModel;
 import org.eclipse.emf.codegen.ecore.genmodel.GenModelPackage;
 import org.eclipse.emf.codegen.ecore.genmodel.GenPackage;
+import org.eclipse.emf.codegen.ecore.genmodel.util.GenModelUtil;
 import org.eclipse.emf.common.EMFPlugin;
 import org.eclipse.emf.common.util.AbstractTreeIterator;
 import org.eclipse.emf.common.util.BasicDiagnostic;
@@ -494,8 +495,7 @@ public abstract class ModelExporter extends ModelConverter
   
   public void loadGenModel(URI uri) throws DiagnosticException
   {
-    setGenModel(uri == null ? null :
-      (GenModel)createResourceSet().getResource(uri, true).getContents().get(0));
+    setGenModel(uri == null ? null : GenModelUtil.getGenModel(createResourceSet().getResource(uri, true)));
   }
   
   public EPackageExportInfo getEPackageExportInfo(EPackage ePackage)
@@ -791,7 +791,8 @@ public abstract class ModelExporter extends ModelConverter
     {
       if (genModelAnnotation != null)
       {
-        changed |= genModelAnnotation.getDetails().remove(GENANNOTATION_KEY_DIRECTORY_URI);
+        String oldValue = genModelAnnotation.getDetails().removeKey(GENANNOTATION_KEY_DIRECTORY_URI);
+        changed |= oldValue != null;
       }
     }
     else
