@@ -1,9 +1,9 @@
 /**
- * Copyright (c) 2002-2010 IBM Corporation and others.
+ * Copyright (c) 2002-2012 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  *
  * Contributors:
  *   IBM - Initial API and implementation
@@ -801,6 +801,12 @@ public class BasicEMap<K, V> implements EMap<K, V>, Serializable
     {
       return BasicEMap.this.hashCode();
     }
+
+    @Override
+    public String toString()
+    {
+      return BasicEMap.this.toString();
+    }
   }
 
   /*
@@ -1662,7 +1668,7 @@ public class BasicEMap<K, V> implements EMap<K, V>, Serializable
   @Override
   public boolean equals(Object object)
   {
-    if (object instanceof EMap<?, ?>)
+    if (object instanceof List<?>)
     {
       return delegateEList.equals(object);
     }
