@@ -193,6 +193,7 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public EList<EStructuralFeature> getEStructuralFeatures()
   {
     if (eStructuralFeatures == null)
@@ -1601,6 +1602,7 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public boolean isAbstract()
   {
     return (eFlags & ABSTRACT_EFLAG) != 0;
@@ -1611,6 +1613,7 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public void setAbstract(boolean newAbstract)
   {
     boolean oldAbstract = (eFlags & ABSTRACT_EFLAG) != 0;
@@ -1624,6 +1627,7 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public boolean isInterface()
   {
     return (eFlags & INTERFACE_EFLAG) != 0;
@@ -1634,6 +1638,7 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public void setInterface(boolean newInterface)
   {
     boolean oldInterface = (eFlags & INTERFACE_EFLAG) != 0;
@@ -1652,7 +1657,7 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
   {
     if (eIsProxy()) return super.toString();
 
-    StringBuffer result = new StringBuffer(super.toString());
+    StringBuilder result = new StringBuilder(super.toString());
     result.append(" (abstract: ");
     result.append((eFlags & ABSTRACT_EFLAG) != 0);
     result.append(", interface: ");
@@ -2063,6 +2068,7 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
    * <!-- end-user-doc -->
    * @generated
    */
+  @Override
   public EList<EOperation> getEOperations()
   {
     if (eOperations == null)
