@@ -1,9 +1,9 @@
 /**
- * Copyright (c) 2002-2010 IBM Corporation and others.
+ * Copyright (c) 2002-2012 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  * 
  * Contributors: 
  *   IBM - Initial API and implementation
@@ -20,7 +20,7 @@ import org.eclipse.emf.common.util.ResourceLocator;
 import org.eclipse.emf.common.util.URI;
 import org.eclipse.emf.ecore.resource.URIHandler;
 
-import com.google.gwt.core.client.GWT;
+import com.google.gwt.core.shared.GWT;
 
 
 /**
@@ -347,7 +347,7 @@ public class EcorePlugin  extends EMFPlugin
   private static Map<String, URI> platformResourceMap;
 
   /**
-   * @see {@link URIHandler#DEFAULT_HANDLERS}
+   * @see URIHandler#DEFAULT_HANDLERS
    */
   public static List<URIHandler> DEFAULT_URI_HANDLERS = new ArrayList<URIHandler>();
 }
\ No newline at end of file
