@@ -1,9 +1,9 @@
 /**
- * Copyright (c) 2002-2011 IBM Corporation and others.
+ * Copyright (c) 2002-2012 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  *
  * Contributors:
  *   IBM - Initial API and implementation
@@ -47,7 +47,7 @@ import org.eclipse.emf.ecore.util.EcoreUtil.ProperContentIterator;
 import org.eclipse.emf.ecore.util.InternalEList;
 import org.eclipse.emf.ecore.util.NotifyingInternalEListImpl;
 
-import com.google.gwt.core.client.GWT;
+import com.google.gwt.core.shared.GWT;
 
 
 /**
@@ -75,8 +75,6 @@ import com.google.gwt.core.client.GWT;
  *   <li><b>ZIP</b></li>
  *   <ul>
  *     <li>{@link #useZip}</li>
- *     <li>{@link #newContentZipEntry}</li>
- *     <li>{@link #isContentZipEntry(ZipEntry)}</li>
  *   </ul>
  *   <li><b>URI Conversion</b></li>
  *   <ul>
@@ -626,8 +624,6 @@ public class ResourceImpl extends NotifierImpl implements Resource, Resource.Int
    * {@link #save(OutputStream, Map)} and {@link #load(InputStream, Map)}
    * will zip compress and decompress contents.
    * @return whether contents will be compressed.
-   * @see #newContentZipEntry
-   * @see #isContentZipEntry(ZipEntry)
    */
   protected boolean useZip()
   {
