@@ -2370,9 +2370,14 @@ public abstract class DelegatingFeatureMap extends DelegatingEcoreEList<FeatureM
     }
   }
 
-    @Override
-   public void set(Object newValue)
-   {
-     super.set(newValue instanceof FeatureMap ? newValue : ((FeatureMap.Internal.Wrapper)newValue).featureMap());
-   }
+  @Override
+  public void set(Object newValue)
+  {
+    super.set
+      (newValue instanceof FeatureMap ?
+         newValue :
+         newValue instanceof FeatureMap.Internal.Wrapper ?
+           ((FeatureMap.Internal.Wrapper)newValue).featureMap() :
+           newValue);
+  }
 }
