@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2002-2010 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  * 
  * Contributors: 
  *   IBM - Initial API and implementation
@@ -12,12 +12,12 @@ package org.eclipse.emf.common.ui;
 
 
 import java.net.MalformedURLException;
-import java.net.URL;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.Map;
 
+import org.eclipse.emf.common.util.CommonUtil;
 import org.eclipse.jface.action.MenuManager;
 import org.eclipse.jface.action.ToolBarManager;
 import org.eclipse.jface.resource.ImageDescriptor;
@@ -61,6 +61,8 @@ import org.eclipse.ui.IWorkbenchPart;
  */
 public abstract class ViewerPane implements IPropertyListener, Listener
 {
+  private static final long serialVersionUID = 1L;
+
   protected IWorkbenchPage page;
   protected IWorkbenchPart part;
   protected Collection<Object> buddies = new ArrayList<Object>();
@@ -78,6 +80,10 @@ public abstract class ViewerPane implements IPropertyListener, Listener
   protected MouseListener mouseListener = 
     new MouseAdapter() 
     {
+      /**
+       * 
+       */
+      private static final long serialVersionUID = 1L;
       @Override
       public void mouseDown(MouseEvent e) 
       {
@@ -155,7 +161,12 @@ public abstract class ViewerPane implements IPropertyListener, Listener
       control.addDisposeListener
         (new DisposeListener()
          {
-           public void widgetDisposed(DisposeEvent event)
+           /**
+           * 
+           */
+          private static final long serialVersionUID = 1L;
+
+          public void widgetDisposed(DisposeEvent event)
            {
              dispose();
            }
@@ -242,6 +253,11 @@ public abstract class ViewerPane implements IPropertyListener, Listener
    */
   class PaneToolBarManager extends ToolBarManager 
   {
+    /**
+     * 
+     */
+    private static final long serialVersionUID = 1L;
+
     public PaneToolBarManager(ToolBar paneToolBar) 
     {
       super(paneToolBar);
@@ -304,12 +320,17 @@ public abstract class ViewerPane implements IPropertyListener, Listener
       {
         pullDownImage = 
           ImageDescriptor.createFromURL
-            (new URL(CommonUIPlugin.INSTANCE.getImage("full/ctool16/ViewPullDown").toString())).createImage();
+            (CommonUtil.newURL(CommonUIPlugin.INSTANCE.getImage("full/ctool16/ViewPullDown").toString())).createImage();
         ti.setImage(pullDownImage);
         ti.addSelectionListener
           (new SelectionAdapter() 
            {
-             @Override
+             /**
+             * 
+             */
+            private static final long serialVersionUID = 1L;
+
+            @Override
             public void widgetSelected(SelectionEvent e) 
              {
               showViewMenu();
@@ -342,7 +363,12 @@ public abstract class ViewerPane implements IPropertyListener, Listener
       titleLabel.addMouseListener
         (new MouseAdapter() 
          {
-           @Override
+           /**
+           * 
+           */
+          private static final long serialVersionUID = 1L;
+
+          @Override
           public void mouseDown(MouseEvent e) 
            {
              if (e.button == 3)
@@ -577,7 +603,12 @@ public abstract class ViewerPane implements IPropertyListener, Listener
     restoreItem.addSelectionListener
       (new SelectionAdapter() 
        {
-         @Override
+         /**
+         * 
+         */
+        private static final long serialVersionUID = 1L;
+
+        @Override
         public void widgetSelected(SelectionEvent selectionEvent) 
          {
            doMaximize();
@@ -590,7 +621,12 @@ public abstract class ViewerPane implements IPropertyListener, Listener
     maximizeItem.addSelectionListener
       (new SelectionAdapter() 
        {
-         @Override
+         /**
+         * 
+         */
+        private static final long serialVersionUID = 1L;
+
+        @Override
         public void widgetSelected(SelectionEvent selectionEvent) 
          {
            doMaximize();
