@@ -1,68 +1,57 @@
 /**
  * Copyright (c) 2005-2006 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- * 
- * Contributors: 
+ * http://www.eclipse.org/legal/epl-v20.html
+ *
+ * Contributors:
  *   IBM - Initial API and implementation
  */
 package org.eclipse.emf.test.tools.codegen;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+
 import java.util.ArrayList;
 import java.util.Collections;
+import java.util.Iterator;
 import java.util.List;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 import org.eclipse.emf.codegen.ecore.genmodel.GenAnnotation;
 import org.eclipse.emf.codegen.ecore.genmodel.GenModel;
 import org.eclipse.emf.codegen.ecore.genmodel.GenModelFactory;
 import org.eclipse.emf.codegen.ecore.genmodel.GenPackage;
+import org.eclipse.emf.codegen.ecore.genmodel.GenPackage.AnnotationReferenceData;
+import org.eclipse.emf.codegen.ecore.genmodel.GenRuntimeVersion;
 import org.eclipse.emf.common.util.URI;
+import org.eclipse.emf.ecore.EAnnotation;
 import org.eclipse.emf.ecore.EClass;
+import org.eclipse.emf.ecore.EObject;
 import org.eclipse.emf.ecore.EPackage;
 import org.eclipse.emf.ecore.EcoreFactory;
 import org.eclipse.emf.ecore.EcorePackage;
+import org.eclipse.emf.ecore.resource.Resource;
 import org.eclipse.emf.ecore.resource.ResourceSet;
 import org.eclipse.emf.ecore.resource.impl.ResourceFactoryImpl;
 import org.eclipse.emf.ecore.resource.impl.ResourceImpl;
 import org.eclipse.emf.ecore.resource.impl.ResourceSetImpl;
+import org.junit.Before;
+import org.junit.Test;
 
-public class GenModelTest extends TestCase
+
+public class GenModelTest
 {
   protected  GenModel genModel;
-  
-  /**
-   * @param name
-   */
-  public GenModelTest(String name)
-  {
-    super(name);
-  }
 
-  public static Test suite()
-  {
-    TestSuite ts = new TestSuite("GenModelTest");
-    ts.addTest(new GenModelTest("testGetModelQualifiedPackageNames"));
-    ts.addTest(new GenModelTest("testGetEditQualifiedPackageNames"));
-    ts.addTest(new GenModelTest("testGetEditorQualifiedPackageNames"));
-    ts.addTest(new GenModelTest("testReloadGenAnnotations"));
-    ts.addTest(new GenModelTest("testGenPackageSubstitutions"));
-    ts.addTest(new GenModelTest("testNestedGenPackageSubstitutions"));
-    ts.addTest(new GenModelTest("testGenModelClasses"));
-    return ts;
-  }
-  
-  @Override
-  protected void setUp() throws Exception
+  @Before
+  public void setUp() throws Exception
   {
     genModel = createGenModel();
   }
-  
+
   protected GenModel createGenModel()
   {
     List<EPackage> ePackages = new ArrayList<EPackage>();
@@ -70,7 +59,7 @@ public class GenModelTest extends TestCase
     ePackages.add(createEPackage(1, false, false));
     ePackages.add(createEPackage(2, true, true));
     ePackages.add(createEPackage(3, false, true));
-    
+
     GenModel genModel = GenModelFactory.eINSTANCE.createGenModel();
     genModel.setModelDirectory("project1/f1");
     genModel.initialize(ePackages);
@@ -78,7 +67,7 @@ public class GenModelTest extends TestCase
     genModel.setEditPluginClass("editPluginClass.PC");
     genModel.setEditorPluginClass("editorPluginClass.PC");
     genModel.setTestSuiteClass("testSuiteClass.TC");
-    
+
     {
       GenPackage genPackage = genModel.getGenPackages().get(0);
       assertEquals("ePackage0", genPackage.getEcorePackage().getName());
@@ -124,14 +113,14 @@ public class GenModelTest extends TestCase
     }
     return genModel;
   }
-  
+
   protected EPackage createEPackage(int id, boolean hasClass, boolean subPackage)
   {
     EPackage ePackage = EcoreFactory.eINSTANCE.createEPackage();
     ePackage.setName("ePackage" + id);
     ePackage.setNsPrefix("NSPrefix_" + ePackage.getName());
     ePackage.setNsURI("NSURI_" + ePackage.getName());
-    
+
     if (hasClass)
     {
       EClass eClass = EcoreFactory.eINSTANCE.createEClass();
@@ -151,44 +140,46 @@ public class GenModelTest extends TestCase
       eClass.setName("Class2");
       subEPackage.getEClassifiers().add(eClass);
     }
-    
+
     return ePackage;
   }
-  
+
   /*
    * Bugzilla 98140
    */
+  @Test
   public void testGetModelQualifiedPackageNames() throws Exception
   {
     List<String> packageNames = genModel.getModelQualifiedPackageNames();
     modelQualifiedPackageNamesTest(packageNames);
     assertTrue(packageNames.isEmpty());
-    
+
     genModel.setTestsDirectory(genModel.getModelDirectory());
     packageNames = genModel.getModelQualifiedPackageNames();
     modelQualifiedPackageNamesTest(packageNames);
     testsQualifiedPackageNamesTest(packageNames);
-    assertTrue(packageNames.isEmpty());    
+    assertTrue(packageNames.isEmpty());
   }
 
   /*
    * Bugzilla 98140
    */
+  @Test
   public void testGetEditQualifiedPackageNames() throws Exception
   {
     List<String> packageNames = genModel.getEditQualifiedPackageNames();
     editQualifiedPackageNamesTest(packageNames);
     assertTrue(packageNames.isEmpty());
-    
+
     genModel.setEditDirectory(genModel.getModelDirectory());
     packageNames = genModel.getEditQualifiedPackageNames();
     modelQualifiedPackageNamesTest(packageNames);
     editQualifiedPackageNamesTest(packageNames);
-    assertTrue(packageNames.isEmpty()); 
+    assertTrue(packageNames.isEmpty());
     //
     packageNames = genModel.getModelQualifiedPackageNames();
     modelQualifiedPackageNamesTest(packageNames);
-    assertTrue(packageNames.isEmpty());    
+    assertTrue(packageNames.isEmpty());
 
     genModel.setTestsDirectory(genModel.getModelDirectory());
     packageNames = genModel.getEditQualifiedPackageNames();
@@ -200,23 +191,24 @@ public class GenModelTest extends TestCase
     packageNames = genModel.getModelQualifiedPackageNames();
     modelQualifiedPackageNamesTest(packageNames);
     testsQualifiedPackageNamesTest(packageNames);
-    assertTrue(packageNames.isEmpty());    
+    assertTrue(packageNames.isEmpty());
   }
-  
+
   /*
    * Bugzilla 98140
    */
+  @Test
   public void testGetEditorQualifiedPackageNames() throws Exception
   {
     List<String> packageNames = genModel.getEditorQualifiedPackageNames();
     editorQualifiedPackageNamesTest(packageNames);
     assertTrue(packageNames.isEmpty());
-    
+
     genModel.setEditorDirectory(genModel.getEditDirectory());
     packageNames = genModel.getEditorQualifiedPackageNames();
     editorQualifiedPackageNamesTest(packageNames);
     editQualifiedPackageNamesTest(packageNames);
-    assertTrue(packageNames.isEmpty()); 
+    assertTrue(packageNames.isEmpty());
     //
     packageNames = genModel.getModelQualifiedPackageNames();
     modelQualifiedPackageNamesTest(packageNames);
@@ -224,15 +216,15 @@ public class GenModelTest extends TestCase
     //
     packageNames = genModel.getEditQualifiedPackageNames();
     editQualifiedPackageNamesTest(packageNames);
-    assertTrue(packageNames.isEmpty());    
-    
+    assertTrue(packageNames.isEmpty());
+
     genModel.setEditDirectory(genModel.getModelDirectory());
     genModel.setEditorDirectory(genModel.getModelDirectory());
     packageNames = genModel.getEditorQualifiedPackageNames();
     editorQualifiedPackageNamesTest(packageNames);
     modelQualifiedPackageNamesTest(packageNames);
     editQualifiedPackageNamesTest(packageNames);
-    assertTrue(packageNames.isEmpty()); 
+    assertTrue(packageNames.isEmpty());
     //
     packageNames = genModel.getModelQualifiedPackageNames();
     modelQualifiedPackageNamesTest(packageNames);
@@ -241,7 +233,7 @@ public class GenModelTest extends TestCase
     packageNames = genModel.getEditQualifiedPackageNames();
     modelQualifiedPackageNamesTest(packageNames);
     editQualifiedPackageNamesTest(packageNames);
-    assertTrue(packageNames.isEmpty());    
+    assertTrue(packageNames.isEmpty());
 
     genModel.setTestsDirectory(genModel.getModelDirectory());
     packageNames = genModel.getEditorQualifiedPackageNames();
@@ -254,7 +246,7 @@ public class GenModelTest extends TestCase
     packageNames = genModel.getModelQualifiedPackageNames();
     modelQualifiedPackageNamesTest(packageNames);
     testsQualifiedPackageNamesTest(packageNames);
-    assertTrue(packageNames.isEmpty());    
+    assertTrue(packageNames.isEmpty());
   }
 
   protected void modelQualifiedPackageNamesTest(List<String> packageNames)
@@ -270,8 +262,8 @@ public class GenModelTest extends TestCase
     assertTrue(packageNames.remove("org.exampleS2.subEPackage2.util"));
     assertTrue(packageNames.remove("ePackage3.subEPackage3"));
     assertTrue(packageNames.remove("ePackage3.subEPackage3.impl"));
-    assertTrue(packageNames.remove("ePackage3.subEPackage3.util"));    
-    
+    assertTrue(packageNames.remove("ePackage3.subEPackage3.util"));
+
     assertTrue(packageNames.remove("modelPluginClass"));
   }
 
@@ -281,7 +273,7 @@ public class GenModelTest extends TestCase
     assertTrue(packageNames.remove("org.example2.ePackage2.provider"));
     assertTrue(packageNames.remove("org.exampleS2.subEPackage2.provider"));
     assertTrue(packageNames.remove("ePackage3.subEPackage3.provider"));
-    
+
     if (!genModel.getModelDirectory().equals(genModel.getEditDirectory()))
     {
       assertTrue(packageNames.remove("editPluginClass"));
@@ -309,16 +301,17 @@ public class GenModelTest extends TestCase
     assertTrue(packageNames.remove("org.exampleS2.subEPackage2.tests"));
     assertTrue(packageNames.remove("ePackage3.subEPackage3.tests"));
 
-    assertTrue(packageNames.remove("testSuiteClass"));    
+    assertTrue(packageNames.remove("testSuiteClass"));
   }
-  
+
   /*
    * Bugzilla 120964
    */
+  @Test
   public void testReloadGenAnnotations() throws Exception
   {
     new ResourceImpl(URI.createURI("foo.bar")).getContents().add(genModel);
-    
+
     GenAnnotation nestedGenAnnotation = genModel.createGenAnnotation();
     nestedGenAnnotation.setSource("1.1s");
     nestedGenAnnotation.getDetails().put("1.1", "one.one");
@@ -326,7 +319,7 @@ public class GenModelTest extends TestCase
     nestedGenAnnotation.getReferences().add(genModel);
     nestedGenAnnotation.getReferences().add(genModel.getGenPackages().get(1));
     nestedGenAnnotation.getReferences().add(EcorePackage.Literals.EATTRIBUTE);
-    
+
     GenAnnotation genAnnotation = genModel.createGenAnnotation();
     genAnnotation.setSource("1s");
     genAnnotation.getDetails().put("1", "one");
@@ -339,23 +332,23 @@ public class GenModelTest extends TestCase
     nestedGenAnnotation.getReferences().add(genAnnotation);
     genAnnotation.getGenAnnotations().add(nestedGenAnnotation);
     genModel.getGenAnnotations().add(genAnnotation);
-    
+
     assertGenModelAnnotations(genModel);
-    
+
     GenModel newGenModel = createGenModel();
     ResourceSet resourceSet = new ResourceSetImpl();
     resourceSet.getResourceFactoryRegistry().getExtensionToFactoryMap().put("bar", new ResourceFactoryImpl());
     resourceSet.createResource(URI.createURI("foo.bar")).getContents().add(newGenModel);
     newGenModel.reconcile(genModel);
-    
+
     assertGenModelAnnotations(genModel);
     assertGenModelAnnotations(newGenModel);
   }
-  
+
   protected void assertGenModelAnnotations(GenModel genModel) throws Exception
   {
     assertEquals(1, genModel.getGenAnnotations().size());
-    
+
     GenAnnotation genAnnotation = genModel.getGenAnnotations().get(0);
     assertEquals("1s", genAnnotation.getSource());
     assertEquals(2, genAnnotation.getDetails().size());
@@ -365,9 +358,9 @@ public class GenModelTest extends TestCase
     assertEquals(genModel, genAnnotation.getReferences().get(0));
     assertEquals(genModel.getGenPackages().get(1), genAnnotation.getReferences().get(1));
     assertEquals(EcorePackage.Literals.EATTRIBUTE, genAnnotation.getReferences().get(2));
-    
+
     assertEquals(1, genAnnotation.getGenAnnotations().size());
-    
+
     GenAnnotation nestedGenAnnotation = genAnnotation.getGenAnnotations().get(0);
     assertEquals("1.1s", nestedGenAnnotation.getSource());
     assertEquals(2, nestedGenAnnotation.getDetails().size());
@@ -377,14 +370,15 @@ public class GenModelTest extends TestCase
     assertEquals(genModel, nestedGenAnnotation.getReferences().get(0));
     assertEquals(genModel.getGenPackages().get(1), nestedGenAnnotation.getReferences().get(1));
     assertEquals(EcorePackage.Literals.EATTRIBUTE, nestedGenAnnotation.getReferences().get(2));
-    
+
     assertEquals(genAnnotation, nestedGenAnnotation.getReferences().get(3));
     assertEquals(nestedGenAnnotation, genAnnotation.getReferences().get(3));
   }
-  
+
   /*
    * Bugzilla 234105
    */
+  @Test
   public void testGenPackageSubstitutions()
   {
     EPackage ePackage = EcoreFactory.eINSTANCE.createEPackage();
@@ -432,6 +426,7 @@ public class GenModelTest extends TestCase
   /*
    * Bugzilla 234105
    */
+  @Test
   public void testNestedGenPackageSubstitutions()
   {
     EPackage ePackage = EcoreFactory.eINSTANCE.createEPackage();
@@ -496,6 +491,7 @@ public class GenModelTest extends TestCase
   /*
    * Bugzilla 234105
    */
+  @Test
   public void testGenModelClasses()
   {
     GenModel genModel = GenModelFactory.eINSTANCE.createGenModel();
@@ -520,7 +516,7 @@ public class GenModelTest extends TestCase
     genPackage.setProviderPackageSuffix("edit");
     genPackage.setPresentationPackageSuffix("edit.ui");
     genPackage.setTestsPackageSuffix("test");
-    
+
     assertNull(genModel.getModelPluginClass());
     assertEquals("domain.edit.DomainEditPlugin", genModel.getEditPluginClass());
     assertEquals("domain.edit.ui.DomainEditorPlugin", genModel.getEditorPluginClass());
@@ -550,4 +546,154 @@ public class GenModelTest extends TestCase
     assertEquals("com.example.internal.domain.presentation.DomainEditorPlugin", genModel.getEditorPluginClass());
     assertEquals("com.example.internal.domain.tests.DomainAllTests", genModel.getTestSuiteClass());
   }
+
+  /*
+   * Bugzilla 403547
+   */
+  @Test
+  public void testURIFragments() throws Exception
+  {
+    new ResourceImpl(URI.createURI("foo.bar")).getContents().add(genModel);
+
+    GenAnnotation nestedGenAnnotation = genModel.createGenAnnotation();
+    nestedGenAnnotation.setSource("%");
+    nestedGenAnnotation.getDetails().put("1.1", "one.one");
+    nestedGenAnnotation.getDetails().put("1.2", "one.two");
+    nestedGenAnnotation.getReferences().add(genModel);
+    nestedGenAnnotation.getReferences().add(genModel.getGenPackages().get(1));
+    nestedGenAnnotation.getReferences().add(EcorePackage.Literals.EATTRIBUTE);
+
+    GenAnnotation genAnnotation = genModel.createGenAnnotation();
+    genAnnotation.setSource("http://foo.bar");
+    genAnnotation.getDetails().put("1", "one");
+    genAnnotation.getDetails().put("2", "two");
+    genAnnotation.getReferences().add(genModel);
+    genAnnotation.getReferences().add(genModel.getGenPackages().get(1));
+    genAnnotation.getReferences().add(EcorePackage.Literals.EATTRIBUTE);
+
+    genAnnotation.getReferences().add(nestedGenAnnotation);
+    nestedGenAnnotation.getReferences().add(genAnnotation);
+    genAnnotation.getGenAnnotations().add(nestedGenAnnotation);
+    genModel.getGenAnnotations().add(genAnnotation);
+
+    assertURIFragments(genModel);
+
+    GenModel newGenModel = createGenModel();
+    ResourceSet resourceSet = new ResourceSetImpl();
+    resourceSet.getResourceFactoryRegistry().getExtensionToFactoryMap().put("bar", new ResourceFactoryImpl());
+    resourceSet.createResource(URI.createURI("foo.bar")).getContents().add(newGenModel);
+    newGenModel.reconcile(genModel);
+
+    assertURIFragments(genModel);
+    assertURIFragments(newGenModel);
+
+    assertURIFragments(genModel.eResource(), newGenModel.eResource());
+  }
+
+  protected void assertURIFragments(GenModel genModel) throws Exception
+  {
+    assertEquals(1, genModel.getGenAnnotations().size());
+
+    GenAnnotation genAnnotation = genModel.getGenAnnotations().get(0);
+    assertEquals("http://foo.bar", genAnnotation.getSource());
+    assertEquals(2, genAnnotation.getDetails().size());
+    assertEquals("one", genAnnotation.getDetails().get("1"));
+    assertEquals("two", genAnnotation.getDetails().get("2"));
+    assertEquals(4, genAnnotation.getReferences().size());
+    assertEquals(genModel, genAnnotation.getReferences().get(0));
+    assertEquals(genModel.getGenPackages().get(1), genAnnotation.getReferences().get(1));
+    assertEquals(EcorePackage.Literals.EATTRIBUTE, genAnnotation.getReferences().get(2));
+
+    assertEquals(1, genAnnotation.getGenAnnotations().size());
+
+    GenAnnotation nestedGenAnnotation = genAnnotation.getGenAnnotations().get(0);
+    assertEquals("%", nestedGenAnnotation.getSource());
+    assertEquals(2, nestedGenAnnotation.getDetails().size());
+    assertEquals("one.one", nestedGenAnnotation.getDetails().get("1.1"));
+    assertEquals("one.two", nestedGenAnnotation.getDetails().get("1.2"));
+    assertEquals(4, nestedGenAnnotation.getReferences().size());
+    assertEquals(genModel, nestedGenAnnotation.getReferences().get(0));
+    assertEquals(genModel.getGenPackages().get(1), nestedGenAnnotation.getReferences().get(1));
+    assertEquals(EcorePackage.Literals.EATTRIBUTE, nestedGenAnnotation.getReferences().get(2));
+
+    assertEquals(genAnnotation, nestedGenAnnotation.getReferences().get(3));
+    assertEquals(nestedGenAnnotation, genAnnotation.getReferences().get(3));
+  }
+
+  protected void assertURIFragments(Resource genModelResource, Resource newGenModelResource) throws Exception
+  {
+    for (Iterator<EObject> i = genModelResource.getAllContents(); i.hasNext(); )
+    {
+      EObject eObject = i.next();
+      String uriFragment = genModelResource.getURIFragment(eObject);
+      EObject newEObject = genModelResource.getEObject(uriFragment);
+      assertNotNull(newEObject);
+      String newURIFragment = genModelResource.getURIFragment(newEObject);
+      assertEquals(uriFragment, newURIFragment);
+    }
+  }
+
+  /*
+   * Bugzilla 573321
+   */
+  @Test
+  public void testAnnotationReferenceURIs() throws Exception
+  {
+    EPackage rootPackage = EcoreFactory.eINSTANCE.createEPackage();
+    rootPackage.setName("root");
+    rootPackage.setNsURI("root");
+
+    EClass rootEClass = EcoreFactory.eINSTANCE.createEClass();
+    rootEClass.setName("RootClass");
+    rootPackage.getEClassifiers().add(rootEClass);
+
+    EPackage subPackage = EcoreFactory.eINSTANCE.createEPackage();
+    subPackage.setName("sub");
+    subPackage.setNsURI("sub");
+
+    EClass subEClass = EcoreFactory.eINSTANCE.createEClass();
+    subEClass.setName("SubClass");
+    subPackage.getEClassifiers().add(subEClass);
+
+    EAnnotation rootEAnnotation = EcoreFactory.eINSTANCE.createEAnnotation();
+    rootEAnnotation.setSource("test");
+    rootEAnnotation.getReferences().add(rootEClass);
+    rootEAnnotation.getReferences().add(subEClass);
+    rootEClass.getEAnnotations().add(rootEAnnotation);
+
+    EAnnotation subEAnnotation = EcoreFactory.eINSTANCE.createEAnnotation();
+    subEAnnotation.setSource("test");
+    subEAnnotation.getReferences().add(rootEClass);
+    subEAnnotation.getReferences().add(subEClass);
+    subEClass.getEAnnotations().add(subEAnnotation);
+
+    rootPackage.getESubpackages().add(subPackage);
+
+    GenModel genModel = GenModelFactory.eINSTANCE.createGenModel();
+    genModel.setRuntimeVersion(GenRuntimeVersion.EMF26);
+    genModel.initialize(Collections.singletonList(rootPackage));
+    GenPackage genPackage = genModel.getGenPackages().get(0);
+    for (EAnnotation eAnnnotation : genPackage.getAllAnnotations())
+    {
+      List<AnnotationReferenceData> referenceData = genPackage.getReferenceData(eAnnnotation);
+      assertEquals(2, referenceData.size());
+      assertEquals("eNS_URI#//RootClass", getReferenceDetail(genPackage, referenceData.get(0)));
+      assertEquals("root.sub.SubPackage.eNS_URI#//SubClass", getReferenceDetail(genPackage, referenceData.get(1)));
+    }
+
+    GenPackage subGenPackage = genPackage.getSubGenPackages().get(0);
+    for (EAnnotation eAnnnotation : subGenPackage.getAllAnnotations())
+    {
+      List<AnnotationReferenceData> referenceData = genPackage.getReferenceData(eAnnnotation);
+      assertEquals(2, referenceData.size());
+      assertEquals("root.RootPackage.eNS_URI#//RootClass", getReferenceDetail(subGenPackage, referenceData.get(0)));
+      assertEquals("eNS_URI#//SubClass", getReferenceDetail(subGenPackage, referenceData.get(1)));
+    }
+  }
+
+  private String getReferenceDetail(GenPackage genPackage, AnnotationReferenceData referenceDataItem)
+  {
+    String detail = (referenceDataItem.containingGenPackage != genPackage ? referenceDataItem.containingGenPackage.getImportedPackageInterfaceName() + "." : "")  + "eNS_URI#"  + referenceDataItem.uriFragment;
+    return detail;
+  }
 }
